@@ -16,10 +16,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include <config.h>
-#include <version.h>
 
 #include <unistd.h>
 #include <stdio.h>
@@ -42,14 +41,6 @@
 #include <cairo-pdf.h>
 #include <cairo-ps.h>
 
-static gboolean
-export_text_rendered_bounds (void *user_data,
-                             const GedaObject *object,
-                             gint *left,
-                             gint *top,
-                             gint *right,
-                             gint *bottom);
-
 static void export_layout_page (PAGE *page,
                                 cairo_rectangle_t *extents,
                                 cairo_matrix_t *mtx,
@@ -166,6 +157,11 @@ cmd_export_impl (void *data, int argc, char **argv)
   gtk_init_check (&argc, &argv);
   scm_init_guile ();
   liblepton_init ();
+
+  /* Enable rendering of placeholders. Otherwise the user won't
+     see what's wrong. */
+  set_render_placeholders ();
+
   scm_dynwind_begin ((scm_t_dynwind_flags) 0);
   toplevel = s_toplevel_new ();
   edascm_dynwind_toplevel (toplevel);
@@ -174,7 +170,6 @@ cmd_export_impl (void *data, int argc, char **argv)
   if (getenv ("LEPTON_INHIBIT_RC_FILES") == NULL) {
     g_rc_parse (toplevel, "lepton-cli export", NULL, NULL);
   }
-  i_vars_libgeda_set (toplevel); /* Ugh */
 
   /* Parse configuration files */
   export_config ();
@@ -228,40 +223,12 @@ cmd_export_impl (void *data, int argc, char **argv)
     exit (1);
   }
 
-  /* Load schematic files */
-  while (optind < argc) {
-    PAGE *page;
-    tmp = argv[optind++];
-
-    page = s_page_new (toplevel, tmp);
-    if (!f_open (toplevel, page, tmp, &err)) {
-      fprintf (stderr,
-               /* TRANSLATORS: The first string is the filename, the second
-                * is the detailed error message */
-               _("ERROR: Failed to load '%1$s': %2$s\n"), tmp,
-               err->message);
-      exit (1);
-    }
-    if (g_chdir (original_cwd) != 0) {
-      fprintf (stderr,
-               _("ERROR: Failed to change directory to '%1$s': %2$s\n"),
-               original_cwd, g_strerror (errno));
-      exit (1);
-    }
-  }
-
   /* Create renderer */
   renderer = eda_renderer_new (NULL, NULL);
   if (settings.font != NULL) {
     g_object_set (renderer, "font-name", settings.font, NULL);
   }
 
-  /* Make sure libgeda knows how to calculate the bounds of text
-   * taking into account font etc. */
-  o_text_set_rendered_bounds_func (toplevel,
-                                   export_text_rendered_bounds,
-                                   renderer);
-
   /* Create color map */
   render_color_map =
     g_array_sized_new (FALSE, FALSE, sizeof(GedaColor), MAX_COLORS);
@@ -290,6 +257,28 @@ cmd_export_impl (void *data, int argc, char **argv)
   }
   eda_renderer_set_color_map (renderer, render_color_map);
 
+  /* Load schematic files */
+  while (optind < argc) {
+    PAGE *page;
+    tmp = argv[optind++];
+
+    page = s_page_new (toplevel, tmp);
+    if (!f_open (toplevel, page, tmp, &err)) {
+      fprintf (stderr,
+               /* TRANSLATORS: The first string is the filename, the second
+                * is the detailed error message */
+               _("ERROR: Failed to load '%1$s': %2$s\n"), tmp,
+               err->message);
+      exit (1);
+    }
+    if (g_chdir (original_cwd) != 0) {
+      fprintf (stderr,
+               _("ERROR: Failed to change directory to '%1$s': %2$s\n"),
+               original_cwd, g_strerror (errno));
+      exit (1);
+    }
+  }
+
   /* Render */
   exporter->func ();
 
@@ -297,29 +286,6 @@ cmd_export_impl (void *data, int argc, char **argv)
   exit (0);
 }
 
-/* Callback function registered with libgeda to allow the libgeda
- * "bounds" functions to get text bounds using the renderer.  If a
- * "rendered bounds" function isn't provided, text objects don't get
- * used when calculating the extents of the drawing. */
-static gboolean
-export_text_rendered_bounds (void *user_data,
-                             const GedaObject *object,
-                             gint *left,
-                             gint *top,
-                             gint *right,
-                             gint *bottom)
-{
-  int result;
-  double t, l, r, b;
-  EdaRenderer *renderer = EDA_RENDERER (user_data);
-  result = eda_renderer_get_user_bounds (renderer, object, &l, &t, &r, &b);
-  *left = lrint (fmin (l,r));
-  *top = lrint (fmin (t, b));
-  *right = lrint (fmax (l, r));
-  *bottom = lrint (fmax (t, b));
-  return result;
-}
-
 /* Prints a message and quits with error status if a cairo status
  * value is not "success". */
 static inline void
@@ -373,9 +339,14 @@ export_layout_page (PAGE *page,
     m[3] = DEFAULT_MARGIN;
   }
 
-  /* Now calculate extents of objects within page */
-  world_get_object_glist_bounds (toplevel, s_page_objects (page),
-                                 &wx_min, &wy_min, &wx_max, &wy_max);
+  /* Now calculate extents of objects within page. Hidden text is
+     not taken into account. */
+  world_get_object_glist_bounds (s_page_objects (page),
+                                 FALSE,
+                                 &wx_min,
+                                 &wy_min,
+                                 &wx_max,
+                                 &wy_max);
   w_width = wx_max - wx_min;
   w_height = wy_max - wy_min;
 
@@ -862,7 +833,7 @@ export_parse_scale (const gchar *scale)
 static void
 export_config (void)
 {
-  EdaConfig *cfg = eda_config_get_context_for_file (NULL);
+  EdaConfig *cfg = eda_config_get_context_for_path (".");
   gchar *str;
   gdouble *lst;
   gdouble dval;
