@@ -1,9 +1,21 @@
 G_BEGIN_DECLS
 
 /* a_basic.c */
-int o_save (TOPLEVEL *toplevel, const GList *object_list, const char *filename, GError **err);
-GList *o_read_buffer(TOPLEVEL *toplevel, GList *object_list, char *buffer, const int size, const char *name, GError **err);
-GList *o_read(TOPLEVEL *toplevel, GList *object_list, char *filename, GError **err);
+int
+o_save (const GList *object_list,
+        const char *filename,
+        GError **err);
+GList*
+o_read_buffer (PAGE *page,
+               GList *object_list,
+               char *buffer,
+               const int size,
+               const char *name,
+               GError **err);
+PAGE*
+o_read (PAGE *page,
+        char *filename,
+        GError **err);
 
 /* f_basic.c */
 gchar *f_get_autosave_filename (const gchar *filename);
@@ -11,11 +23,18 @@ gboolean f_has_active_autosave (const gchar *filename, GError **err);
 int f_open(TOPLEVEL *toplevel, PAGE *page, const gchar *filename, GError **err);
 int f_open_flags(TOPLEVEL *toplevel, PAGE *page, const gchar *filename,
                  const gint flags, GError **err);
-void f_close(TOPLEVEL *toplevel);
-int f_save(TOPLEVEL *toplevel, PAGE *page, const char *filename, GError **error);
+int
+f_save (PAGE *page,
+        const char *filename,
+        GError **error);
+
 gchar *f_normalize_filename (const gchar *filename, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 char *follow_symlinks (const gchar *filename, GError **error);
 
+GString*
+f_backup_message (gchar *backup_filename,
+                  gboolean stat_error);
+
 /* g_basic.c */
 SCM g_scm_eval_protected (SCM exp, SCM module_or_state);
 SCM g_scm_eval_string_protected (SCM str);
@@ -32,10 +51,6 @@ void g_rc_parse_handler (TOPLEVEL *toplevel, const gchar *rcname, const gchar *r
 SCM g_rc_rc_filename();
 SCM g_rc_parse_rc (SCM pname_s, SCM rcname_s);
 
-/* i_vars.c */
-void i_vars_libgeda_set(TOPLEVEL *toplevel);
-void i_vars_libgeda_freenames();
-
 /* liblepton.c */
 void liblepton_init(void);
 void set_guile_compiled_path();
@@ -51,13 +66,29 @@ void m_polygon_append_bezier(GArray *points, GedaBezier *bezier, int segments);
 void m_polygon_append_point(GArray *points, int x, int y);
 
 /* o_attrib.c */
-void o_attrib_add(TOPLEVEL *toplevel, OBJECT *object, OBJECT *item);
-gboolean o_attrib_is_attached (TOPLEVEL *toplevel, OBJECT *attrib, OBJECT *object);
-void o_attrib_attach(TOPLEVEL *toplevel, OBJECT *attrib, OBJECT *object, int set_color);
-void o_attrib_attach_list(TOPLEVEL *toplevel, GList *attr_list, OBJECT *object, int set_color);
-void o_attrib_detach_all(TOPLEVEL *toplevel, OBJECT *object);
+void
+o_attrib_add (OBJECT *object,
+              OBJECT *item);
+
+void
+o_attrib_attach (OBJECT *attrib,
+                 OBJECT *object,
+                 int set_color);
+
+void
+o_attrib_attach_list (GList *attr_list,
+                      OBJECT *object,
+                      int set_color);
+
+void
+o_attrib_detach_all (OBJECT *object);
+
 void o_attrib_print(GList *attributes);
-void o_attrib_remove(TOPLEVEL *toplevel, GList **list, OBJECT *remove);
+
+void
+o_attrib_remove (GList **list,
+                 OBJECT *remove);
+
 gboolean o_attrib_string_get_name_value (const gchar *string, gchar **name_ptr, gchar **value_ptr);
 gboolean o_attrib_get_name_value (const OBJECT *attrib, gchar **name_ptr, gchar **value_ptr);
 const char *o_attrib_get_name (const OBJECT *attrib);
@@ -76,9 +107,16 @@ void o_unembed (OBJECT *o_current);
 
 /* o_selection.c */
 SELECTION *o_selection_new( void );
-void o_selection_add(TOPLEVEL *toplevel, SELECTION *selection, OBJECT *o_selected);
+
+void
+o_selection_add (SELECTION *selection,
+                 OBJECT *o_selected);
+
 void o_selection_print_all(const SELECTION *selection);
-void o_selection_remove(TOPLEVEL *toplevel, SELECTION *selection, OBJECT *o_selected);
+
+void
+o_selection_remove (SELECTION *selection,
+                    OBJECT *o_selected);
 
 /* s_attrib.c */
 int s_attrib_add_entry(char *new_attrib);
@@ -118,21 +156,11 @@ gchar *s_clib_symbol_get_data_by_name (const gchar *name);
 GList *s_toplevel_get_symbols (const TOPLEVEL *toplevel);
 
 /* s_conn.c */
-void s_conn_remove_object_connections (TOPLEVEL *toplevel, OBJECT *to_remove);
+void s_conn_remove_object_connections (OBJECT *to_remove);
 void s_conn_update_object (PAGE* page, OBJECT *object);
 int s_conn_net_search(OBJECT* new_net, int whichone, GList * conn_list);
 GList *s_conn_return_others(GList *input_list, OBJECT *object);
 
-/* s_hierarchy.c */
-PAGE *s_hierarchy_down_schematic_single(TOPLEVEL *toplevel, const gchar *filename, PAGE *parent, int page_control, int flag, GError **err);
-void s_hierarchy_down_symbol (TOPLEVEL *toplevel, const CLibSymbol *symbol, PAGE *parent);
-PAGE *s_hierarchy_find_up_page(GedaPageList *page_list, PAGE *current_page);
-PAGE* s_hierarchy_load_subpage (PAGE *page, const char *filename, GError **error);
-GList* s_hierarchy_traversepages(TOPLEVEL *toplevel, PAGE *p_current, gint flags);
-gint s_hierarchy_print_page(PAGE *p_current, void * data);
-PAGE *s_hierarchy_find_prev_page(GedaPageList *page_list, PAGE *current_page);
-PAGE *s_hierarchy_find_next_page(GedaPageList *page_list, PAGE *current_page);
-
 /* s_log.c */
 void s_log_init (const gchar *filename);
 void s_log_close (void);
@@ -148,7 +176,9 @@ void s_menu_init(void);
 
 /* s_slot.c */
 char *s_slot_search_slot(OBJECT *object, OBJECT **return_found);
-void s_slot_update_object(TOPLEVEL *toplevel, OBJECT *object);
+
+void
+s_slot_update_object (OBJECT *object);
 
 /* s_textbuffer.c */
 TextBuffer *s_textbuffer_new (const gchar *data, const gint size, const gchar* name);
