@@ -14,8 +14,7 @@
 ;;;
 ;;; You should have received a copy of the GNU General Public License
 ;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-;;; MA 02111-1301 USA.
+;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 ;;; Legacy Scheme RC interface.
 
@@ -29,7 +28,8 @@
             geda-rc-path
             path-sep
             load-scheme-dir
-            load-rc-from-sys-config-dirs))
+            load-rc-from-sys-config-dirs
+            process-gafrc))
 
 (define path-sep file-name-separator-string)
 
@@ -65,3 +65,19 @@ path (rather than the regular Scheme load path)."
   (let ((rc-file (search-path (sys-config-dirs) basename '("" ".scm"))))
     ;; Use primitive-load to suppress autocompilation
     (if rc-file (primitive-load rc-file))))
+
+
+;;; List of processed rc directories.
+(define %rc-dirs (make-hash-table))
+
+
+;;; Backward compatibility stuff.
+(define (process-gafrc program schematic)
+  "Process \"gafrc\" file for PROGRAM in the directory SCHEMATIC
+resides in."
+  (let ((cwd (getcwd)))
+    (unless (hash-ref %rc-dirs cwd)
+      (chdir (dirname schematic))
+      ((@@ (guile-user) parse-rc) program "gafrc")
+      (hash-set! %rc-dirs cwd cwd)
+      (chdir cwd))))
