@@ -22,7 +22,6 @@
  *  \brief basic libgeda read and write functions
  */
 #include <config.h>
-#include <version.h>
 
 #include <stdio.h>
 #ifdef HAVE_STRING_H
@@ -38,14 +37,15 @@
  *  \bug g_access introduces a race condition in certain cases, but
  *  solves bug #698565 in the normal use-case
  *
- *  \param [in] toplevel    The current TOPLEVEL.
  *  \param [in] object_list The head of a GList of OBJECTs to save.
  *  \param [in] filename    The filename to save the data to.
  *  \param [in,out] err     #GError structure for error reporting.
  *  \return 1 on success, 0 on failure.
  */
-int o_save (TOPLEVEL *toplevel, const GList *object_list,
-            const char *filename, GError **err)
+int
+o_save (const GList *object_list,
+        const char *filename,
+        GError **err)
 {
   char *buffer;
 
@@ -70,7 +70,7 @@ int o_save (TOPLEVEL *toplevel, const GList *object_list,
 
 /*! \brief Read a memory buffer
  *  \par Function Description
- *  This function reads data in libgeda format from a memory buffer.
+ *  This function reads data in gEDA format from a memory buffer.
  *
  *  If the size argument is negative, the buffer is assumed to be
  *  null-terminated.
@@ -78,14 +78,14 @@ int o_save (TOPLEVEL *toplevel, const GList *object_list,
  *  The name argument is used for debugging, and should be set to a
  *  meaningful string (e.g. the name of the file the data is from).
  *
- *  \param [in,out] toplevel    The current TOPLEVEL structure.
+ *  \param [in,out] page         The PAGE object.
  *  \param [in]     object_list  The object_list to read data to.
  *  \param [in]     buffer       The memory buffer to read from.
  *  \param [in]     size         The size of the buffer.
  *  \param [in]     name         The name to describe the data with.
  *  \return GList of objects if successful read, or NULL on error.
  */
-GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
+GList *o_read_buffer (PAGE *page, GList *object_list,
                       char *buffer, const int size,
                       const char *name, GError **err)
 {
@@ -105,6 +105,7 @@ GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
   int itemsread = 0;
 
   int embedded_level = 0;
+  gboolean force_boundingbox;
 
   g_return_val_if_fail ((buffer != NULL), NULL);
 
@@ -134,53 +135,53 @@ GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
     {
         /* yes */
         /* verify symbol version (not file format but rather contents) */
-        o_component_check_symversion(toplevel, last_component);
+        o_component_check_symversion (page, last_component);
         last_component = NULL;  /* no longer need to check */
     }
 
     switch (objtype) {
 
       case(OBJ_LINE):
-        if ((new_obj = o_line_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = o_line_read (line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
 
 
       case(OBJ_NET):
-        if ((new_obj = o_net_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = o_net_read (line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
 
       case(OBJ_BUS):
-        if ((new_obj = o_bus_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = o_bus_read (line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
 
       case(OBJ_BOX):
-        if ((new_obj = o_box_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = o_box_read (line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
 
       case(OBJ_PICTURE):
-        new_obj = o_picture_read (toplevel, line, tb, release_ver, fileformat_ver, err);
+        new_obj = o_picture_read (line, tb, release_ver, fileformat_ver, err);
         if (new_obj == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
 
       case(OBJ_CIRCLE):
-        if ((new_obj = o_circle_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = o_circle_read (line, release_ver, fileformat_ver, err)) == NULL)
 	  goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
 
       case(OBJ_COMPONENT):
       case(OBJ_PLACEHOLDER):
-        if ((new_obj = o_component_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = o_component_read (page, line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
 
@@ -189,28 +190,28 @@ GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
         break;
 
       case(OBJ_TEXT):
-        new_obj = o_text_read (toplevel, line, tb, release_ver, fileformat_ver, err);
+        new_obj = o_text_read (line, tb, release_ver, fileformat_ver, err);
         if (new_obj == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
 
       case(OBJ_PATH):
-        new_obj = o_path_read (toplevel, line, tb, release_ver, fileformat_ver, err);
+        new_obj = o_path_read (line, tb, release_ver, fileformat_ver, err);
         if (new_obj == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
 
       case(OBJ_PIN):
-        if ((new_obj = o_pin_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = o_pin_read (line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         found_pin++;
         break;
 
       case(OBJ_ARC):
-        if ((new_obj = o_arc_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = o_arc_read (line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
@@ -219,7 +220,7 @@ GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
         /* first is the fp */
         /* 2nd is the object to get the attributes */
         if (new_obj != NULL) {
-          new_attrs_list = o_read_attribs (toplevel, new_obj, tb, release_ver, fileformat_ver, err);
+          new_attrs_list = o_read_attribs (page, new_obj, tb, release_ver, fileformat_ver, err);
           if (new_attrs_list == NULL)
             goto error;
           new_object_list = g_list_concat (new_attrs_list, new_object_list);
@@ -230,7 +231,7 @@ GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
           {
             /* yes */
             /* verify symbol version (not file format but rather contents) */
-            o_component_check_symversion(toplevel, last_component);
+            o_component_check_symversion (page, last_component);
             last_component = NULL;
           }
 
@@ -238,7 +239,7 @@ GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
           if (new_obj != NULL &&
               (new_obj->type == OBJ_COMPONENT ||
                new_obj->type == OBJ_PLACEHOLDER)) {
-            s_slot_update_object (toplevel, new_obj);
+            s_slot_update_object (new_obj);
           }
           new_obj = NULL;
         }
@@ -271,8 +272,7 @@ GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
         if (embedded_level>0) {
           /* don't do this since objects are already
            * stored/read translated
-           * geda_component_object_translate (toplevel, new_object_list->x,
-           *                                  new_object_list->y, new_object_list->component);
+           * geda_component_object_translate (new_object_list->x, new_object_list->y, new_object_list->component);
            */
           new_object_list = g_list_reverse (new_object_list);
 
@@ -342,14 +342,16 @@ GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
   /* and had no attached attributes */
   if (last_component)
   {
-        o_component_check_symversion(toplevel, last_component);
-        last_component = NULL;  /* no longer need to check */
+    o_component_check_symversion (page, last_component);
+    last_component = NULL;  /* no longer need to check */
   }
 
-  if (found_pin) {
-    if (release_ver <= VERSION_20020825) {
-      geda_pin_object_update_whichend (toplevel, new_object_list, found_pin);
-    }
+  if (release_ver <= VERSION_20020825) {
+    cfg_read_bool ("schematic.gui", "force-boundingbox",
+                   default_force_boundingbox, &force_boundingbox);
+
+    geda_pin_object_update_whichend (new_object_list,
+                                     (found_pin == 1 || force_boundingbox));
   }
 
   s_textbuffer_free(tb);
@@ -360,7 +362,7 @@ GList *o_read_buffer (TOPLEVEL *toplevel, GList *object_list,
   return(object_list);
 
 error:
-  geda_object_list_delete (toplevel, new_object_list);
+  geda_object_list_delete (new_object_list);
 
   unsigned long linenum = s_textbuffer_linenum (tb);
   g_prefix_error (err, "Parsing stopped at line %lu:\n", linenum);
@@ -370,21 +372,22 @@ error:
 
 /*! \brief Read a file
  *  \par Function Description
- *  This function reads a file in libgeda format.
+ *  This function reads a file in gEDA format.
  *
- *  \param [in,out] toplevel    The current TOPLEVEL structure.
- *  \param [in]     object_list  The object_list to read data to.
+ *  \param [in,out] page         The PAGE object.
  *  \param [in]     filename     The filename to read from.
  *  \param [in,out] err          #GError structure for error reporting, or
  *                               NULL to disable error reporting
- *  \return object_list if successful read, or NULL on error.
+ *  \return page
  */
-GList *o_read (TOPLEVEL *toplevel, GList *object_list, char *filename,
-               GError **err)
+PAGE*
+o_read (PAGE *page,
+        char *filename,
+        GError **err)
 {
   char *buffer = NULL;
   size_t size;
-  GList *result;
+  GList *objects;
 
   /* Return NULL if error reporting is enabled and the return location
    * for an error isn't NULL. */
@@ -395,7 +398,10 @@ GList *o_read (TOPLEVEL *toplevel, GList *object_list, char *filename,
   }
 
   /* Parse file contents */
-  result = o_read_buffer (toplevel, object_list, buffer, size, filename, err);
+  objects = o_read_buffer (page, NULL, buffer, size, filename, err);
   g_free (buffer);
-  return result;
+
+  s_page_append_list (page, objects);
+
+  return page;
 }
