@@ -51,7 +51,6 @@
 
 #include "libgeda_priv.h"
 
-
 /*! \brief Get the autosave filename for a file
  *  \par Function description
  *  Returns the expected autosave filename for the \a filename passed.
@@ -166,6 +165,33 @@ int f_open(TOPLEVEL *toplevel, PAGE *page,
                        F_OPEN_RC | F_OPEN_CHECK_BACKUP, err);
 }
 
+
+GString*
+f_backup_message (gchar *backup_filename,
+                  gboolean stat_error)
+{
+  GString *message = g_string_new ("");
+
+  g_string_append_printf (message,
+                          _("\nWARNING: Found an autosave backup file:\n  %1$s.\n\n"),
+                          backup_filename);
+
+  if (stat_error) {
+    g_string_append (message,
+                     _("I could not guess if it is newer, so you have to do it manually.\n"));
+  } else {
+    g_string_append (message,
+                     _("The backup copy is newer than the schematic, so it seems you should load it instead of the original file.\n"));
+  }
+
+  g_string_append (message,
+                   _("lepton-schematic usually makes backup copies automatically, and this situation happens when it crashed or it was forced to exit abruptly.\n"));
+
+  /* The user must g_string_free the message. */
+  return message;
+}
+
+
 /*! \brief Opens the schematic file with fine-grained control over behaviour.
  *  \par Function Description
  *  Opens the schematic file and carries out a number of actions
@@ -194,7 +220,7 @@ int f_open_flags(TOPLEVEL *toplevel, PAGE *page,
   char *file_directory = NULL;
   char *saved_cwd = NULL;
   char *backup_filename = NULL;
-  char load_backup_file = 0;
+  gboolean load_backup_file = FALSE;
   GError *tmp_err = NULL;
 
   /* has the head been freed yet? */
@@ -249,48 +275,39 @@ int f_open_flags(TOPLEVEL *toplevel, PAGE *page,
 
   g_free (file_directory);
 
-  if (flags & F_OPEN_CHECK_BACKUP) {
+  if (flags & F_OPEN_FORCE_BACKUP) {
+    backup_filename = f_get_autosave_filename (full_filename);
+    load_backup_file = TRUE;
+  }
+  else if (flags & F_OPEN_CHECK_BACKUP) {
     /* Check if there is a newer autosave backup file */
-    GString *message;
     gboolean active_backup = f_has_active_autosave (full_filename, &tmp_err);
     backup_filename = f_get_autosave_filename (full_filename);
 
-    if (tmp_err != NULL) g_warning ("%s\n", tmp_err->message);
+    gboolean stat_error = (tmp_err != NULL);
+    if (stat_error) {
+      g_warning ("%s\n", tmp_err->message);
+      g_error_free (tmp_err);
+    }
+
     if (active_backup) {
-      message = g_string_new ("");
-      g_string_append_printf(message, _("\nWARNING: Found an autosave backup file:\n  %1$s.\n\n"), backup_filename);
-      if (tmp_err != NULL) {
-        g_string_append(message, _("I could not guess if it is newer, so you have to do it manually.\n"));
-      } else {
-        g_string_append(message, _("The backup copy is newer than the schematic, so it seems you should load it instead of the original file.\n"));
-      }
-      g_string_append (message, _("lepton-schematic usually makes backup copies automatically, and this situation happens when it crashed or it was forced to exit abruptly.\n"));
-      if (toplevel->load_newer_backup_func == NULL) {
-        g_warning ("%s", message->str);
-        g_warning (_("\nRun lepton-schematic and correct the situation.\n\n"));
-      } else {
-        /* Ask the user if load the backup or the original file */
-        if (toplevel->load_newer_backup_func
-            (toplevel->load_newer_backup_data, message)) {
-          /* Load the backup file */
-          load_backup_file = 1;
-        }
-      }
+      GString *message =
+        f_backup_message (backup_filename, stat_error);
+      g_warning ("%s", message->str);
+      g_warning (_("\nRun lepton-schematic and correct the situation.\n\n"));
       g_string_free (message, TRUE);
+      /* load_backup_file = FALSE; */
     }
-    if (tmp_err != NULL) g_error_free (tmp_err);
   }
 
   /* Now that we have set the current directory and read
    * the RC file, it's time to read in the file. */
-  if (load_backup_file == 1) {
+  if (load_backup_file) {
     /* Load the backup file */
-    s_page_append_list (toplevel, page,
-                        o_read (toplevel, NULL, backup_filename, &tmp_err));
+    o_read (page, backup_filename, &tmp_err);
   } else {
     /* Load the original file */
-    s_page_append_list (toplevel, page,
-                        o_read (toplevel, NULL, full_filename, &tmp_err));
+    o_read (page, full_filename, &tmp_err);
   }
 
   if (tmp_err == NULL)
@@ -298,7 +315,7 @@ int f_open_flags(TOPLEVEL *toplevel, PAGE *page,
   else
     g_propagate_error (err, tmp_err);
 
-  if (load_backup_file == 0) {
+  if (!load_backup_file) {
     /* If it's not the backup file */
     page->CHANGED=0; /* added 4/7/98 */
   } else {
@@ -326,16 +343,6 @@ int f_open_flags(TOPLEVEL *toplevel, PAGE *page,
   return opened;
 }
 
-/*! \brief Closes the schematic file
- *  \par Function Description
- *  Does nothing
- *
- *  \param [in,out] toplevel  The TOPLEVEL object with schematic to be closed.
- */
-void f_close(TOPLEVEL *toplevel)
-{
-
-}
 
 /*! \brief Save the schematic file
  *  \par Function Description
@@ -344,13 +351,15 @@ void f_close(TOPLEVEL *toplevel)
  *  \bug g_access introduces a race condition in certain cases, but
  *  solves bug #698565 in the normal use-case
  *
- *  \param [in,out] toplevel  The TOPLEVEL object containing the schematic.
  *  \param [in]      filename  The file name to save the schematic to.
  *  \param [in,out] err       #GError structure for error reporting, or
  *                            NULL to disable error reporting
  *  \return 1 on success, 0 on failure.
  */
-int f_save(TOPLEVEL *toplevel, PAGE *page, const char *filename, GError **err)
+int
+f_save (PAGE *page,
+        const char *filename,
+        GError **err)
 {
   gchar *backup_filename;
   gchar *real_filename;
@@ -452,7 +461,7 @@ int f_save(TOPLEVEL *toplevel, PAGE *page, const char *filename, GError **err)
   g_free (dirname);
   g_free (only_filename);
   
-  if (o_save (toplevel, s_page_objects (page), real_filename, &tmp_err)) {
+  if (o_save (s_page_objects (page), real_filename, &tmp_err)) {
 
     page->saved_since_first_loaded = 1;
 
