@@ -44,7 +44,6 @@
  *  line type with a width of 0, and no filling. It can be changed after
  *  with the #o_set_line_options() and #o_set_fill_options().
  *
- *  \param [in]     toplevel     The TOPLEVEL object.
  *  \param [in]     type         Box type.
  *  \param [in]     color        Box border color.
  *  \param [in]     x1           Upper x coordinate.
@@ -54,8 +53,12 @@
  *  \return The new OBJECT
  */
 OBJECT*
-geda_box_object_new (TOPLEVEL *toplevel, char type, int color,
-                     int x1, int y1, int x2, int y2)
+geda_box_object_new (char type,
+                     int color,
+                     int x1,
+                     int y1,
+                     int x2,
+                     int y2)
 {
   OBJECT *new_node;
   BOX *box;
@@ -74,16 +77,15 @@ geda_box_object_new (TOPLEVEL *toplevel, char type, int color,
   box->lower_y = y2;
 
   /* line type and filling initialized to default */
-  o_set_line_options (toplevel,
-                      new_node,
+  o_set_line_options (new_node,
                       DEFAULT_OBJECT_END,
                       TYPE_SOLID,
                       LINE_WIDTH,
                       -1,
                       -1);
 
-  o_set_fill_options(toplevel, new_node,
-		     FILLING_HOLLOW, -1, -1, -1, -1, -1);
+  o_set_fill_options (new_node,
+                      FILLING_HOLLOW, -1, -1, -1, -1, -1);
 
   return new_node;
 }
@@ -93,18 +95,17 @@ geda_box_object_new (TOPLEVEL *toplevel, char type, int color,
  *  The function #geda_box_object_copy() creates a verbatim copy of the object
  *  pointed by <B>o_current</B> describing a box.
  *
- *  \param [in]      toplevel  The TOPLEVEL object.
  *  \param [in]      o_current  BOX OBJECT to copy.
  *  \return The new OBJECT
  */
 OBJECT*
-geda_box_object_copy(TOPLEVEL *toplevel, OBJECT *o_current)
+geda_box_object_copy (OBJECT *o_current)
 {
   OBJECT *new_obj;
 
   /* A new box object is created with #geda_box_object_new().
    * Values for its fields are default and need to be modified. */
-  new_obj = geda_box_object_new (toplevel, OBJ_BOX, o_current->color, 0, 0, 0, 0);
+  new_obj = geda_box_object_new (OBJ_BOX, o_current->color, 0, 0, 0, 0);
 
   /*
    * The dimensions of the new box are set with the ones of the original box.
@@ -116,13 +117,13 @@ geda_box_object_copy(TOPLEVEL *toplevel, OBJECT *o_current)
   new_obj->box->lower_x = o_current->box->lower_x;
   new_obj->box->lower_y = o_current->box->lower_y;
 
-  o_set_line_options(toplevel, new_obj, o_current->line_end,
-		     o_current->line_type, o_current->line_width,
-		     o_current->line_length, o_current->line_space);
-  o_set_fill_options(toplevel, new_obj,
-		     o_current->fill_type, o_current->fill_width,
-		     o_current->fill_pitch1, o_current->fill_angle1,
-		     o_current->fill_pitch2, o_current->fill_angle2);
+  o_set_line_options (new_obj, o_current->line_end,
+                      o_current->line_type, o_current->line_width,
+                      o_current->line_length, o_current->line_space);
+  o_set_fill_options (new_obj,
+                      o_current->fill_type, o_current->fill_width,
+                      o_current->fill_pitch1, o_current->fill_angle1,
+                      o_current->fill_pitch2, o_current->fill_angle2);
 
   return new_obj;
 }
@@ -133,7 +134,6 @@ geda_box_object_copy(TOPLEVEL *toplevel, OBJECT *o_current)
  * the box to the rectangle enclosed by the points (\a x1, \a y1) and
  * (\a x2, \a y2).
  *
- * \param [in]     toplevel current #TOPLEVEL.
  * \param [in,out] object   box #OBJECT to be modified.
  * \param [in]     x1       x coordinate of first corner of box.
  * \param [in]     y1       y coordinate of first corner of box.
@@ -141,10 +141,13 @@ geda_box_object_copy(TOPLEVEL *toplevel, OBJECT *o_current)
  * \param [in]     y2       y coordinate of second corner of box,
  */
 void
-geda_box_object_modify_all (TOPLEVEL *toplevel, OBJECT *object,
-                            int x1, int y1, int x2, int y2)
+geda_box_object_modify_all (OBJECT *object,
+                            int x1,
+                            int y1,
+                            int x2,
+                            int y2)
 {
-  o_emit_pre_change_notify (toplevel, object);
+  o_emit_pre_change_notify (object);
 
   object->box->lower_x = (x1 > x2) ? x1 : x2;
   object->box->lower_y = (y1 > y2) ? y2 : y1;
@@ -152,7 +155,7 @@ geda_box_object_modify_all (TOPLEVEL *toplevel, OBJECT *object,
   object->box->upper_x = (x1 > x2) ? x2 : x1;
   object->box->upper_y = (y1 > y2) ? y1 : y2;
 
-  o_emit_change_notify (toplevel, object);
+  o_emit_change_notify (object);
 }
 
 /*! \brief Modify a BOX OBJECT's coordinates.
@@ -164,7 +167,6 @@ geda_box_object_modify_all (TOPLEVEL *toplevel, OBJECT *object,
  *  The coordinates of the corner is modified in the world coordinate system.
  *  Screen coordinates and boundings are then updated.
  *
- *  \param [in]     toplevel  The TOPLEVEL object.
  *  \param [in,out] object     BOX OBJECT to be modified.
  *  \param [in]     x          x coordinate.
  *  \param [in]     y          y coordinate.
@@ -180,11 +182,14 @@ geda_box_object_modify_all (TOPLEVEL *toplevel, OBJECT *object,
  *  </DL>
  */
 void
-geda_box_object_modify (TOPLEVEL *toplevel, OBJECT *object, int x, int y, int whichone)
+geda_box_object_modify (OBJECT *object,
+                        int x,
+                        int y,
+                        int whichone)
 {
 	int tmp;
 
-	o_emit_pre_change_notify (toplevel, object);
+	o_emit_pre_change_notify (object);
 
 	/* change the position of the selected corner */
 	switch(whichone) {
@@ -225,7 +230,7 @@ geda_box_object_modify (TOPLEVEL *toplevel, OBJECT *object, int x, int y, int wh
 		object->box->lower_y = tmp;
 	}
 
-	o_emit_change_notify (toplevel, object);
+	o_emit_change_notify (object);
 
 }
 
@@ -241,14 +246,16 @@ geda_box_object_modify (TOPLEVEL *toplevel, OBJECT *object, int x, int y, int wh
  *    <DT>*</DT><DD>the file format used for the releases after 2000704.
  *  </DL>
  *
- *  \param [in]     toplevel       The TOPLEVEL object.
  *  \param [in]     buf             Character string with box description.
  *  \param [in]     release_ver     libgeda release version number.
  *  \param [in]     fileformat_ver  libgeda file format version number.
  *  \return The BOX OBJECT that was created, or NULL on error.
  */
-OBJECT *o_box_read (TOPLEVEL *toplevel, const char buf[],
-                    unsigned int release_ver, unsigned int fileformat_ver, GError **err)
+OBJECT*
+o_box_read (const char buf[],
+            unsigned int release_ver,
+            unsigned int fileformat_ver,
+            GError **err)
 {
   OBJECT *new_obj;
   char type;
@@ -338,17 +345,16 @@ OBJECT *o_box_read (TOPLEVEL *toplevel, const char buf[],
   d_y2 = y1;
 
   /* create a new box */
-  new_obj = geda_box_object_new (toplevel, type, color, d_x1, d_y1, d_x2, d_y2);
+  new_obj = geda_box_object_new (type, color, d_x1, d_y1, d_x2, d_y2);
   /* set its line options */
-  o_set_line_options (toplevel,
-                      new_obj,
+  o_set_line_options (new_obj,
                       (OBJECT_END) box_end,
                       (OBJECT_TYPE) box_type,
                       box_width,
                       box_length,
                       box_space);
   /* set its fill options */
-  o_set_fill_options (toplevel, new_obj,
+  o_set_fill_options (new_obj,
                       (OBJECT_FILLING) box_filling,
                       fill_width,
                       pitch1, angle1, pitch2, angle2);
@@ -454,15 +460,16 @@ geda_box_object_translate (GedaObject *object, int dx, int dy)
  *  <B>angle</B> degrees.
  *  The center of rotation is in world unit.
  *
- *  \param [in]      toplevel      The TOPLEVEL object.
  *  \param [in]      world_centerx  Rotation center x coordinate in WORLD units.
  *  \param [in]      world_centery  Rotation center y coordinate in WORLD units.
  *  \param [in]      angle          Rotation angle in degrees (See note below).
  *  \param [in,out]  object         BOX OBJECT to rotate.
  *
  */
-void geda_box_object_rotate (TOPLEVEL *toplevel,
-			int world_centerx, int world_centery, int angle,
+void
+geda_box_object_rotate (int world_centerx,
+                        int world_centery,
+                        int angle,
 			OBJECT *object)
 {
   int newx1, newy1;
@@ -522,13 +529,13 @@ void geda_box_object_rotate (TOPLEVEL *toplevel,
  *  The box is first translated to the origin, then mirrored and finally
  *  translated back at its previous position.
  *
- *  \param [in]     toplevel      The TOPLEVEL object.
  *  \param [in]     world_centerx  Origin x coordinate in WORLD units.
  *  \param [in]     world_centery  Origin y coordinate in WORLD units.
  *  \param [in,out] object         BOX OBJECT to mirror.
  */
-void geda_box_object_mirror (TOPLEVEL *toplevel,
-			int world_centerx, int world_centery,
+void
+geda_box_object_mirror (int world_centerx,
+                        int world_centery,
 			OBJECT *object)
 {
   int newx1, newy1;
@@ -569,7 +576,6 @@ void geda_box_object_mirror (TOPLEVEL *toplevel,
  *  parameters to the boundings of the box object described in <B>*box</B>
  *  in world units.
  *
- *  \param [in]  toplevel  The TOPLEVEL object.
  *  \param [in]  object     BOX OBJECT to read coordinates from.
  *  \param [out] left       Left box coordinate in WORLD units.
  *  \param [out] top        Top box coordinate in WORLD units.
@@ -577,8 +583,7 @@ void geda_box_object_mirror (TOPLEVEL *toplevel,
  *  \param [out] bottom     Bottom box coordinate in WORLD units.
  */
 void
-geda_box_object_calculate_bounds (TOPLEVEL *toplevel,
-                                  const OBJECT *object,
+geda_box_object_calculate_bounds (const OBJECT *object,
                                   GedaBounds *bounds)
 {
   gint expand;
@@ -627,17 +632,20 @@ geda_box_object_get_position (const GedaObject *object, gint *x, gint *y)
 /*! \brief Calculates the distance between the given point and the closest
  * point on the perimeter of the box.
  *
- *  \param [in] toplevel     The TOPLEVEL object.
- *  \param [in] object       The box OBJECT.
- *  \param [in] x            The x coordinate of the given point.
- *  \param [in] y            The y coordinate of the given point.
- *  \param [in] force_solid  If true, force treating the object as solid.
+ *  \param [in] object         The box OBJECT.
+ *  \param [in] x              The x coordinate of the given point.
+ *  \param [in] y              The y coordinate of the given point.
+ *  \param [in] force_solid    If true, force treating the object as solid.
+ *  \param [in] include_hidden Take hidden text into account.
  *  \return The shortest distance from the object to the point. With an
  *  invalid parameter, this function returns G_MAXDOUBLE.
  */
 double
-geda_box_object_shortest_distance (TOPLEVEL *toplevel, OBJECT *object,
-                                   int x, int y, int force_solid)
+geda_box_object_shortest_distance (OBJECT *object,
+                                   int x,
+                                   int y,
+                                   int force_solid,
+                                   gboolean include_hidden)
 {
   int solid;
 
