@@ -98,11 +98,15 @@ always_promote_attributes ()
   return attributes;
 }
 
+static gboolean placeholder_rendering = FALSE;
+
 
 /*! \brief Return the bounds of the given GList of objects.
  *  \par Given a list of objects, calcule the bounds coordinates.
- *  \param [in]  toplevel The TOPLEVEL structure.
+ *
  *  \param [in]  head   The list of objects to look the bounds for.
+ *  \param [in] include_hidden If bounds of hidden objects should
+ *                             be calculated.
  *  \param [out] left   pointer to the left coordinate of the object.
  *  \param [out] top    pointer to the top coordinate of the object.
  *  \param [out] right  pointer to the right coordinate of the object.
@@ -111,8 +115,13 @@ always_promote_attributes ()
  *  \retval 0 No bounds were found
  *  \retval 1 Bound was found
  */
-int world_get_object_glist_bounds(TOPLEVEL *toplevel, const GList *head,
-                                  int *left, int *top, int *right, int *bottom)
+int
+world_get_object_glist_bounds (const GList *head,
+                               gboolean include_hidden,
+                               int *left,
+                               int *top,
+                               int *right,
+                               int *bottom)
 {
   const GList *s_current=NULL;
   OBJECT *o_current=NULL;
@@ -128,7 +137,12 @@ int world_get_object_glist_bounds(TOPLEVEL *toplevel, const GList *head,
     /* Sanity check */
     g_return_val_if_fail ((o_current != NULL), found);
 
-    if ( geda_object_calculate_visible_bounds( toplevel, o_current, &rleft, &rtop, &rright, &rbottom) ) {
+    if (geda_object_calculate_visible_bounds (o_current,
+                                              include_hidden,
+                                              &rleft,
+                                              &rtop,
+                                              &rright,
+                                              &rbottom)) {
       if ( found ) {
         *left = MIN( *left, rleft );
         *top = MIN( *top, rtop );
@@ -151,13 +165,14 @@ int world_get_object_glist_bounds(TOPLEVEL *toplevel, const GList *head,
  *
  *  On failure, this function sets the bounds to empty.
  *
- *  \param [in] toplevel The toplevel object.
  *  \param [in] object The component object.
+ *  \param [in] include_hidden If bounds of hidden objects should
+ *                             be calculated.
  *  \param [out] bounds The bounds of the component object
  */
 void
-geda_component_object_calculate_bounds (TOPLEVEL *toplevel,
-                                        const OBJECT *object,
+geda_component_object_calculate_bounds (const OBJECT *object,
+                                        gboolean include_hidden,
                                         GedaBounds *bounds)
 {
   geda_bounds_init (bounds);
@@ -166,8 +181,8 @@ geda_component_object_calculate_bounds (TOPLEVEL *toplevel,
   g_return_if_fail (((object->type == OBJ_COMPONENT) || (object->type == OBJ_PLACEHOLDER)));
   g_return_if_fail (object->component != NULL);
 
-  world_get_object_glist_bounds (toplevel,
-                                 object->component->prim_objs,
+  world_get_object_glist_bounds (object->component->prim_objs,
+                                 include_hidden,
                                  &(bounds->min_x),
                                  &(bounds->min_y),
                                  &(bounds->max_x),
@@ -208,15 +223,13 @@ geda_component_object_get_position (const GedaObject *object, gint *x, gint *y)
  *  An attribute object is promotable if it's promoted by default, or the user
  *  has configered it to promote an attribute.
  *
- *  \param [in] toplevel  The TOPLEVEL object
  *  \param [in] object    The attribute object to check
  *  \return TRUE if the object is a eligible attribute, FALSE otherwise
  */
 static int
-o_component_is_eligible_attribute (TOPLEVEL *toplevel, OBJECT *object)
+o_component_is_eligible_attribute (OBJECT *object)
 {
   gboolean promote_invisible;
-  g_return_val_if_fail (toplevel, FALSE);
   g_return_val_if_fail (object, FALSE);
 
   cfg_read_bool ("schematic.attrib", "promote-invisible",
@@ -242,7 +255,7 @@ o_component_is_eligible_attribute (TOPLEVEL *toplevel, OBJECT *object)
   }
 
   /* object is invisible and we do not want to promote invisible text */
-  if ((!o_is_visible (toplevel, object)) &&
+  if ((!o_is_visible (object)) &&
       (promote_invisible == FALSE))
     return FALSE; /* attribute not eligible for promotion */
 
@@ -283,12 +296,13 @@ o_component_is_embedded (OBJECT *o_current)
  *  from the prim_objs of the component.  If detach is FALSE, the
  *  OBJECTs are left in place.
  *
- *  \param [in]  toplevel The toplevel environment.
  *  \param [in]  object   The component object being modified.
  *  \param [in]  detach   Should the attributes be detached?
  *  \returns              A linked list of OBJECTs to promote.
  */
-GList *o_component_get_promotable (TOPLEVEL *toplevel, OBJECT *object, int detach)
+GList*
+o_component_get_promotable (OBJECT *object,
+                            int detach)
 {
   GList *promoted = NULL;
   GList *attribs;
@@ -308,7 +322,7 @@ GList *o_component_get_promotable (TOPLEVEL *toplevel, OBJECT *object, int detac
     tmp = (OBJECT*) iter->data;
 
     /* Is it an attribute we want to promote? */
-    if (!o_component_is_eligible_attribute (toplevel, tmp))
+    if (!o_component_is_eligible_attribute (tmp))
       continue;
 
     if (detach) {
@@ -332,11 +346,11 @@ GList *o_component_get_promotable (TOPLEVEL *toplevel, OBJECT *object, int detac
  *  Selects promotable attributes from \a object, and returns a new
  *  #GList containing them (suitable for appending to a #PAGE).
  *
- *  \param [in]  toplevel The #TOPLEVEL environment.
  *  \param [in]  object   The component #OBJECT to promote from.
  *  \return A #GList of promoted attributes.
  */
-GList *o_component_promote_attribs (TOPLEVEL *toplevel, OBJECT *object)
+GList*
+o_component_promote_attribs (OBJECT *object)
 {
   GList *promoted = NULL;
   GList *promotable = NULL;
@@ -346,7 +360,7 @@ GList *o_component_promote_attribs (TOPLEVEL *toplevel, OBJECT *object)
   cfg_read_bool ("schematic.attrib", "keep-invisible",
                  default_keep_invisible, &keep_invisible);
 
-  promotable = o_component_get_promotable (toplevel, object, FALSE);
+  promotable = o_component_get_promotable (object, FALSE);
 
   /* Run through the attributes deciding if we want to keep them (in
    * which case we copy them and make them invisible) or if we want to
@@ -354,8 +368,8 @@ GList *o_component_promote_attribs (TOPLEVEL *toplevel, OBJECT *object)
   if (keep_invisible) {
     for (iter = promotable; iter != NULL; iter = g_list_next (iter)) {
       OBJECT *o_kept = (OBJECT *) iter->data;
-      OBJECT *o_copy = o_object_copy (toplevel, o_kept);
-      o_set_visibility (toplevel, o_kept, INVISIBLE);
+      OBJECT *o_copy = o_object_copy (o_kept);
+      o_set_visibility (o_kept, INVISIBLE);
       o_copy->parent = NULL;
       promoted = g_list_prepend (promoted, o_copy);
     }
@@ -372,7 +386,7 @@ GList *o_component_promote_attribs (TOPLEVEL *toplevel, OBJECT *object)
 
   /* Attach promoted attributes to the original component
      object. */
-  o_attrib_attach_list (toplevel, promoted, object, TRUE);
+  o_attrib_attach_list (promoted, object, TRUE);
 
   return promoted;
 }
@@ -391,15 +405,15 @@ GList *o_component_promote_attribs (TOPLEVEL *toplevel, OBJECT *object)
  *  true, attributes eligible for promotion are kept in memory but
  *  flagged as invisible.
  *
- *  \param [in]  toplevel The toplevel environment.
  *  \param [in]  object   The component object being altered.
  */
-static void o_component_remove_promotable_attribs (TOPLEVEL *toplevel, OBJECT *object)
+static void
+o_component_remove_promotable_attribs (OBJECT *object)
 {
   GList *promotable, *iter;
   gboolean keep_invisible;
 
-  promotable = o_component_get_promotable (toplevel, object, FALSE);
+  promotable = o_component_get_promotable (object, FALSE);
 
   if (promotable == NULL)
     return;
@@ -410,42 +424,149 @@ static void o_component_remove_promotable_attribs (TOPLEVEL *toplevel, OBJECT *o
   for (iter = promotable; iter != NULL; iter = g_list_next (iter)) {
     OBJECT *a_object = (OBJECT*) iter->data;
     if (keep_invisible == TRUE) {   /* Hide promotable attributes */
-      o_set_visibility (toplevel, a_object, INVISIBLE);
+      o_set_visibility (a_object, INVISIBLE);
     } else {                                /* Delete promotable attributes */
       object->component->prim_objs =
         g_list_remove (object->component->prim_objs, a_object);
-      s_delete_object (toplevel, a_object);
+      s_delete_object (a_object);
     }
   }
 
   g_list_free (promotable);
 }
 
-static void create_placeholder(TOPLEVEL * toplevel, OBJECT * new_node, int x, int y)
+/*! \brief Enable rendering of placeholders */
+void
+set_render_placeholders()
+{
+  placeholder_rendering = TRUE;
+}
+
+/*! \brief If placeholders have to be rendered
+ *  \return TRUE if placeholders have to be rendered, otherwise
+ *          FALSE
+ */
+static gboolean
+render_placeholders()
+{
+  return placeholder_rendering;
+}
+
+
+
+/*! \brief Create a placeholder symbol.
+ *
+ *  \par Function Description
+ *  Create a smaller placeholder which looks like this:
+ *
+ *     |
+ *     | missing-symbol.sym
+ *     |____________________
+ *    /
+ *   X
+ *
+ *  Do not call this function directly,
+ *  call create_placeholder() instead.
+ *
+ *  \param node  Placeholder object.
+ *  \param x     Placeholder's origin X.
+ *  \param y     Placeholder's origin Y.
+ *
+ */
+static void
+create_placeholder_small (OBJECT* node, int x, int y)
+{
+  const gint color = DETACHED_ATTRIBUTE_COLOR;
+  const gint text_size = 6;
+
+  /* two crossed lines to mark component's origin:
+  */
+  OBJECT* line1 = geda_line_object_new (color,
+                                        x - 30, y + 30,
+                                        x + 30, y - 30 );
+  OBJECT* line2 = geda_line_object_new (color,
+                                        x - 30, y - 30,
+                                        x + 50, y + 50 );
+
+  /* text - symbol file name:
+  */
+  OBJECT* txt = geda_text_object_new (color,
+                                      x + 100, y + 100,
+                                      LOWER_LEFT,
+                                      0,
+                                      node->component_basename,
+                                      text_size,
+                                      VISIBLE,
+                                      SHOW_NAME_VALUE);
+
+  GedaBounds bounds;
+  geda_text_object_calculate_bounds (txt, FALSE, &bounds);
+
+  bounds.max_x = geda_coord_snap (bounds.max_x, 100);
+  bounds.max_y = geda_coord_snap (bounds.max_y, 100);
+
+  /* two lines at the left and bottom sides of the text:
+  */
+  OBJECT* line3 = geda_line_object_new (color,
+                                        x + 50, y + 50,
+                                        x + 50, bounds.max_y + 10 );
+  OBJECT* line4 = geda_line_object_new (color,
+                                        x + 50, y + 50,
+                                        bounds.max_x + 10, y + 50 );
+
+  OBJECT* objs[] =
+  {
+      line1,
+      line2,
+      txt,
+      line3,
+      line4
+  };
+
+  for ( size_t i = 0; i < sizeof(objs) / sizeof(objs[0]); ++i )
+  {
+      node->component->prim_objs =
+        g_list_append (node->component->prim_objs, objs[i]);
+  }
+
+} /* create_placeholder_small() */
+
+
+
+/*! \brief Create a placeholder symbol.
+ *
+ *  \par Function Description
+ *  Create a placeholder which looks like this:
+ *
+ *          /\
+ *         /  \
+ *        / !  \
+ *       /______\
+ *    Component not found:
+ *     missing-symbol.sym
+ *   +
+ *
+ *  Do not call this function directly,
+ *  call create_placeholder() instead.
+ *
+ *  \param new_node  Placeholder object.
+ *  \param x         Placeholder's origin X.
+ *  \param y         Placeholder's origin Y.
+ *
+ */
+static void
+create_placeholder_classic (OBJECT *new_node, int x, int y)
 {
     GedaBounds bounds;
     OBJECT *new_prim_obj;
     char *not_found_text = NULL;
     int x_offset, y_offset;
 
-    /* Put placeholder into object list.  Changed by SDB on
-     * 1.19.2005 to fix problem that symbols were silently
-     * deleted by gattrib when RC files were messed up.  */
-    new_node->type = OBJ_PLACEHOLDER;
-
-    /* Some programs (e.g. netlister) don't need to render
-     * anything, so we just return here. */
-    if (!toplevel->rendered_text_bounds_func) {
-      return;
-    }
-
     /* Mark the origin of the missing component */
-    new_prim_obj = geda_line_object_new (toplevel,
-                                        DETACHED_ATTRIBUTE_COLOR,
-                                        x - 50, y, x + 50, y);
+    new_prim_obj = geda_line_object_new (DETACHED_ATTRIBUTE_COLOR,
+                                         x - 50, y, x + 50, y);
     new_node->component->prim_objs = g_list_prepend (new_node->component->prim_objs, new_prim_obj);
-    new_prim_obj = geda_line_object_new (toplevel,
-                                         DETACHED_ATTRIBUTE_COLOR,
+    new_prim_obj = geda_line_object_new (DETACHED_ATTRIBUTE_COLOR,
                                          x, y + 50, x, y - 50);
     new_node->component->prim_objs = g_list_prepend (new_node->component->prim_objs, new_prim_obj);
 
@@ -453,8 +574,7 @@ static void create_placeholder(TOPLEVEL * toplevel, OBJECT * new_node, int x, in
     not_found_text =
       g_strdup_printf (_("Component not found:\n %1$s"),
            new_node->component_basename);
-    new_prim_obj = geda_text_object_new (toplevel,
-                                         DETACHED_ATTRIBUTE_COLOR,
+    new_prim_obj = geda_text_object_new (DETACHED_ATTRIBUTE_COLOR,
                                          x + NOT_FOUND_TEXT_X,
                                          y + NOT_FOUND_TEXT_Y,
                                          LOWER_LEFT,
@@ -466,42 +586,38 @@ static void create_placeholder(TOPLEVEL * toplevel, OBJECT * new_node, int x, in
     g_free(not_found_text);
 
     /* figure out where to put the hazard triangle */
-    geda_text_object_calculate_bounds (toplevel,
-                                       new_prim_obj,
+    geda_text_object_calculate_bounds (new_prim_obj,
+                                       FALSE,
                                        &bounds);
     x_offset = (bounds.max_x - bounds.min_x) / 4;
     y_offset = bounds.max_y - bounds.min_y + 100;  /* 100 is just an additional offset */
 
     /* add hazard triangle */
-    new_prim_obj = geda_line_object_new (toplevel,
-                                         DETACHED_ATTRIBUTE_COLOR,
+    new_prim_obj = geda_line_object_new (DETACHED_ATTRIBUTE_COLOR,
                                          x + NOT_FOUND_TEXT_X + x_offset,
                                          y + NOT_FOUND_TEXT_Y + y_offset,
                                          x + NOT_FOUND_TEXT_X + x_offset + 600,
                                          y + NOT_FOUND_TEXT_Y + y_offset);
-    o_set_line_options(toplevel, new_prim_obj, END_ROUND, TYPE_SOLID,
-                       50, -1, -1);
+    o_set_line_options (new_prim_obj, END_ROUND, TYPE_SOLID,
+                        50, -1, -1);
     new_node->component->prim_objs = g_list_prepend (new_node->component->prim_objs, new_prim_obj);
-    new_prim_obj = geda_line_object_new (toplevel,
-                                         DETACHED_ATTRIBUTE_COLOR,
+    new_prim_obj = geda_line_object_new (DETACHED_ATTRIBUTE_COLOR,
                                          x + NOT_FOUND_TEXT_X + x_offset,
                                          y + NOT_FOUND_TEXT_Y + y_offset,
                                          x + NOT_FOUND_TEXT_X + x_offset + 300,
                                          y + NOT_FOUND_TEXT_Y + y_offset + 500);
-    o_set_line_options(toplevel, new_prim_obj, END_ROUND, TYPE_SOLID,
-                       50, -1, -1);
+    o_set_line_options (new_prim_obj, END_ROUND, TYPE_SOLID,
+                        50, -1, -1);
     new_node->component->prim_objs = g_list_prepend (new_node->component->prim_objs, new_prim_obj);
-    new_prim_obj = geda_line_object_new (toplevel,
-                                         DETACHED_ATTRIBUTE_COLOR,
+    new_prim_obj = geda_line_object_new (DETACHED_ATTRIBUTE_COLOR,
                                          x + NOT_FOUND_TEXT_X + x_offset + 300,
                                          y + NOT_FOUND_TEXT_Y + y_offset + 500,
                                          x + NOT_FOUND_TEXT_X + x_offset + 600,
                                          y + NOT_FOUND_TEXT_Y + y_offset);
-    o_set_line_options(toplevel, new_prim_obj, END_ROUND, TYPE_SOLID,
-                       50, -1, -1);
+    o_set_line_options (new_prim_obj, END_ROUND, TYPE_SOLID,
+                        50, -1, -1);
     new_node->component->prim_objs = g_list_prepend (new_node->component->prim_objs, new_prim_obj);
-    new_prim_obj = geda_text_object_new (toplevel,
-                                         DETACHED_ATTRIBUTE_COLOR,
+    new_prim_obj = geda_text_object_new (DETACHED_ATTRIBUTE_COLOR,
                                          x + NOT_FOUND_TEXT_X + x_offset + 270,
                                          y + NOT_FOUND_TEXT_Y + y_offset + 90,
                                          LOWER_LEFT,
@@ -512,14 +628,62 @@ static void create_placeholder(TOPLEVEL * toplevel, OBJECT * new_node, int x, in
                                          SHOW_NAME_VALUE);
     new_node->component->prim_objs = g_list_prepend (new_node->component->prim_objs, new_prim_obj);
     new_node->component->prim_objs = g_list_reverse(new_node->component->prim_objs);
-}
+
+} /* create_placeholder_classic() */
+
+
+
+/*! \brief Create a placeholder symbol.
+ *
+ *  \par Function Description
+ *  Create a placeholder to be used in place of missing symbol.
+ *  Depending on value of the schematic.gui::small-placeholders
+ *  configuration key, draw either alternative, smaller
+ *  placeholder (true) or the original one (false).
+ *
+ *  \param node  Placeholder object.
+ *  \param x     Placeholder's origin X.
+ *  \param y     Placeholder's origin Y.
+ *
+ */
+static void
+create_placeholder (OBJECT* node, int x, int y)
+{
+    /* Put placeholder into object list.  Changed by SDB on
+     * 1.19.2005 to fix problem that symbols were silently
+     * deleted by gattrib when RC files were messed up.  */
+    node->type = OBJ_PLACEHOLDER;
+
+    /* Some programs (e.g. netlister) don't need to render
+     * anything, so we just return here. */
+    if (!render_placeholders())
+    {
+      return;
+    }
+
+    gboolean small_placeholders = TRUE;
+    cfg_read_bool ("schematic.gui", "small-placeholders",
+                   TRUE, &small_placeholders);
+
+    if (small_placeholders)
+    {
+      create_placeholder_small (node, x, y);
+    }
+    else
+    {
+      create_placeholder_classic (node, x, y);
+    }
+
+} /* create_placeholder() */
+
+
 
 /* Done */
 /*! \brief
  *  \par Function Description
  *
  */
-OBJECT *o_component_new (TOPLEVEL *toplevel,
+OBJECT *o_component_new (PAGE *page,
                          char type,
                          int color, int x, int y, int angle,
                          int mirror, const CLibSymbol *clib,
@@ -556,23 +720,24 @@ OBJECT *o_component_new (TOPLEVEL *toplevel,
   }
 
   if (clib == NULL || buffer == NULL)
-    create_placeholder(toplevel, new_node, x, y);
+    create_placeholder (new_node, x, y);
   else {
     GError * err = NULL;
 
     /* add connections till translated */
-    new_node->component->prim_objs = o_read_buffer (toplevel, NULL, buffer, -1, new_node->component_basename, &err);
+    new_node->component->prim_objs =
+      o_read_buffer (page, NULL, buffer, -1, new_node->component_basename, &err);
     if (err) {
       g_error_free(err);
       /* If reading fails, replace with placeholder object */
-      create_placeholder(toplevel, new_node, x, y);
+      create_placeholder (new_node, x, y);
     }
     else {
       if (mirror) {
-        geda_object_list_mirror (new_node->component->prim_objs, 0, 0, toplevel);
+        geda_object_list_mirror (new_node->component->prim_objs, 0, 0);
       }
 
-      geda_object_list_rotate (new_node->component->prim_objs, 0, 0, angle, toplevel);
+      geda_object_list_rotate (new_node->component->prim_objs, 0, 0, angle);
       geda_object_list_translate (new_node->component->prim_objs, x, y);
     }
 
@@ -593,7 +758,6 @@ OBJECT *o_component_new (TOPLEVEL *toplevel,
  *  \par Function Description
  *  This function creates a new embedded object.
  *
- *  \param [in]  toplevel  The TOPLEVEL object
  *  \param [in]  type      The type of the object (usually OBJ_COMLEX)
  *  \param [in]  color     The color of the object
  *  \param [in]  x         The x location of the component object
@@ -604,9 +768,15 @@ OBJECT *o_component_new (TOPLEVEL *toplevel,
  *  \param [in]  selectable whether the object can be selected with the mouse
  *  \return a new component object
  */
-OBJECT *o_component_new_embedded (TOPLEVEL *toplevel,
-                                  char type, int color, int x, int y, int angle, int mirror,
-                                  const gchar *basename, int selectable)
+OBJECT*
+o_component_new_embedded (char type,
+                          int color,
+                          int x,
+                          int y,
+                          int angle,
+                          int mirror,
+                          const gchar *basename,
+                          int selectable)
 {
   OBJECT *new_node=NULL;
 
@@ -639,15 +809,17 @@ OBJECT *o_component_new_embedded (TOPLEVEL *toplevel,
  *  If the component object was read successfully, a new object is
  *  allocated and appended to the \a object_list.
  *
- *  \param [in] toplevel     The TOPLEVEL object
+ *  \param [in] page         The PAGE object
  *  \param [in] buf          a text buffer (usually a line of a schematic file)
  *  \param [in] release_ver  The release number gEDA
  *  \param [in] fileformat_ver a integer value of the file format
  *  \return The object list, or NULL on error.
  */
-OBJECT *o_component_read (TOPLEVEL *toplevel,
-                          const char buf[], unsigned int release_ver,
-                          unsigned int fileformat_ver, GError **err)
+OBJECT *o_component_read (PAGE *page,
+                          const char buf[],
+                          unsigned int release_ver,
+                          unsigned int fileformat_ver,
+                          GError **err)
 {
   OBJECT *new_obj;
   char type;
@@ -662,6 +834,7 @@ OBJECT *o_component_read (TOPLEVEL *toplevel,
   if (sscanf(buf, "%c %d %d %d %d %d %s\n",
 	     &type, &x1, &y1, &selectable, &angle, &mirror, basename) != 7) {
     g_set_error(err, EDA_ERROR, EDA_ERROR_PARSE, _("Failed to parse component object"));
+    g_free (basename);
     return NULL;
   }
 
@@ -697,15 +870,19 @@ OBJECT *o_component_read (TOPLEVEL *toplevel,
   }
   if (strncmp(basename, "EMBEDDED", 8) == 0) {
 
-    new_obj = o_component_new_embedded (toplevel, type,
-                                        DEFAULT_COLOR, x1, y1, angle, mirror,
+    new_obj = o_component_new_embedded (type,
+                                        DEFAULT_COLOR,
+                                        x1,
+                                        y1,
+                                        angle,
+                                        mirror,
                                         basename + 8,
                                         selectable);
   } else {
 
     const CLibSymbol *clib = s_clib_get_symbol_by_name (basename);
 
-    new_obj = o_component_new (toplevel, type,
+    new_obj = o_component_new (page, type,
                                DEFAULT_COLOR,
                                x1, y1,
                                angle, mirror, clib,
@@ -713,7 +890,7 @@ OBJECT *o_component_read (TOPLEVEL *toplevel,
     /* Delete or hide attributes eligible for promotion inside the
        component. */
     if (new_obj)
-      o_component_remove_promotable_attribs (toplevel, new_obj);
+      o_component_remove_promotable_attribs (new_obj);
   }
 
   g_free (basename);
@@ -789,11 +966,11 @@ geda_component_object_translate (GedaObject *object, int dx, int dy)
  *  This function creates a copy of the component object \a
  *  o_current.
  *
- *  \param [in] toplevel     The TOPLEVEL object
  *  \param [in] o_current    The object that is copied
  *  \return a new component object
  */
-OBJECT *o_component_copy(TOPLEVEL *toplevel, OBJECT *o_current)
+OBJECT*
+o_component_copy (OBJECT *o_current)
 {
   OBJECT *o_new;
   GList *iter;
@@ -814,7 +991,7 @@ OBJECT *o_component_copy(TOPLEVEL *toplevel, OBJECT *o_current)
 
   /* Copy contents and set the parent pointers on the copied objects. */
   o_new->component->prim_objs =
-    o_glist_copy_all (toplevel, o_current->component->prim_objs,
+    o_glist_copy_all (o_current->component->prim_objs,
                       NULL);
 
   for (iter = o_new->component->prim_objs;
@@ -825,9 +1002,9 @@ OBJECT *o_component_copy(TOPLEVEL *toplevel, OBJECT *o_current)
 
   /* Delete or hide attributes eligible for promotion inside the
      component. */
-  o_component_remove_promotable_attribs (toplevel, o_new);
+  o_component_remove_promotable_attribs (o_new);
 
-  s_slot_update_object (toplevel, o_new);
+  s_slot_update_object (o_new);
 
   /* deal with stuff that has changed */
 
@@ -845,16 +1022,16 @@ OBJECT *o_component_copy(TOPLEVEL *toplevel, OBJECT *o_current)
  *  (\a centerx,\a centery) point by \a angle degrees.
  *  The center of rotation is in world units.
  *
- *  \param [in]      toplevel  The toplevel environment.
  *  \param [in]      centerx   X coordinate of rotation center (world coords).
  *  \param [in]      centery   Y coordinate of rotation center (world coords).
  *  \param [in]      angle     Rotation angle in degrees.
  *  \param [in,out]  object    Component object to rotate.
  */
 void
-geda_component_object_rotate (TOPLEVEL *toplevel,
-                              int centerx, int centery,
-                              int angle, OBJECT *object)
+geda_component_object_rotate (int centerx,
+                              int centery,
+                              int angle,
+                              OBJECT *object)
 {
   int x, y;
   int newx, newy;
@@ -873,7 +1050,7 @@ geda_component_object_rotate (TOPLEVEL *toplevel,
 
   geda_component_object_translate (object, -object->component->x, -object->component->y);
 
-  geda_object_list_rotate (object->component->prim_objs, 0, 0, angle, toplevel);
+  geda_object_list_rotate (object->component->prim_objs, 0, 0, angle);
 
   object->component->x = 0;
   object->component->y = 0;
@@ -890,8 +1067,8 @@ geda_component_object_rotate (TOPLEVEL *toplevel,
  *
  */
 void
-geda_component_object_mirror (TOPLEVEL *toplevel,
-                              int world_centerx, int world_centery,
+geda_component_object_mirror (int world_centerx,
+                              int world_centery,
                               OBJECT *object)
 {
   int x, y;
@@ -906,7 +1083,7 @@ geda_component_object_mirror (TOPLEVEL *toplevel,
 
   geda_component_object_translate (object, -object->component->x, -object->component->y);
 
-  geda_object_list_mirror (object->component->prim_objs, 0, 0, toplevel);
+  geda_object_list_mirror (object->component->prim_objs, 0, 0);
 
   switch(object->component->angle) {
     case(90):
@@ -972,15 +1149,15 @@ o_component_find_pin_by_attribute (OBJECT *object,
  *  \par Function Description
  *  This function compares the symversion of a symbol with it's
  *  earlier saved symversion in a schematic.
- *  Major symversion changes are added to the toplevel object
- *  (toplevel->major_changed_refdes), minor changes are reported
+ *  Major symversion changes are added to the page object
+ *  (page->major_changed_refdes), minor changes are reported
  *  to the messaging system.
  *
- *  \param toplevel  The TOPLEVEL object
+ *  \param page      The PAGE object
  *  \param object    The component OBJECT
  */
 void
-o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
+o_component_check_symversion (PAGE* page, OBJECT* object)
 {
   char *inside = NULL;
   char *outside = NULL;
@@ -998,6 +1175,17 @@ o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
 		     object->type == OBJ_PLACEHOLDER));
   g_return_if_fail (object->component != NULL);
 
+
+  /* No need to check symversion if symbol is not found in libraries:
+  */
+  GList* symlist = s_clib_search (object->component_basename, CLIB_EXACT);
+  if (symlist == NULL)
+  {
+    return;
+  }
+  g_list_free (symlist);
+
+
   /* first look on the inside for the symversion= attribute */
   inside = o_attrib_search_inherited_attribs_by_name (object, "symversion", 0);
 
@@ -1008,7 +1196,7 @@ o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
   refdes = o_attrib_search_object_attribs_by_name(object, "refdes", 0);
   if (!refdes)
   {
-    refdes = g_strdup ("unknown");
+    refdes = g_strdup ("no refdes");
   }
 
   if (inside)
@@ -1018,12 +1206,15 @@ o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
     {
       if (inside)
       {
-        s_log_message(_("WARNING: Symbol version parse error on refdes %1$s:\n"
-                        "\tCould not parse symbol file symversion=%2$s"),
-                      refdes, inside);
+        s_log_message(_("WARNING: %s (%s): could not parse "
+                        "symversion (%s) in symbol file"),
+                      object->component_basename,
+                      refdes,
+                      inside);
       } else {
-        s_log_message(_("WARNING: Symbol version parse error on refdes %1$s:\n"
-                        "\tCould not parse symbol file symversion="),
+        s_log_message(_("WARNING: %s (%s): could not parse "
+                        "symversion in symbol file"),
+                      object->component_basename,
                       refdes);
       }
       goto done;
@@ -1038,9 +1229,11 @@ o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
     outside_value = strtod(outside, &err_check);
     if (outside_value == 0 && outside == err_check)
     {
-      s_log_message(_("WARNING: Symbol version parse error on refdes %1$s:\n"
-                      "\tCould not parse attached symversion=%2$s"),
-                    refdes, outside);
+      s_log_message(_("WARNING: %s (%s): could not parse "
+                      "attached symversion (%s)"),
+                    object->component_basename,
+                    refdes,
+                    outside);
       goto done;
     }
     outside_present = TRUE;
@@ -1063,10 +1256,10 @@ o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
   /* No symversion inside, but a version is outside, this is a weird case */
   if (!inside_present && outside_present)
   {
-    s_log_message(_("WARNING: Symbol version oddity on refdes %1$s:\n"
-                    "\tsymversion=%2$s attached to instantiated symbol, "
-                    "but no symversion= inside symbol file."),
-                  refdes, outside);
+    s_log_message(_("WARNING: %s (%s): symversion attached, "
+                    "but absent inside symbol file"),
+                  object->component_basename,
+                  refdes);
     goto done;
   }
 
@@ -1077,11 +1270,6 @@ o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
       ((inside_present && outside_present) && (inside_value > outside_value)))
   {
 
-    s_log_message(_("WARNING: Symbol version mismatch on refdes %1$s (%2$s):\n"
-                    "\tSymbol in library is newer than "
-                    "instantiated symbol."),
-                  refdes, object->component_basename);
-
     /* break up the version values into major.minor numbers */
     inside_major = floor(inside_value);
     inside_minor = inside_value - inside_major;
@@ -1105,17 +1293,36 @@ o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
     if (inside_major > outside_major)
     {
       char* refdes_copy;
-      s_log_message(_("\tMAJOR VERSION CHANGE (file %1$.3f, "
-                      "instantiated %2$.3f, %3$s)!"),
-                    inside_value, outside_value, refdes);
 
-      /* add the refdes to the major_changed_refdes GList */
-      /* make sure refdes_copy is freed somewhere */
-      refdes_copy = g_strconcat (refdes, " (",
-                                 object->component_basename,
-                                 ")", NULL);
-      toplevel->major_changed_refdes =
-        g_list_append(toplevel->major_changed_refdes, refdes_copy);
+      s_log_message(_("WARNING: %s (%s): MAJOR symversion change "
+                      "(attached: %.3f < library: %.3f)"),
+                    object->component_basename,
+                    refdes,
+                    outside_value,
+                    inside_value);
+
+      /* add the refdes and basename to the page's major_changed_refdes GList:
+      */
+      if (page != NULL)
+      {
+        /* make sure refdes_copy is freed somewhere:
+        */
+        refdes_copy = g_strconcat ("refdes: ",
+                                   refdes,
+                                   " (",
+                                   object->component_basename,
+                                   ")",
+                                   NULL);
+
+        page->major_changed_refdes =
+          g_list_append (page->major_changed_refdes,
+                         refdes_copy);
+      }
+      else
+      {
+        g_warning (" >> o_complex_check_symversion(): !page_current");
+      }
+
 
       /* don't bother checking minor changes if there are major ones*/
       goto done;
@@ -1123,9 +1330,12 @@ o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
 
     if (inside_minor > outside_minor)
     {
-      s_log_message(_("\tMinor version change (file %1$.3f, "
-                      "instantiated %2$.3f)"),
-                    inside_value, outside_value);
+      s_log_message(_("WARNING: %s (%s): minor symversion change "
+                      "(attached: %.3f < library: %.3f)"),
+                    object->component_basename,
+                    refdes,
+                    outside_value,
+                    inside_value);
     }
 
     goto done;
@@ -1134,10 +1344,12 @@ o_component_check_symversion (TOPLEVEL* toplevel, OBJECT* object)
   /* outside value is greater than inside value, this is weird case */
   if ((inside_present && outside_present) && (outside_value > inside_value))
   {
-    s_log_message(_("WARNING: Symbol version oddity on refdes %1$s:\n"
-                    "\tInstantiated symbol is newer than "
-                    "symbol in library."),
-                  refdes);
+    s_log_message(_("WARNING: %s (%s): symbol is newer "
+                    "than symbol in library (%.3f > %.3f)"),
+                  object->component_basename,
+                  refdes,
+                  outside_value,
+                  inside_value);
     goto done;
   }
 
@@ -1156,19 +1368,22 @@ done:
  *        force treating them as solid filled.
  *        We ignore the force_solid argument to this function.
  *
- *  \param [in] toplevel     The TOPLEVEL object.
- *  \param [in] object       The component OBJECT.
- *  \param [in] x            The x coordinate of the given point.
- *  \param [in] y            The y coordinate of the given point.
- *  \param [in] force_solid  If true, force treating the object as solid.
+ *  \param [in] object         The component OBJECT.
+ *  \param [in] x              The x coordinate of the given point.
+ *  \param [in] y              The y coordinate of the given point.
+ *  \param [in] force_solid    If true, force treating the object as solid.
+ *  \param [in] include_hidden Take hidden text into account.
  *  \return The shortest distance from the object to the point. If the
  *  distance cannot be calculated, this function returns a really large
  *  number (G_MAXDOUBLE).  With an invalid parameter, this function returns
  *  G_MAXDOUBLE.
  */
 double
-geda_component_object_shortest_distance (TOPLEVEL *toplevel, OBJECT *object,
-                                         int x, int y, int force_solid)
+geda_component_object_shortest_distance (OBJECT *object,
+                                         int x,
+                                         int y,
+                                         int force_solid,
+                                         gboolean include_hidden)
 {
   double shortest_distance = G_MAXDOUBLE;
   double distance;
@@ -1185,8 +1400,12 @@ geda_component_object_shortest_distance (TOPLEVEL *toplevel, OBJECT *object,
 
     /* Collect the bounds of any lines and arcs in the symbol */
     if ((obj->type == OBJ_LINE || obj->type == OBJ_ARC) &&
-        geda_object_calculate_visible_bounds(toplevel, obj,
-                                       &left, &top, &right, &bottom)) {
+        geda_object_calculate_visible_bounds (obj,
+                                              include_hidden,
+                                              &left,
+                                              &top,
+                                              &right,
+                                              &bottom)) {
       if (found_line_bounds) {
         line_bounds.lower_x = MIN (line_bounds.lower_x, left);
         line_bounds.lower_y = MIN (line_bounds.lower_y, top);
@@ -1200,7 +1419,7 @@ geda_component_object_shortest_distance (TOPLEVEL *toplevel, OBJECT *object,
         found_line_bounds = 1;
       }
     } else {
-      distance = geda_object_shortest_distance_full (toplevel, obj, x, y, TRUE);
+      distance = geda_object_shortest_distance_full (obj, x, y, TRUE, include_hidden);
       shortest_distance = MIN (shortest_distance, distance);
     }
 
