@@ -158,63 +158,61 @@ s_basic_new_object (int type, char const *prefix)
  *  look at above.. this returns what was passed in!!!!
  *  copies selected to list_head (!! returns new list)
  *
- *  \param [in]  toplevel   The TOPLEVEL object.
  *  \param [in]  selected
  *  \return OBJECT pointer.
  */
-OBJECT *o_object_copy (TOPLEVEL *toplevel,
-                       OBJECT *selected)
+OBJECT*
+o_object_copy (OBJECT *selected)
 {
   OBJECT *new_obj;
 
-  g_return_val_if_fail (toplevel != NULL, NULL);
   g_return_val_if_fail (selected != NULL, NULL);
 
   switch(selected->type) {
 
     case(OBJ_LINE):
-      new_obj = geda_line_object_copy (toplevel, selected);
+      new_obj = geda_line_object_copy (selected);
       break;
 
     case(OBJ_NET):
-      new_obj = geda_net_object_copy (toplevel, selected);
+      new_obj = geda_net_object_copy (selected);
       break;
 
     case(OBJ_BUS):
-      new_obj = geda_bus_object_copy (toplevel, selected);
+      new_obj = geda_bus_object_copy (selected);
       break;
 
     case(OBJ_BOX):
-      new_obj = geda_box_object_copy (toplevel, selected);
+      new_obj = geda_box_object_copy (selected);
       break;
 
     case(OBJ_PICTURE):
-      new_obj = o_picture_copy (toplevel, selected);
+      new_obj = o_picture_copy (selected);
       break;
 
     case(OBJ_CIRCLE):
-      new_obj = geda_circle_object_copy (toplevel, selected);
+      new_obj = geda_circle_object_copy (selected);
       break;
 
     case(OBJ_COMPONENT):
     case(OBJ_PLACEHOLDER):
-      new_obj = o_component_copy (toplevel, selected);
+      new_obj = o_component_copy (selected);
       break;
 
     case(OBJ_TEXT):
-      new_obj = geda_text_object_copy (toplevel, selected);
+      new_obj = geda_text_object_copy (selected);
       break;
 
     case(OBJ_PATH):
-      new_obj = geda_path_object_copy (toplevel, selected);
+      new_obj = geda_path_object_copy (selected);
       break;
 
     case(OBJ_PIN):
-      new_obj = geda_pin_object_copy (toplevel, selected);
+      new_obj = geda_pin_object_copy (selected);
       break;
 
     case(OBJ_ARC):
-      new_obj = geda_arc_object_copy (toplevel, selected);
+      new_obj = geda_arc_object_copy (selected);
       break;
 
     default:
@@ -241,19 +239,19 @@ OBJECT *o_object_copy (TOPLEVEL *toplevel,
  *
  */
 void
-s_delete_object(TOPLEVEL *toplevel, OBJECT *o_current)
+s_delete_object (OBJECT *o_current)
 {
   if (o_current != NULL) {
     /* If currently attached to a page, remove it from the page */
     if (o_current->page != NULL) {
-      s_page_remove (toplevel, o_current->page, o_current);
+      s_page_remove (o_current->page, o_current);
     }
 
-    s_conn_remove_object_connections (toplevel, o_current);
+    s_conn_remove_object_connections (o_current);
 
     if (o_current->attached_to != NULL) {
       /* do the actual remove */
-      o_attrib_remove(toplevel, &o_current->attached_to->attribs, o_current);
+      o_attrib_remove (&o_current->attached_to->attribs, o_current);
     }
 
     /* printf("sdeleting line\n"); */
@@ -301,7 +299,7 @@ s_delete_object(TOPLEVEL *toplevel, OBJECT *o_current)
 
       if (o_current->component->prim_objs) {
         /* printf("sdeleting component's primitive objects\n");*/
-        geda_object_list_delete (toplevel, o_current->component->prim_objs);
+        geda_object_list_delete (o_current->component->prim_objs);
         o_current->component->prim_objs = NULL;
       }
 
@@ -309,7 +307,7 @@ s_delete_object(TOPLEVEL *toplevel, OBJECT *o_current)
       o_current->component = NULL;
     }
 
-    o_attrib_detach_all (toplevel, o_current);
+    o_attrib_detach_all (o_current);
 
     o_current->weak_refs = s_weakref_notify (o_current, o_current->weak_refs);
 
@@ -404,7 +402,6 @@ s_object_remove_weak_ptr (OBJECT *object,
  *  See #OBJECT_END and #OBJECT_TYPE for information on valid
  *  object end and type values.
  *
- *  \param [in]     toplevel  The TOPLEVEL object.
  *  \param [in,out] o_current  OBJECT to set line options on.
  *  \param [in]     end        An OBJECT_END.
  *  \param [in]     type       An OBJECT_TYPE.
@@ -415,9 +412,13 @@ s_object_remove_weak_ptr (OBJECT *object,
  *  \todo Make space an unsigned int and check for a max value instead.
  *        If a max value is not required, then it would simplify the code.
  */
-void o_set_line_options(TOPLEVEL *toplevel, OBJECT *o_current,
-			OBJECT_END end, OBJECT_TYPE type,
-			int width, int length, int space)
+void
+o_set_line_options (OBJECT *o_current,
+                    OBJECT_END end,
+                    OBJECT_TYPE type,
+                    int width,
+                    int length,
+                    int space)
 {
   g_return_if_fail (o_current != NULL);
 
@@ -448,7 +449,7 @@ void o_set_line_options(TOPLEVEL *toplevel, OBJECT *o_current,
     break;
   }
 
-  o_emit_pre_change_notify (toplevel, o_current);
+  o_emit_pre_change_notify (o_current);
 
   o_current->line_width = width;
   o_current->line_end   = end;
@@ -457,7 +458,7 @@ void o_set_line_options(TOPLEVEL *toplevel, OBJECT *o_current,
   o_current->line_length = length;
   o_current->line_space  = space;
 
-  o_emit_change_notify (toplevel, o_current);
+  o_emit_change_notify (o_current);
 
 }
 
@@ -501,7 +502,6 @@ gboolean o_get_line_options(OBJECT *object,
  *  This function allows an #OBJECT's fill options to be configured.
  *  See #OBJECT_FILLING for information on valid fill types.
  *
- *  \param [in]      toplevel  The TOPLEVEL object.
  *  \param [in,out]  o_current  OBJECT to be updated.
  *  \param [in]      type       OBJECT_FILLING type.
  *  \param [in]      width      fill width.
@@ -511,10 +511,14 @@ gboolean o_get_line_options(OBJECT *object,
  *  \param [in]      angle2     cross hatch angle
  *
  */
-void o_set_fill_options(TOPLEVEL *toplevel, OBJECT *o_current,
-			OBJECT_FILLING type, int width,
-			int pitch1, int angle1,
-			int pitch2, int angle2)
+void
+o_set_fill_options (OBJECT *o_current,
+                    OBJECT_FILLING type,
+                    int width,
+                    int pitch1,
+                    int angle1,
+                    int pitch2,
+                    int angle2)
 {
   if(o_current == NULL) {
     return;
@@ -549,7 +553,7 @@ void o_set_fill_options(TOPLEVEL *toplevel, OBJECT *o_current,
     pitch2 = -1;
   }
 
-  o_emit_pre_change_notify (toplevel, o_current);
+  o_emit_pre_change_notify (o_current);
 
   o_current->fill_type = type;
   o_current->fill_width = width;
@@ -560,7 +564,7 @@ void o_set_fill_options(TOPLEVEL *toplevel, OBJECT *o_current,
   o_current->fill_pitch2 = pitch2;
   o_current->fill_angle2 = angle2;
 
-  o_emit_change_notify (toplevel, o_current);
+  o_emit_change_notify (o_current);
 }
 
 /*! \brief get #OBJECT's fill properties.
@@ -602,7 +606,6 @@ gboolean o_get_fill_options(OBJECT *object,
  *  \par Function Description
  *  This function gets the position of an object in world coordinates.
  *
- *  \param [in] toplevel The toplevel environment.
  *  \param [out] x       pointer to the x-position
  *  \param [out] y       pointer to the y-position
  *  \param [in] object   The object to get the position.
@@ -685,15 +688,18 @@ geda_object_translate (GedaObject *object, gint dx, gint dy)
  *  This function rotates the object <B>object</B> about the coordinates
  *  <B>world_centerx</B> and <B>world_centery</B>, by <B>angle</B>degrees.
  *
- *  \param [in] toplevel The toplevel environment.
  *  \param [in] world_centerx  X coordinate of rotation center (world coords)
  *  \param [in] world_centery  Y coordinate of rotation center (world coords)
  *  \param [in] angle          Angle of rotation (degrees)
  *  \param [in] object         The object to rotate.
  */
-void geda_object_rotate (TOPLEVEL *toplevel, int world_centerx, int world_centery, int angle, OBJECT *object)
+void
+geda_object_rotate (int world_centerx,
+                    int world_centery,
+                    int angle,
+                    OBJECT *object)
 {
-  void (*func) (TOPLEVEL*, int, int, int, OBJECT*) = NULL;
+  void (*func) (int, int, int, OBJECT*) = NULL;
 
   switch (object->type) {
       case OBJ_LINE:    func = geda_line_object_rotate;    break;
@@ -715,7 +721,7 @@ void geda_object_rotate (TOPLEVEL *toplevel, int world_centerx, int world_center
   }
 
   if (func != NULL) {
-    (*func) (toplevel, world_centerx, world_centery, angle, object);
+    (*func) (world_centerx, world_centery, angle, object);
   }
 }
 
@@ -725,14 +731,16 @@ void geda_object_rotate (TOPLEVEL *toplevel, int world_centerx, int world_center
  *  This function mirrors an object about the point
  *  (<B>world_centerx</B>,<B>world_centery</B>) in world units.
  *
- *  \param [in]     toplevel       The TOPLEVEL object.
  *  \param [in]     world_centerx  Origin x coordinate in WORLD units.
  *  \param [in]     world_centery  Origin y coordinate in WORLD units.
  *  \param [in,out] object         The OBJECT to mirror.
  */
-void geda_object_mirror (TOPLEVEL *toplevel, int world_centerx, int world_centery, OBJECT *object)
+void
+geda_object_mirror (int world_centerx,
+                    int world_centery,
+                    OBJECT *object)
 {
-  void (*func) (TOPLEVEL*, int, int, OBJECT*) = NULL;
+  void (*func) (int, int, OBJECT*) = NULL;
 
   switch (object->type) {
       case OBJ_LINE:    func = geda_line_object_mirror;    break;
@@ -754,7 +762,7 @@ void geda_object_mirror (TOPLEVEL *toplevel, int world_centerx, int world_center
   }
 
   if (func != NULL) {
-    (*func) (toplevel, world_centerx, world_centery, object);
+    (*func) (world_centerx, world_centery, object);
   }
 }
 
@@ -762,40 +770,43 @@ void geda_object_mirror (TOPLEVEL *toplevel, int world_centerx, int world_center
 /*! \brief Calculates the distance between the given point and the closest
  * point on the given object.
  *
- *  \param [in] toplevel     The TOPLEVEL object.
- *  \param [in] object       The given object.
- *  \param [in] x            The x coordinate of the given point.
- *  \param [in] y            The y coordinate of the given point.
+ *  \param [in] object         The given object.
+ *  \param [in] x              The x coordinate of the given point.
+ *  \param [in] y              The y coordinate of the given point.
+ *  \param [in] include_hidden Take hidden text into account.
  *  \return The shortest distance from the object to the point. If the
  *  distance cannot be calculated, this function returns a really large
  *  number (G_MAXDOUBLE).  If an error occurs, this function returns
  *  G_MAXDOUBLE.
  */
 double
-geda_object_shortest_distance (TOPLEVEL *toplevel, OBJECT *object, int x, int y)
+geda_object_shortest_distance (OBJECT *object, int x, int y, gboolean include_hidden)
 {
-  return geda_object_shortest_distance_full (toplevel, object, x, y, FALSE);
+  return geda_object_shortest_distance_full (object, x, y, FALSE, include_hidden);
 }
 
 /*! \brief Calculates the distance between the given point and the closest
  * point on the given object. Allows forcing objects to solid.
  *
- *  \param [in] toplevel     The TOPLEVEL object.
- *  \param [in] object       The given object.
- *  \param [in] x            The x coordinate of the given point.
- *  \param [in] y            The y coordinate of the given point.
- *  \param [in] force_solid  If true, force treating the object as solid.
+ *  \param [in] object         The given object.
+ *  \param [in] x              The x coordinate of the given point.
+ *  \param [in] y              The y coordinate of the given point.
+ *  \param [in] force_solid    If true, force treating the object as solid.
+ *  \param [in] include_hidden Take hidden text into account.
  *  \return The shortest distance from the object to the point. If the
  *  distance cannot be calculated, this function returns a really large
  *  number (G_MAXDOUBLE).  If an error occurs, this function returns
  *  G_MAXDOUBLE.
  */
 double
-geda_object_shortest_distance_full (TOPLEVEL *toplevel, OBJECT *object,
-                                    int x, int y, int force_solid)
+geda_object_shortest_distance_full (OBJECT *object,
+                                    int x,
+                                    int y,
+                                    int force_solid,
+                                    gboolean include_hidden)
 {
   double shortest_distance = G_MAXDOUBLE;
-  double (*func) (TOPLEVEL *, OBJECT *, int, int, int) = NULL;
+  double (*func) (OBJECT *, int, int, int, gboolean) = NULL;
 
   g_return_val_if_fail (object != NULL, G_MAXDOUBLE);
 
@@ -818,7 +829,7 @@ geda_object_shortest_distance_full (TOPLEVEL *toplevel, OBJECT *object,
   }
 
   if (func != NULL) {
-    shortest_distance = (*func) (toplevel, object, x, y, force_solid);
+    shortest_distance = (*func) (object, x, y, force_solid, include_hidden);
   }
 
   return shortest_distance;
@@ -827,14 +838,12 @@ geda_object_shortest_distance_full (TOPLEVEL *toplevel, OBJECT *object,
 
 /*! \brief Change the color of an object
  *
- *  \par Function Description
- *  This function changes the color of an object.
- *
- *  \param [in] toplevel  The TOPLEVEL structure.
  *  \param [in] object    The OBJECT to change color.
  *  \param [in] color     The new color.
  */
-void o_set_color (TOPLEVEL *toplevel, OBJECT *object, int color)
+void
+o_set_color (OBJECT *object,
+             int color)
 {
   g_return_if_fail (object != NULL);
 
@@ -842,7 +851,7 @@ void o_set_color (TOPLEVEL *toplevel, OBJECT *object, int color)
 
   if (object->type == OBJ_COMPONENT ||
       object->type == OBJ_PLACEHOLDER)
-    geda_object_list_set_color (object->component->prim_objs, color, toplevel);
+    geda_object_list_set_color (object->component->prim_objs, color);
 }
 
 
@@ -873,12 +882,11 @@ o_get_page (OBJECT *object)
  * If \a object is part of a component #OBJECT, returns that
  * #OBJECT. Otherwise, returns NULL.
  *
- * \param [in] toplevel  The TOPLEVEL structure.
  * \param [in] object    The OBJECT for which to get the containing OBJECT.
  * \return The component OBJECT which owns \a object, or NULL.
  */
 OBJECT *
-o_get_parent (TOPLEVEL *toplevel, OBJECT *object)
+o_get_parent (OBJECT *object)
 {
   g_return_val_if_fail ((object != NULL), NULL);
 
@@ -963,19 +971,26 @@ o_remove_change_notify (TOPLEVEL *toplevel,
 
 /*! \brief Emit an object pre-change notification.
  * \par Function Description
- * Calls each pre-change callback function registered with #TOPLEVEL
- * to notify listeners that \a object is about to be modified.  All
- * libgeda functions that modify #OBJECT structures should call this
- * just before making a change to an #OBJECT.
  *
- * \param toplevel #TOPLEVEL structure to emit notifications from.
+ * Calls each pre-change callback function registered with \a
+ * object's #TOPLEVEL to notify listeners that \a object is about
+ * to be modified.  All liblepton functions that modify #OBJECT
+ * structures should call this just before making a change to an
+ * #OBJECT.
+ *
  * \param object   #OBJECT structure to emit notifications for.
  */
 void
-o_emit_pre_change_notify (TOPLEVEL *toplevel, OBJECT *object)
+o_emit_pre_change_notify (OBJECT *object)
 {
   GList *iter;
 
+  if (object->page == NULL) {
+    return;
+  }
+
+  TOPLEVEL *toplevel = object->page->toplevel;
+
   if (toplevel == NULL) {
     return;
   }
@@ -994,19 +1009,26 @@ o_emit_pre_change_notify (TOPLEVEL *toplevel, OBJECT *object)
 
 /*! \brief Emit an object change notification.
  * \par Function Description
- * Calls each change callback function registered with #TOPLEVEL to
- * notify listeners that \a object has just been modified.  All
- * libgeda functions that modify #OBJECT structures should call this
- * just after making a change to an #OBJECT.
  *
- * \param toplevel #TOPLEVEL structure to emit notifications from.
+ * Calls each change callback function registered with \a object's
+ * #TOPLEVEL to notify listeners that \a object has just been
+ * modified.  All liblepton functions that modify #OBJECT
+ * structures should call this just after making a change to an
+ * #OBJECT.
+ *
  * \param object   #OBJECT structure to emit notifications for.
  */
 void
-o_emit_change_notify (TOPLEVEL *toplevel, OBJECT *object)
+o_emit_change_notify (OBJECT *object)
 {
   GList *iter;
 
+  if (object->page == NULL) {
+    return;
+  }
+
+  TOPLEVEL *toplevel = object->page->toplevel;
+
   if (toplevel == NULL) {
     return;
   }
@@ -1027,12 +1049,11 @@ o_emit_change_notify (TOPLEVEL *toplevel, OBJECT *object)
  *  \par Function Description
  *  Attribute getter for the visible field within the object.
  *
- *  \param toplevel The TOPLEVEL structure
  *  \param object   The OBJECT structure to be queried
  *  \return TRUE when VISIBLE, FALSE otherwise
  */
 gboolean
-o_is_visible (const TOPLEVEL *toplevel, const OBJECT *object)
+o_is_visible (const OBJECT *object)
 {
   g_return_val_if_fail (object != NULL, FALSE);
   return object->visibility == VISIBLE;
@@ -1052,16 +1073,12 @@ geda_object_get_visible (const GedaObject *object)
 }
 
 /*! \brief Set visibility of the object.
- *  \par Function Description
- *  Set value of visibility field within the object.
- *  If resulting visibility value is changed,
- *  invalidate the bounds of the object and parent objects.
  *
- *  \param toplevel The #TOPLEVEL structure
- *  \param object   The #OBJECT structure to be modified
+ *  \param object     The #OBJECT structure to be modified
+ *  \param visibility If the object should be visible
  */
 void
-o_set_visibility (TOPLEVEL *toplevel, OBJECT *object, int visibility)
+o_set_visibility (OBJECT *object, int visibility)
 {
   g_return_if_fail (object != NULL);
   object->visibility = visibility;
@@ -1069,8 +1086,10 @@ o_set_visibility (TOPLEVEL *toplevel, OBJECT *object, int visibility)
 
 /*! \brief Return the bounds of the given object.
  *  \par Given an object, calculate the bounds coordinates.
- *  \param [in] toplevel The toplevel structure.
+ *
  *  \param [in] o_current The object to look the bounds for.
+ *  \param [in] include_hidden If bounds of hidden objects should
+ *                             be calculated.
  *  \param [out] rleft   pointer to the left coordinate of the object.
  *  \param [out] rtop    pointer to the top coordinate of the object.
  *  \param [out] rright  pointer to the right coordinate of the object.
@@ -1080,8 +1099,8 @@ o_set_visibility (TOPLEVEL *toplevel, OBJECT *object, int visibility)
  *  \retval 1 Bound was found
  */
 gboolean
-geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
-                                      OBJECT *o_current,
+geda_object_calculate_visible_bounds (OBJECT *o_current,
+                                      gboolean include_hidden,
                                       gint *rleft,
                                       gint *rtop,
                                       gint *rright,
@@ -1094,7 +1113,7 @@ geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
   /* only do bounding boxes for visible or doing show_hidden_text*/
   /* you might lose some attrs though */
   if (o_current->type == OBJ_TEXT &&
-      ! (o_is_visible (toplevel, o_current) || toplevel->show_hidden_text)) {
+      ! (o_is_visible (o_current) || include_hidden)) {
     return 0;
   }
 
@@ -1106,28 +1125,28 @@ geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
     if (o_current->line == NULL) {
       return 0;
     }
-    geda_line_object_calculate_bounds (toplevel, o_current, &bounds);
+    geda_line_object_calculate_bounds (o_current, &bounds);
     break;
 
   case(OBJ_NET):
     if (o_current->line == NULL) {
       return 0;
     }
-    geda_net_object_calculate_bounds (toplevel, o_current, &bounds);
+    geda_net_object_calculate_bounds (o_current, &bounds);
     break;
 
   case(OBJ_BUS):
     if (o_current->line == NULL) {
       return 0;
     }
-    geda_bus_object_calculate_bounds(toplevel, o_current, &bounds);
+    geda_bus_object_calculate_bounds (o_current, &bounds);
     break;
 
   case(OBJ_BOX):
     if (o_current->box == NULL) {
       return 0;
     }
-    geda_box_object_calculate_bounds (toplevel, o_current, &bounds);
+    geda_box_object_calculate_bounds (o_current, &bounds);
     break;
 
   case(OBJ_PATH):
@@ -1135,7 +1154,7 @@ geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
     if (o_current->path->num_sections <= 0) {
       return 0;
     }
-    geda_path_object_calculate_bounds (toplevel, o_current, &bounds);
+    geda_path_object_calculate_bounds (o_current, &bounds);
     break;
 
   case(OBJ_PICTURE):
@@ -1149,7 +1168,7 @@ geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
     if (o_current->circle == NULL) {
       return 0;
     }
-    geda_circle_object_calculate_bounds (toplevel, o_current, &bounds);
+    geda_circle_object_calculate_bounds (o_current, &bounds);
     break;
 
   case(OBJ_COMPONENT):
@@ -1161,21 +1180,23 @@ geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
     if (o_current->component->prim_objs == NULL)
       return 0;
 
-    geda_component_object_calculate_bounds(toplevel, o_current, &bounds);
+    geda_component_object_calculate_bounds (o_current,
+                                            include_hidden,
+                                            &bounds);
     break;
 
   case(OBJ_PIN):
     if (o_current->line == NULL) {
       return 0;
     }
-    geda_pin_object_calculate_bounds (toplevel, o_current, &bounds);
+    geda_pin_object_calculate_bounds (o_current, &bounds);
     break;
 
   case(OBJ_ARC):
     if (o_current->arc == NULL) {
       return 0;
     }
-    geda_arc_object_calculate_bounds (toplevel, o_current,
+    geda_arc_object_calculate_bounds (o_current,
                                       &bounds.min_x,
                                       &bounds.min_y,
                                       &bounds.max_x,
@@ -1183,7 +1204,9 @@ geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
     break;
 
   case(OBJ_TEXT):
-    if (!geda_text_object_calculate_bounds(toplevel, o_current, &bounds)) {
+    if (!geda_text_object_calculate_bounds (o_current,
+                                            include_hidden,
+                                            &bounds)) {
       return 0;
     }
     break;
