@@ -57,7 +57,7 @@ static gint global_pid = 0;
 /* Called just before removing an OBJECT from a PAGE
  * or after appending an OBJECT to a PAGE. */
 static void
-object_added (TOPLEVEL *toplevel, PAGE *page, OBJECT *object)
+object_added (PAGE *page, OBJECT *object)
 {
   /* Set up object parent pointer */
 #ifndef NDEBUG
@@ -70,14 +70,14 @@ object_added (TOPLEVEL *toplevel, PAGE *page, OBJECT *object)
   /* Update object connection tracking */
   s_conn_update_object (page, object);
 
-  o_emit_change_notify (toplevel, object);
+  o_emit_change_notify (object);
 }
 
 /* Called just before removing an OBJECT from a PAGE. */
 static void
-pre_object_removed (TOPLEVEL *toplevel, PAGE *page, OBJECT *object)
+pre_object_removed (PAGE *page, OBJECT *object)
 {
-  o_emit_pre_change_notify (toplevel, object);
+  o_emit_pre_change_notify (object);
 
   /* Remove object from the list of connectible objects */
   s_conn_remove_object (page, object);
@@ -96,7 +96,7 @@ pre_object_removed (TOPLEVEL *toplevel, PAGE *page, OBJECT *object)
   }
 
   /* Remove object from connection system */
-  s_conn_remove_object_connections (toplevel, object);
+  s_conn_remove_object_connections (object);
 }
 
 /*! \brief create a new page object
@@ -150,6 +150,8 @@ PAGE *s_page_new (TOPLEVEL *toplevel, const gchar *filename)
   page->saved_since_first_loaded = 0;
   page->do_autosave_backup = 0;
 
+  page->major_changed_refdes = NULL;
+
   /* now append page to page list of toplevel */
   geda_list_add( toplevel->pages, page );
   page->toplevel = toplevel;
@@ -218,10 +220,10 @@ void s_page_delete (TOPLEVEL *toplevel, PAGE *page)
   g_object_unref( page->selection_list );
 
   /* then delete objects of page */
-  s_page_delete_objects (toplevel, page);
+  s_page_delete_objects (page);
 
   /* Free the objects in the place list. */
-  geda_object_list_delete (toplevel, page->place_list);
+  geda_object_list_delete (page->place_list);
   page->place_list = NULL;
 
   /*  This removes all objects from the list of connectible objects
@@ -236,7 +238,7 @@ void s_page_delete (TOPLEVEL *toplevel, PAGE *page)
   page->connectible_list = NULL;
 
   /* free current page undo structs */
-  s_undo_free_all (toplevel, page);
+  s_undo_free_all (page);
 
   /* ouch, deal with parents going away and the children still around */
   page->up = -2;
@@ -246,6 +248,13 @@ void s_page_delete (TOPLEVEL *toplevel, PAGE *page)
 
   page->weak_refs = s_weakref_notify (page, page->weak_refs);
 
+
+  if (page->major_changed_refdes)
+  {
+    g_list_free_full (page->major_changed_refdes, &g_free);
+  }
+
+
   g_free (page);
 
   /* restore page_current */
@@ -508,43 +517,6 @@ void s_page_print_all (TOPLEVEL *toplevel)
   }
 }
 
-/*! \brief Saves all the pages of a TOPLEVEL object.
- *  \par Function Description
- *  Saves all the pages in the <B>toplevel</B> parameter.
- *
- *  \param [in] toplevel  The TOPLEVEL to save pages from.
- *  \return The number of failed tries to save a page.
- */
-gint s_page_save_all (TOPLEVEL *toplevel)
-{
-  const GList *iter;
-  PAGE *p_current;
-  gint status = 0;
-
-  for ( iter = geda_list_get_glist( toplevel->pages );
-        iter != NULL;
-        iter = g_list_next( iter ) ) {
-
-    p_current = (PAGE *)iter->data;
-
-    if (f_save (toplevel, p_current,
-                s_page_get_filename (p_current), NULL)) {
-      s_log_message (_("Saved [%1$s]"),
-                     s_page_get_filename (p_current));
-      /* reset the CHANGED flag of p_current */
-      p_current->CHANGED = 0;
-
-    } else {
-      s_log_message (_("Could NOT save [%1$s]"),
-                     s_page_get_filename (p_current));
-      /* increase the error counter */
-      status++;
-    }
-
-  }
-
-  return status;
-}
 
 /*! \brief Check if CHANGED flag is set for any page in list.
  *  \par Function Description
@@ -659,14 +631,15 @@ gint s_page_autosave (TOPLEVEL *toplevel)
  *  Links the passed OBJECT to the end of the PAGE's
  *  linked list of objects.
  *
- *  \param [in] toplevel  The TOPLEVEL object.
  *  \param [in] page      The PAGE the object is being added to.
  *  \param [in] object    The OBJECT being added to the page.
  */
-void s_page_append (TOPLEVEL *toplevel, PAGE *page, OBJECT *object)
+void
+s_page_append (PAGE *page,
+               OBJECT *object)
 {
   page->_object_list = g_list_append (page->_object_list, object);
-  object_added (toplevel, page, object);
+  object_added (page, object);
 }
 
 /*! \brief Append a GList of OBJECTs to the PAGE
@@ -675,16 +648,17 @@ void s_page_append (TOPLEVEL *toplevel, PAGE *page, OBJECT *object)
  *  Links the passed OBJECT GList to the end of the PAGE's
  *  object_list.
  *
- *  \param [in] toplevel  The TOPLEVEL object.
  *  \param [in] page      The PAGE the objects are being added to.
  *  \param [in] obj_list  The OBJECT list being added to the page.
  */
-void s_page_append_list (TOPLEVEL *toplevel, PAGE *page, GList *obj_list)
+void
+s_page_append_list (PAGE *page,
+                    GList *obj_list)
 {
   GList *iter;
   page->_object_list = g_list_concat (page->_object_list, obj_list);
   for (iter = obj_list; iter != NULL; iter = g_list_next (iter)) {
-    object_added (toplevel, page, (OBJECT*) iter->data);
+    object_added (page, (OBJECT*) iter->data);
   }
 }
 
@@ -694,13 +668,14 @@ void s_page_append_list (TOPLEVEL *toplevel, PAGE *page, GList *obj_list)
  *  Removes the passed OBJECT from the PAGE's
  *  linked list of objects.
  *
- *  \param [in] toplevel  The TOPLEVEL object.
  *  \param [in] page      The PAGE the object is being removed from.
  *  \param [in] object    The OBJECT being removed from the page.
  */
-void s_page_remove (TOPLEVEL *toplevel, PAGE *page, OBJECT *object)
+void
+s_page_remove (PAGE *page,
+               OBJECT *object)
 {
-  pre_object_removed (toplevel, page, object);
+  pre_object_removed (page, object);
   page->_object_list = g_list_remove (page->_object_list, object);
 }
 
@@ -711,45 +686,42 @@ void s_page_remove (TOPLEVEL *toplevel, PAGE *page, OBJECT *object)
  * \a object2 in the position thus vacated. If \a object1 is not in \a
  * page, object2 is appended to \a page.
  *
- * \param [in] toplevel  The TOPLEVEL object.
  * \param [in] page      The PAGE to be modified.
  * \param [in] object1   The OBJECT being removed from the page.
  * \param [in] object2   The OBJECT being added to the page.
  */
 void
-s_page_replace (TOPLEVEL *toplevel, PAGE *page,
-                OBJECT *object1, OBJECT *object2)
+s_page_replace (PAGE *page,
+                OBJECT *object1,
+                OBJECT *object2)
 {
   GList *iter = g_list_find (page->_object_list, object1);
 
   /* If object1 not found, append object2 */
   if (iter == NULL) {
-    s_page_append (toplevel, page, object2);
+    s_page_append (page, object2);
     return;
   }
 
-  pre_object_removed (toplevel, page, object1);
+  pre_object_removed (page, object1);
   iter->data = object2;
-  object_added (toplevel, page, object2);
+  object_added (page, object2);
 }
 
 /*! \brief Remove and free all OBJECTs from the PAGE
  *
- *  \par Function Description
- *  Removes and frees all OBJECTs from the PAGE.
- *
- *  \param [in] toplevel  The TOPLEVEL object.
  *  \param [in] page      The PAGE being cleared.
  */
-void s_page_delete_objects (TOPLEVEL *toplevel, PAGE *page)
+void
+s_page_delete_objects (PAGE *page)
 {
   GList *objects = page->_object_list;
   GList *iter;
   for (iter = objects; iter != NULL; iter = g_list_next (iter)) {
-    pre_object_removed (toplevel, page, (OBJECT*) iter->data);
+    pre_object_removed (page, (OBJECT*) iter->data);
   }
   page->_object_list = NULL;
-  geda_object_list_delete (toplevel, objects);
+  geda_object_list_delete (objects);
 }
 
 
@@ -770,33 +742,6 @@ const GList *s_page_objects (PAGE *page)
 }
 
 
-/*! \brief Find the objects in a given region
- *
- *  \par Function Description
- *  Finds the objects which are inside, or intersect
- *  the passed box shaped region.
- *
- *  \param [in] toplevel  The TOPLEVEL object.
- *  \param [in] page      The PAGE to find objects on.
- *  \param [in] min_x     The smaller X coordinate of the region.
- *  \param [in] min_y     The smaller Y coordinate of the region.
- *  \param [in] max_x     The larger  X coordinate of the region.
- *  \param [in] max_y     The larger  Y coordinate of the region.
- *  \return The GList of OBJECTs in the region.
- */
-GList *s_page_objects_in_region (TOPLEVEL *toplevel, PAGE *page,
-                                 int min_x, int min_y, int max_x, int max_y)
-{
-  BOX rect;
-
-  rect.lower_x = min_x;
-  rect.lower_y = min_y;
-  rect.upper_x = max_x;
-  rect.upper_y = max_y;
-
-  return s_page_objects_in_regions (toplevel, page, &rect, 1);
-}
-
 /*! \brief Find the objects in a given region
  *
  *  \par Function Description
@@ -807,10 +752,15 @@ GList *s_page_objects_in_region (TOPLEVEL *toplevel, PAGE *page,
  *  \param [in] page      The PAGE to find objects on.
  *  \param [in] rects     The BOX regions to check.
  *  \param [in] n_rects   The number of regions.
+ *  \param [in] include_hidden Calculate bounds of hidden objects.
  *  \return The GList of OBJECTs in the region.
  */
-GList *s_page_objects_in_regions (TOPLEVEL *toplevel, PAGE *page,
-                                  BOX *rects, int n_rects)
+GList*
+s_page_objects_in_regions (TOPLEVEL *toplevel,
+                           PAGE *page,
+                           BOX *rects,
+                           int n_rects,
+                           gboolean include_hidden)
 {
   GList *iter;
   GList *list = NULL;
@@ -821,8 +771,12 @@ GList *s_page_objects_in_regions (TOPLEVEL *toplevel, PAGE *page,
     int left, top, right, bottom;
     int visible;
 
-    visible = geda_object_calculate_visible_bounds (toplevel, object,
-                                              &left, &top, &right, &bottom);
+    visible = geda_object_calculate_visible_bounds (object,
+                                                    include_hidden,
+                                                    &left,
+                                                    &top,
+                                                    &right,
+                                                    &bottom);
     if (visible) {
       for (i = 0; i < n_rects; i++) {
         if (right  >= rects[i].lower_x &&
