@@ -337,19 +337,18 @@ static const char* fallback_xpm[] = {
  *  Parses \a first_line and subsequent lines from \a tb, and returns
  *  a newly-created picture #OBJECT.
  *
- *  \param [in]  toplevel       The TOPLEVEL object.
  *  \param [in]  first_line      Character string with picture description.
  *  \param [in]  tb              Text buffer to load embedded data from.
  *  \param [in]  release_ver     libgeda release version number.
  *  \param [in]  fileformat_ver  libgeda file format version number.
  *  \return A pointer to the new picture object, or NULL on error.
  */
-OBJECT *o_picture_read (TOPLEVEL *toplevel,
-                        const char *first_line,
-                        TextBuffer *tb,
-                        unsigned int release_ver,
-                        unsigned int fileformat_ver,
-                        GError **err)
+OBJECT*
+o_picture_read (const char *first_line,
+                TextBuffer *tb,
+                unsigned int release_ver,
+                unsigned int fileformat_ver,
+                GError **err)
 {
   OBJECT *new_obj;
   int x1, y1;
@@ -451,7 +450,7 @@ OBJECT *o_picture_read (TOPLEVEL *toplevel,
 
   /* create the picture */
   /* The picture is described by its upper left and lower right corner */
-  new_obj = o_picture_new (toplevel, file_content, file_length, filename,
+  new_obj = o_picture_new (file_content, file_length, filename,
                            type,
                            x1, y1+height, x1+width, y1,
                            angle, mirrored, embedded);
@@ -554,7 +553,6 @@ geda_picture_object_to_buffer (const GedaObject *object)
  *  attempt to be loaded from \a filename.  Otherwise, the picture
  *  object will be initially empty.
  *
- *  \param [in]     toplevel      The TOPLEVEL object.
  *  \param [in]     file_content  Raw data of the image file, or NULL.
  *  \param [in]     file_length   Length of raw data buffer
  *  \param [in]     filename      File name backing this picture, or NULL.
@@ -568,11 +566,17 @@ geda_picture_object_to_buffer (const GedaObject *object)
  *  \param [in]     embedded      Whether the embedded flag should be set or not.
  *  \return A pointer to a new picture #OBJECT.
  */
-OBJECT *o_picture_new (TOPLEVEL *toplevel,
-                       const gchar *file_content, gsize file_length,
+OBJECT *o_picture_new (const gchar *file_content,
+                       gsize file_length,
                        const gchar *filename,
-                       char type, int x1, int y1, int x2, int y2, int angle,
-                       int mirrored, int embedded)
+                       char type,
+                       int x1,
+                       int y1,
+                       int x2,
+                       int y2,
+                       int angle,
+                       int mirrored,
+                       int embedded)
 {
   OBJECT *new_node;
   PICTURE *picture;
@@ -601,7 +605,7 @@ OBJECT *o_picture_new (TOPLEVEL *toplevel,
 
   if (file_content != NULL) {
     GError *error = NULL;
-    if (!o_picture_set_from_buffer (toplevel, new_node, filename,
+    if (!o_picture_set_from_buffer (new_node, filename,
                                     file_content, file_length, &error)) {
       s_log_message (_("Failed to load buffer image [%1$s]: %2$s"),
                      filename, error->message);
@@ -615,12 +619,12 @@ OBJECT *o_picture_new (TOPLEVEL *toplevel,
   }
   if (picture->pixbuf == NULL && filename != NULL) {
     GError *error = NULL;
-    if (!o_picture_set_from_file (toplevel, new_node, filename, &error)) {
+    if (!o_picture_set_from_file (new_node, filename, &error)) {
       s_log_message (_("Failed to load image from [%1$s]: %2$s"),
                      filename, error->message);
       g_error_free (error);
       /* picture not found; try to open a fall back pixbuf */
-      picture->pixbuf = o_picture_get_fallback_pixbuf(toplevel);
+      picture->pixbuf = o_picture_get_fallback_pixbuf ();
     }
   }
 
@@ -719,7 +723,6 @@ o_picture_get_ratio (OBJECT *object)
  *  The coordinates of the corner is modified in the world coordinate system.
  *  Screen coordinates and boundings are then updated.
  *
- *  \param [in]     toplevel  The TOPLEVEL object.
  *  \param [in,out] object     Picture OBJECT to modify.
  *  \param [in]     x          New x coordinate.
  *  \param [in]     y          New y coordinate.
@@ -733,13 +736,16 @@ o_picture_get_ratio (OBJECT *object)
  *    <DT>*</DT><DD>PICTURE_LOWER_RIGHT
  *  </DL>
  */
-void o_picture_modify(TOPLEVEL *toplevel, OBJECT *object,
-                      int x, int y, int whichone)
+void
+o_picture_modify (OBJECT *object,
+                  int x,
+                  int y,
+                  int whichone)
 {
   int tmp;
   double ratio = o_picture_get_ratio (object);
 
-  o_emit_pre_change_notify (toplevel, object);
+  o_emit_pre_change_notify (object);
 
   /* change the position of the selected corner */
   switch(whichone) {
@@ -796,7 +802,7 @@ void o_picture_modify(TOPLEVEL *toplevel, OBJECT *object,
     object->picture->lower_y = tmp;
   }
 
-  o_emit_change_notify (toplevel, object);
+  o_emit_change_notify (object);
 }
 
 /*! \brief Modify a picture object's coordinates.
@@ -806,7 +812,6 @@ void o_picture_modify(TOPLEVEL *toplevel, OBJECT *object,
  * the points (\a x1, \a y1) and (\a x2, \a y2), and scaled as large
  * as possible to still fit within that rectangle.
  *
- * \param [in]     toplevel current #TOPLEVEL.
  * \param [in,out] object   picture #OBJECT to be modified.
  * \param [in]     x1       x coordinate of first corner of box.
  * \param [in]     y1       y coordinate of first corner of box.
@@ -814,10 +819,13 @@ void o_picture_modify(TOPLEVEL *toplevel, OBJECT *object,
  * \param [in]     y2       y coordinate of second corner of box.
  */
 void
-o_picture_modify_all (TOPLEVEL *toplevel, OBJECT *object,
-                      int x1, int y1, int x2, int y2)
+o_picture_modify_all (OBJECT *object,
+                      int x1,
+                      int y1,
+                      int x2,
+                      int y2)
 {
-  o_emit_pre_change_notify (toplevel, object);
+  o_emit_pre_change_notify (object);
 
   /* Normalise the requested rectangle. */
   object->picture->lower_x = (x1 > x2) ? x1 : x2;
@@ -825,7 +833,7 @@ o_picture_modify_all (TOPLEVEL *toplevel, OBJECT *object,
   object->picture->upper_x = (x1 > x2) ? x2 : x1;
   object->picture->upper_y = (y1 > y2) ? y1 : y2;
 
-  o_emit_change_notify (toplevel, object);
+  o_emit_change_notify (object);
 }
 
 /*! \brief Rotate picture OBJECT using WORLD coordinates.
@@ -835,7 +843,6 @@ o_picture_modify_all (TOPLEVEL *toplevel, OBJECT *object,
  *  degrees.
  *  The center of rotation is in world units.
  *
- *  \param [in]      toplevel      The TOPLEVEL object.
  *  \param [in]      world_centerx  Rotation center x coordinate in
  *                                  WORLD units.
  *  \param [in]      world_centery  Rotation center y coordinate in
@@ -843,8 +850,10 @@ o_picture_modify_all (TOPLEVEL *toplevel, OBJECT *object,
  *  \param [in]      angle          Rotation angle in degrees (See note below).
  *  \param [in,out]  object         Picture OBJECT to rotate.
  */
-void geda_picture_object_rotate (TOPLEVEL *toplevel,
-                            int world_centerx, int world_centery, int angle,
+void
+geda_picture_object_rotate (int world_centerx,
+                            int world_centery,
+                            int angle,
                             OBJECT *object)
 {
   int newx1, newy1;
@@ -902,13 +911,13 @@ void geda_picture_object_rotate (TOPLEVEL *toplevel,
  *  The picture is first translated to the origin, then mirrored and
  *  finally translated back at its previous position.
  *
- *  \param [in]     toplevel      The TOPLEVEL object.
  *  \param [in]     world_centerx  Origin x coordinate in WORLD units.
  *  \param [in]     world_centery  Origin y coordinate in WORLD units.
  *  \param [in,out] object         Picture OBJECT to mirror.
  */
-void geda_picture_object_mirror(TOPLEVEL *toplevel,
-                            int world_centerx, int world_centery,
+void
+geda_picture_object_mirror (int world_centerx,
+                            int world_centery,
                             OBJECT *object)
 {
   int newx1, newy1;
@@ -983,11 +992,11 @@ geda_picture_object_translate (GedaObject *object, int dx, int dy)
  *  This function creates a verbatim copy of the object pointed by
  *  <B>o_current</B> describing a picture.
  *
- *  \param [in]  toplevel   The TOPLEVEL object.
  *  \param [in]  object     Picture OBJECT to copy.
  *  \return The new OBJECT
  */
-OBJECT *o_picture_copy(TOPLEVEL *toplevel, OBJECT *object)
+OBJECT*
+o_picture_copy (OBJECT *object)
 {
   OBJECT *new_node;
   PICTURE *picture;
@@ -1022,7 +1031,7 @@ OBJECT *o_picture_copy(TOPLEVEL *toplevel, OBJECT *object)
   picture->embedded    = object->picture->embedded;
 
   /* Get the picture data */
-  picture->pixbuf = o_picture_get_pixbuf (toplevel, object);
+  picture->pixbuf = o_picture_get_pixbuf (object);
 
   return new_node;
 }
@@ -1032,10 +1041,10 @@ OBJECT *o_picture_copy(TOPLEVEL *toplevel, OBJECT *object)
  * Verify that a picture has valid data associated with it, and if so,
  * mark it to be embedded.
  *
- *  \param [in]     toplevel     The TOPLEVEL object.
  *  \param [in]     object       The picture OBJECT to embed
  */
-void o_picture_embed (TOPLEVEL *toplevel, OBJECT *object)
+void
+o_picture_embed (OBJECT *object)
 {
   const gchar *filename = o_picture_get_filename (object);
   gchar *basename;
@@ -1062,10 +1071,10 @@ void o_picture_embed (TOPLEVEL *toplevel, OBJECT *object)
  * Verify that the file associated with \a object exists on disk and
  * is usable, and if so, reload the picture and mark it as unembedded.
  *
- *  \param [in]     toplevel     The TOPLEVEL object.
  *  \param [in]     object       The picture OBJECT to unembed
  */
-void o_picture_unembed (TOPLEVEL *toplevel, OBJECT *object)
+void
+o_picture_unembed (OBJECT *object)
 {
   GError *err = NULL;
   const gchar *filename = o_picture_get_filename (object);
@@ -1073,7 +1082,7 @@ void o_picture_unembed (TOPLEVEL *toplevel, OBJECT *object)
 
   if (!o_picture_is_embedded (object)) return;
 
-  o_picture_set_from_file (toplevel, object, filename, &err);
+  o_picture_set_from_file (object, filename, &err);
 
   if (err != NULL) {
     s_log_message (_("Failed to load image from file [%1$s]: %2$s"),
@@ -1095,17 +1104,20 @@ void o_picture_unembed (TOPLEVEL *toplevel, OBJECT *object)
  *
  *  Interrior points within the picture return a distance of zero.
  *
- *  \param [in] toplevel     The TOPLEVEL object.
- *  \param [in] object       The picture OBJECT.
- *  \param [in] x            The x coordinate of the given point.
- *  \param [in] y            The y coordinate of the given point.
- *  \param [in] force_solid  If true, force treating the object as solid.
+ *  \param [in] object         The picture OBJECT.
+ *  \param [in] x              The x coordinate of the given point.
+ *  \param [in] y              The y coordinate of the given point.
+ *  \param [in] force_solid    If true, force treating the object as solid.
+ *  \param [in] include_hidden Take hidden text into account.
  *  \return The shortest distance from the object to the point. With an
  *  invalid parameter, this function returns G_MAXDOUBLE.
  */
 double
-geda_picture_object_shortest_distance (TOPLEVEL *toplevel, OBJECT *object,
-                                       int x, int y, int force_solid)
+geda_picture_object_shortest_distance (OBJECT *object,
+                                       int x,
+                                       int y,
+                                       int force_solid,
+                                       gboolean include_hidden)
 {
   double dx, dy;
   double x1, y1, x2, y2;
@@ -1152,12 +1164,11 @@ o_picture_is_embedded (const OBJECT *object)
  * The returned value should have its reference count decremented with
  * g_object_unref() when no longer needed.
  *
- * \param toplevel  The current #TOPLEVEL.
  * \param object    The picture #OBJECT to inspect.
  * \return A #GdkPixbuf for the picture.
  */
 GdkPixbuf *
-o_picture_get_pixbuf (TOPLEVEL *toplevel, OBJECT *object)
+o_picture_get_pixbuf (OBJECT *object)
 {
   g_return_val_if_fail (object != NULL, NULL);
   g_return_val_if_fail (object->picture != NULL, NULL);
@@ -1169,33 +1180,12 @@ o_picture_get_pixbuf (TOPLEVEL *toplevel, OBJECT *object)
   }
 }
 
-/*! \brief Get the raw image data from a picture object.
- * \par Function Description
- * Returns the raw image file data underlying the picture \a object,
- * or NULL if the picture could not be loaded.
- *
- * \param toplevel  The current #TOPLEVEL.
- * \param object    The picture #OBJECT to inspect.
- * \param len       Location to store buffer length.
- * \return A read-only buffer of raw image data.
- */
-const char *
-o_picture_get_data (TOPLEVEL *toplevel, OBJECT *object,
-                    size_t *len)
-{
-  g_return_val_if_fail (object != NULL, NULL);
-  g_return_val_if_fail (object->picture != NULL, NULL);
-
-  *len = object->picture->file_length;
-  return object->picture->file_content;
-}
 
 /*! \brief Set a picture object's contents from a buffer.
  * \par Function Description
  * Sets the contents of the picture \a object by reading image data
  * from a buffer.  The buffer should be in on-disk format.
  *
- * \param toplevel The current #TOPLEVEL.
  * \param object   The picture #OBJECT to modify.
  * \param filename The new filename for the picture.
  * \param data     The new image data buffer.
@@ -1204,9 +1194,10 @@ o_picture_get_data (TOPLEVEL *toplevel, OBJECT *object,
  * \return TRUE on success, FALSE on failure.
  */
 gboolean
-o_picture_set_from_buffer (TOPLEVEL *toplevel, OBJECT *object,
+o_picture_set_from_buffer (OBJECT *object,
                            const gchar *filename,
-                           const gchar *data, size_t len,
+                           const gchar *data,
+                           size_t len,
                            GError **error)
 {
   GdkPixbuf *pixbuf;
@@ -1224,7 +1215,7 @@ o_picture_set_from_buffer (TOPLEVEL *toplevel, OBJECT *object,
   g_object_unref (stream);
   if (pixbuf == NULL) return FALSE;
 
-  o_emit_pre_change_notify (toplevel, object);
+  o_emit_pre_change_notify (object);
 
   if (object->picture->pixbuf != NULL) {
     g_object_unref (object->picture->pixbuf);
@@ -1246,7 +1237,7 @@ o_picture_set_from_buffer (TOPLEVEL *toplevel, OBJECT *object,
   object->picture->file_content = buf;
   object->picture->file_length = len;
 
-  o_emit_change_notify (toplevel, object);
+  o_emit_change_notify (object);
   return TRUE;
 }
 
@@ -1255,14 +1246,13 @@ o_picture_set_from_buffer (TOPLEVEL *toplevel, OBJECT *object,
  * Sets the contents of the picture \a object by reading image data
  * from a file.
  *
- * \param toplevel The current #TOPLEVEL.
  * \param object   The picture #OBJECT to modify.
  * \param filename The filename to load image data from.
  * \param error    Location to return error information.
  * \return TRUE on success, FALSE on failure.
  */
 gboolean
-o_picture_set_from_file (TOPLEVEL *toplevel, OBJECT *object,
+o_picture_set_from_file (OBJECT *object,
                          const gchar *filename,
                          GError **error)
 {
@@ -1276,7 +1266,7 @@ o_picture_set_from_file (TOPLEVEL *toplevel, OBJECT *object,
     return FALSE;
   }
 
-  status = o_picture_set_from_buffer (toplevel, object, filename,
+  status = o_picture_set_from_buffer (object, filename,
                                       buf, len, error);
   g_free (buf);
   return status;
@@ -1307,7 +1297,7 @@ o_picture_get_filename (const GedaObject *object)
  * \return a #GdkPixbuf containing a warning image.
  */
 GdkPixbuf *
-o_picture_get_fallback_pixbuf (TOPLEVEL *toplevel)
+o_picture_get_fallback_pixbuf ()
 {
   static GdkPixbuf *pixbuf = NULL;
   static gboolean failed = FALSE;
