@@ -51,6 +51,8 @@
 #endif
 
 #include "libgeda_priv.h"
+#include "libleptonrenderer/libleptonrenderer.h"
+
 
 /*! \brief Scale factor between legacy lepton-schematic font units
  *  and postscript points.
@@ -76,30 +78,38 @@ int tab_in_chars = 8;
  *  be moved to EdaRenderer. And, this method should not be a virtual method
  *  of GedaObject.
  *
- *  \param [in]  toplevel  The TOPLEVEL object.
- *  \param [in]  object    a text object
- *  \param [out] bounds    the bounds of the text
+ *  \param [in]  object         a text object
+ *  \param [in]  include_hidden if hidden text should be taken into
+ *                              account
+ *  \param [out] bounds         the bounds of the text
  *  \return TRUE if successful, FALSE if unsuccessful
  */
 gboolean
-geda_text_object_calculate_bounds (TOPLEVEL *toplevel,
-                                   const GedaObject *object,
+geda_text_object_calculate_bounds (const GedaObject *object,
+                                   gboolean include_hidden,
                                    GedaBounds *bounds)
 {
+  if (! (o_is_visible (object) || include_hidden))
+    return FALSE;
+
   geda_bounds_init (bounds);
 
   g_return_val_if_fail (object != NULL, FALSE);
   g_return_val_if_fail (object->text != NULL, FALSE);
   g_return_val_if_fail (object->type == OBJ_TEXT, FALSE);
-  g_return_val_if_fail (toplevel != NULL, FALSE);
-  g_return_val_if_fail (toplevel->rendered_text_bounds_func != NULL, FALSE);
 
-  return toplevel->rendered_text_bounds_func (toplevel->rendered_text_bounds_data,
-                                              object,
-                                              &bounds->min_x,
-                                              &bounds->min_y,
-                                              &bounds->max_x,
-                                              &bounds->max_y);
+  double t, l, r, b;
+  gboolean result = eda_renderer_get_text_user_bounds (object,
+                                                       include_hidden,
+                                                       &l, &t, &r, &b);
+
+  /* Round bounds to nearest integer */
+  bounds->min_x = lrint (fmin (l, r));
+  bounds->min_y = lrint (fmin (t, b));
+  bounds->max_x = lrint (fmax (l, r));
+  bounds->max_y = lrint (fmax (t, b));
+
+  return result;
 }
 
 /*! \brief Get the text alignment
@@ -390,7 +400,6 @@ update_disp_string (OBJECT *object)
  *  \par Function Description
  *  Create an OBJECT of type OBJ_TEXT.
  *
- *  \param [in]  toplevel              The TOPLEVEL object.
  *  \param [in]  type                   OBJ_TEXT (TODO: why bother)
  *  \param [in]  color                  The color of the text.
  *  \param [in]  x                      World x coord of text.
@@ -407,8 +416,7 @@ update_disp_string (OBJECT *object)
  *  Caller is responsible for string; this function allocates its own copy.
  */
 GedaObject*
-geda_text_object_new (TOPLEVEL *toplevel,
-                      gint color,
+geda_text_object_new (gint color,
                       gint x,
                       gint y,
                       gint alignment,
@@ -440,7 +448,7 @@ geda_text_object_new (TOPLEVEL *toplevel,
   new_node->text = text;
 
   new_node->color = color;
-  o_set_visibility (toplevel, new_node, visibility);
+  o_set_visibility (new_node, visibility);
   new_node->show_name_value = show_name_value;
 
   update_disp_string (new_node);
@@ -455,7 +463,6 @@ geda_text_object_new (TOPLEVEL *toplevel,
  *  If the line object was read successfully, a new object is
  *  create and appended to the \a object_list.
  *
- *  \param [in] toplevel     The TOPLEVEL object
  *  \param [in] first_line   the first line of the text
  *  \param [in] tb           a text buffer (usually a line of a schematic file)
  *  \param [in] release_ver  The release number gEDA
@@ -463,8 +470,7 @@ geda_text_object_new (TOPLEVEL *toplevel,
  *  \return The object list, or NULL on error.
  */
 OBJECT*
-o_text_read (TOPLEVEL *toplevel,
-             const char *first_line,
+o_text_read (const char *first_line,
              TextBuffer *tb,
              unsigned int release_ver,
              unsigned int fileformat_ver,
@@ -591,8 +597,7 @@ o_text_read (TOPLEVEL *toplevel,
     }
   }
 
-  new_obj = geda_text_object_new (toplevel,
-                                  color,
+  new_obj = geda_text_object_new (color,
                                   x,
                                   y,
                                   alignment,
@@ -647,15 +652,14 @@ geda_text_object_to_buffer (const GedaObject *object)
  *  This function updates the underlying primary of the text object
  *  \a o_current.
  *
- *  \param toplevel  The TOPLEVEL object
  *  \param o_current The text object to update
  */
 void
-o_text_recreate (TOPLEVEL *toplevel, OBJECT *o_current)
+o_text_recreate (OBJECT *o_current)
 {
-  o_emit_pre_change_notify (toplevel, o_current);
+  o_emit_pre_change_notify (o_current);
   update_disp_string (o_current);
-  o_emit_change_notify (toplevel, o_current);
+  o_emit_change_notify (o_current);
 }
 
 /*! \brief move a text object
@@ -681,12 +685,11 @@ geda_text_object_translate (GedaObject *object, int dx, int dy)
  *  \par Function Description
  *  This function creates a copy of the text object \a o_current.
  *
- *  \param [in] toplevel     The TOPLEVEL object
  *  \param [in] object    The object that is copied
  *  \return a new text object
  */
 GedaObject*
-geda_text_object_copy (TOPLEVEL *toplevel, const GedaObject *object)
+geda_text_object_copy (const GedaObject *object)
 {
   GedaObject *new_obj;
 
@@ -694,8 +697,7 @@ geda_text_object_copy (TOPLEVEL *toplevel, const GedaObject *object)
   g_return_val_if_fail (object->text != NULL, NULL);
   g_return_val_if_fail (object->type == OBJ_TEXT, NULL);
 
-  new_obj = geda_text_object_new (toplevel,
-                                  object->color,
+  new_obj = geda_text_object_new (object->color,
                                   object->text->x,
                                   object->text->y,
                                   object->text->alignment,
@@ -713,7 +715,6 @@ geda_text_object_copy (TOPLEVEL *toplevel, const GedaObject *object)
  *  This function rotates a text \a object around the point
  *  (\a world_centerx, \a world_centery).
  *
- *  \param [in] toplevel      The TOPLEVEL object
  *  \param [in] world_centerx x-coord of the rotation center
  *  \param [in] world_centery y-coord of the rotation center
  *  \param [in] angle         The angle to rotate the text object
@@ -721,8 +722,7 @@ geda_text_object_copy (TOPLEVEL *toplevel, const GedaObject *object)
  *  \note only steps of 90 degrees are allowed for the \a angle
  */
 void
-geda_text_object_rotate (TOPLEVEL *toplevel,
-                         int world_centerx,
+geda_text_object_rotate (int world_centerx,
                          int world_centery,
                          int angle,
                          OBJECT *object)
@@ -747,7 +747,7 @@ geda_text_object_rotate (TOPLEVEL *toplevel,
 
   geda_text_object_translate (object, x-object->text->x, y-object->text->y);
 
-  o_text_recreate(toplevel, object);
+  o_text_recreate (object);
 }
 
 
@@ -756,14 +756,12 @@ geda_text_object_rotate (TOPLEVEL *toplevel,
  *  This function mirrors a text \a object horizontaly at the point
  *  (\a world_centerx, \a world_centery).
  *
- *  \param [in] toplevel      The TOPLEVEL object
  *  \param [in] world_centerx x-coord of the mirror position
  *  \param [in] world_centery y-coord of the mirror position
  *  \param [in] object        The text object
  */
 void
-geda_text_object_mirror (TOPLEVEL *toplevel,
-                         int world_centerx,
+geda_text_object_mirror (int world_centerx,
                          int world_centery,
                          OBJECT *object)
 {
@@ -843,7 +841,7 @@ geda_text_object_mirror (TOPLEVEL *toplevel,
   object->text->x = -x + (world_centerx);
   object->text->y =  y + (world_centery);
 
-  o_text_recreate(toplevel, object);
+  o_text_recreate (object);
 }
 
 /*! \brief Calculates the distance between the given point and the closest
@@ -852,30 +850,34 @@ geda_text_object_mirror (TOPLEVEL *toplevel,
  *  This function will calculate the distance to the text regardless
  *  if the text is visible or not.
  *
- *  \param [in] toplevel     The TOPLEVEL object.
- *  \param [in] object       The text OBJECT.
- *  \param [in] x            The x coordinate of the given point.
- *  \param [in] y            The y coordinate of the given point.
- *  \param [in] force_solid  If true, force treating the object as solid.
+ *  \param [in] object         The text OBJECT.
+ *  \param [in] x              The x coordinate of the given point.
+ *  \param [in] y              The y coordinate of the given point.
+ *  \param [in] force_solid    If true, force treating the object as solid.
+ *  \param [in] include_hidden Take hidden text into account.
  *  \return The shortest distance from the object to the point. If the
  *  distance cannot be calculated, this function returns a really large
  *  number (G_MAXDOUBLE).  With an invalid parameter, this funciton
  *  returns G_MAXDOUBLE.
  */
 double
-geda_text_object_shortest_distance (TOPLEVEL *toplevel,
-                                    OBJECT *object,
+geda_text_object_shortest_distance (OBJECT *object,
                                     int x,
                                     int y,
-                                    int force_solid)
+                                    int force_solid,
+                                    gboolean include_hidden)
 {
   int left, top, right, bottom;
   double dx, dy;
 
   g_return_val_if_fail (object->text != NULL, G_MAXDOUBLE);
 
-  if (!geda_object_calculate_visible_bounds(toplevel, object,
-                                      &left, &top, &right, &bottom))
+  if (!geda_object_calculate_visible_bounds (object,
+                                             include_hidden,
+                                             &left,
+                                             &top,
+                                             &right,
+                                             &bottom))
     return G_MAXDOUBLE;
 
   dx = MIN (x - left, right - x);
@@ -891,14 +893,13 @@ geda_text_object_shortest_distance (TOPLEVEL *toplevel,
  *  \par Function Description
  *  Updates the text object with a new text string.
  *
- *  \param [in]  toplevel              The TOPLEVEL object.
  *  \param [in]  obj                   The text object.
  *  \param [in]  new_string            The new value.
  */
 void
-o_text_set_string (TOPLEVEL *toplevel, OBJECT *obj, const gchar *new_string)
+o_text_set_string (OBJECT *obj,
+                   const gchar *new_string)
 {
-  g_return_if_fail (toplevel != NULL);
   g_return_if_fail (obj != NULL);
   g_return_if_fail (obj->type == OBJ_TEXT);
   g_return_if_fail (obj->text != NULL);
@@ -907,23 +908,5 @@ o_text_set_string (TOPLEVEL *toplevel, OBJECT *obj, const gchar *new_string)
   g_free (obj->text->string);
   obj->text->string = g_strdup (new_string);
 
-  o_text_recreate (toplevel, obj);
-}
-
-/*! \brief Set the font-renderer-specific bounds function.
- *  \par Function Description
- *  Set the function to be used to calculate text bounds for a given
- *  #TOPLEVEL.
- *
- *  \param [in] toplevel     The TOPLEVEL object
- *  \param [in] func      Function to use.
- *  \param [in] user_data User data to be passed to the function.
- */
-void
-o_text_set_rendered_bounds_func (TOPLEVEL *toplevel,
-                                 RenderedBoundsFunc func,
-                                 void *user_data)
-{
-  toplevel->rendered_text_bounds_func = func;
-  toplevel->rendered_text_bounds_data = user_data;
+  o_text_recreate (obj);
 }
