@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /*!
@@ -187,10 +187,9 @@ SCM_DEFINE (copy_object, "%copy-object", 1, 0, 0,
   SCM_ASSERT (EDASCM_OBJECTP (obj_s), obj_s,
               SCM_ARG1, s_copy_object);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
 
-  result = edascm_from_object (o_object_copy (toplevel, obj));
+  result = edascm_from_object (o_object_copy (obj));
 
   /* At the moment, the only pointer to the object is owned by the
    * smob. */
@@ -289,22 +288,16 @@ SCM_DEFINE (object_id, "%object-id", 1, 0, 0,
 SCM_DEFINE (object_bounds, "%object-bounds", 0, 0, 1,
             (SCM rst_s), "Get the bounds of a list of objects")
 {
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
-
   GList *obj_list = edascm_to_object_glist (rst_s, s_object_bounds);
 
   int success, left, top, right, bottom;
-  if (toplevel->show_hidden_text) {
-    success = world_get_object_glist_bounds (toplevel, obj_list,
-                                             &left, &top, &right, &bottom);
-  } else {
-    toplevel->show_hidden_text = TRUE;
-
-    success = world_get_object_glist_bounds (toplevel, obj_list,
-                                             &left, &top, &right, &bottom);
-
-    toplevel->show_hidden_text = FALSE;
-  }
+  success = world_get_object_glist_bounds (obj_list,
+                                           /* Include hidden text. */
+                                           TRUE,
+                                           &left,
+                                           &top,
+                                           &right,
+                                           &bottom);
 
   SCM result = SCM_BOOL_F;
   if (success) {
@@ -425,7 +418,6 @@ SCM_DEFINE (set_object_stroke_x, "%set-object-stroke!", 4, 2, 0,
                || edascm_is_object_type (obj_s, OBJ_PATH)),
               obj_s, SCM_ARG1, s_set_object_stroke_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   int cap, type, width, length = -1, space = -1;
 
@@ -483,8 +475,7 @@ SCM_DEFINE (set_object_stroke_x, "%set-object-stroke!", 4, 2, 0,
     /* This case intentionally falls through */
   }
 
-  o_set_line_options (toplevel,
-                      obj,
+  o_set_line_options (obj,
                       (OBJECT_END) cap,
                       (OBJECT_TYPE) type,
                       width,
@@ -581,7 +572,6 @@ SCM_DEFINE (set_object_fill_x, "%set-object-fill!", 2, 5, 0,
                || edascm_is_object_type (obj_s, OBJ_PATH)),
               obj_s, SCM_ARG1, s_set_object_fill_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   int type, width = -1, angle1 = -1, space1 = -1, angle2 = -1, space2 = -1;
 
@@ -645,8 +635,7 @@ SCM_DEFINE (set_object_fill_x, "%set-object-fill!", 2, 5, 0,
     /* This case intentionally falls through */
   }
 
-  o_set_fill_options (toplevel,
-                      obj,
+  o_set_fill_options (obj,
                       (OBJECT_FILLING) type,
                       width,
                       space1,
@@ -701,9 +690,8 @@ SCM_DEFINE (set_object_color_x, "%set-object-color!", 2, 0, 0,
   SCM_ASSERT (scm_is_integer (color_s), color_s,
               SCM_ARG2, s_set_object_color_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
-  o_set_color (toplevel, obj, scm_to_int (color_s));
+  o_set_color (obj, scm_to_int (color_s));
 
   o_page_changed (obj);
 
@@ -881,8 +869,7 @@ SCM_DEFINE (set_object_embedded_x, "%set-object-embedded!", 2, 0, 0,
 SCM_DEFINE (make_line, "%make-line", 0, 0, 0,
             (), "Create a new line object.")
 {
-  GedaObject *object = geda_line_object_new (edascm_c_current_toplevel (),
-                                             DEFAULT_COLOR,
+  GedaObject *object = geda_line_object_new (DEFAULT_COLOR,
                                              0,
                                              0,
                                              0,
@@ -933,7 +920,6 @@ SCM_DEFINE (set_line_x, "%set-line!", 6, 0, 0,
   SCM_ASSERT (scm_is_integer (y2_s),    y2_s,    SCM_ARG5, s_set_line_x);
   SCM_ASSERT (scm_is_integer (color_s), color_s, SCM_ARG6, s_set_line_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (line_s);
   int x1 = scm_to_int (x1_s);
   int y1 = scm_to_int (y1_s);
@@ -941,30 +927,30 @@ SCM_DEFINE (set_line_x, "%set-line!", 6, 0, 0,
   int y2 = scm_to_int (y2_s);
 
   /* We may need to update connectivity. */
-  s_conn_remove_object_connections (toplevel, obj);
+  s_conn_remove_object_connections (obj);
 
   switch (obj->type) {
   case OBJ_LINE:
-    geda_line_object_modify (toplevel, obj, x1, y1, LINE_END1);
-    geda_line_object_modify (toplevel, obj, x2, y2, LINE_END2);
+    geda_line_object_modify (obj, x1, y1, LINE_END1);
+    geda_line_object_modify (obj, x2, y2, LINE_END2);
     break;
   case OBJ_NET:
-    geda_net_object_modify (toplevel, obj, x1, y1, 0);
-    geda_net_object_modify (toplevel, obj, x2, y2, 1);
+    geda_net_object_modify (obj, x1, y1, 0);
+    geda_net_object_modify (obj, x2, y2, 1);
     break;
   case OBJ_BUS:
-    geda_bus_object_modify (toplevel, obj, x1, y1, 0);
-    geda_bus_object_modify (toplevel, obj, x2, y2, 1);
+    geda_bus_object_modify (obj, x1, y1, 0);
+    geda_bus_object_modify (obj, x2, y2, 1);
     break;
   case OBJ_PIN:
     /* Swap ends according to pin's whichend flag. */
-    geda_pin_object_modify (toplevel, obj, x1, y1, obj->whichend ? 1 : 0);
-    geda_pin_object_modify (toplevel, obj, x2, y2, obj->whichend ? 0 : 1);
+    geda_pin_object_modify (obj, x1, y1, obj->whichend ? 1 : 0);
+    geda_pin_object_modify (obj, x2, y2, obj->whichend ? 0 : 1);
     break;
   default:
     return line_s;
   }
-  o_set_color (toplevel, obj, scm_to_int (color_s));
+  o_set_color (obj, scm_to_int (color_s));
 
   /* We may need to update connectivity. */
   PAGE *page = o_get_page (obj);
@@ -1036,8 +1022,7 @@ SCM_DEFINE (make_net, "%make-net", 0, 0, 0,
   OBJECT *obj;
   SCM result;
 
-  obj = geda_net_object_new (edascm_c_current_toplevel (),
-                             OBJ_NET, NET_COLOR, 0, 0, 0, 0);
+  obj = geda_net_object_new (OBJ_NET, NET_COLOR, 0, 0, 0, 0);
 
 
   result = edascm_from_object (obj);
@@ -1067,8 +1052,7 @@ SCM_DEFINE (make_bus, "%make-bus", 0, 0, 0,
   OBJECT *obj;
   SCM result;
 
-  obj = geda_bus_object_new (edascm_c_current_toplevel (),
-                             BUS_COLOR,
+  obj = geda_bus_object_new (BUS_COLOR,
                              0,
                              0,
                              0,
@@ -1112,8 +1096,7 @@ SCM_DEFINE (make_pin, "%make-pin", 1, 0, 0,
                     scm_list_1 (type_s));
   }
 
-  OBJECT *obj = geda_pin_object_new (edascm_c_current_toplevel (),
-                                     PIN_COLOR,
+  OBJECT *obj = geda_pin_object_new (PIN_COLOR,
                                      0,
                                      0,
                                      0,
@@ -1177,8 +1160,7 @@ SCM_DEFINE (pin_type, "%pin-type", 1, 0, 0,
 SCM_DEFINE (make_box, "%make-box", 0, 0, 0,
             (), "Create a new box object.")
 {
-  OBJECT *obj = geda_box_object_new (edascm_c_current_toplevel (),
-                                     OBJ_BOX, DEFAULT_COLOR,
+  OBJECT *obj = geda_box_object_new (OBJ_BOX, DEFAULT_COLOR,
                                      0, 0, 0, 0);
 
   SCM result = edascm_from_object (obj);
@@ -1219,12 +1201,11 @@ SCM_DEFINE (set_box_x, "%set-box!", 6, 0, 0,
   SCM_ASSERT (scm_is_integer (y2_s),    y2_s,    SCM_ARG5, s_set_box_x);
   SCM_ASSERT (scm_is_integer (color_s), color_s, SCM_ARG6, s_set_box_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (box_s);
-  geda_box_object_modify_all (toplevel, obj,
+  geda_box_object_modify_all (obj,
                               scm_to_int (x1_s), scm_to_int (y1_s),
                               scm_to_int (x2_s), scm_to_int (y2_s));
-  o_set_color (toplevel, obj, scm_to_int (color_s));
+  o_set_color (obj, scm_to_int (color_s));
 
   o_page_changed (obj);
 
@@ -1275,8 +1256,7 @@ SCM_DEFINE (box_info, "%box-info", 1, 0, 0,
 SCM_DEFINE (make_circle, "%make-circle", 0, 0, 0,
             (), "Create a new circle object.")
 {
-  GedaObject *object = geda_circle_object_new (edascm_c_current_toplevel (),
-                                               DEFAULT_COLOR,
+  GedaObject *object = geda_circle_object_new (DEFAULT_COLOR,
                                                0,
                                                0,
                                                1);
@@ -1317,12 +1297,11 @@ SCM_DEFINE (set_circle_x, "%set-circle!", 5, 0, 0,
   SCM_ASSERT (scm_is_integer (r_s),     r_s,     SCM_ARG4, s_set_circle_x);
   SCM_ASSERT (scm_is_integer (color_s), color_s, SCM_ARG5, s_set_circle_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (circle_s);
-  geda_circle_object_modify (toplevel, obj, scm_to_int(x_s), scm_to_int(y_s),
+  geda_circle_object_modify (obj, scm_to_int(x_s), scm_to_int(y_s),
                              CIRCLE_CENTER);
-  geda_circle_object_modify (toplevel, obj, scm_to_int(r_s), 0, CIRCLE_RADIUS);
-  o_set_color (toplevel, obj, scm_to_int (color_s));
+  geda_circle_object_modify (obj, scm_to_int(r_s), 0, CIRCLE_RADIUS);
+  o_set_color (obj, scm_to_int (color_s));
 
   o_page_changed (obj);
 
@@ -1371,8 +1350,7 @@ SCM_DEFINE (circle_info, "%circle-info", 1, 0, 0,
 SCM_DEFINE (make_arc, "%make-arc", 0, 0, 0,
             (), "Create a new arc object.")
 {
-  GedaObject *object = geda_arc_object_new (edascm_c_current_toplevel (),
-                                            DEFAULT_COLOR,
+  GedaObject *object = geda_arc_object_new (DEFAULT_COLOR,
                                             0,
                                             0,
                                             1,
@@ -1422,13 +1400,12 @@ SCM_DEFINE (set_arc_x, "%set-arc!", 7, 0, 0,
   SCM_ASSERT (scm_is_integer (end_angle_s),
                                   end_angle_s, SCM_ARG6, s_set_arc_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (arc_s);
-  geda_arc_object_modify (toplevel, obj, scm_to_int(x_s), scm_to_int(y_s), ARC_CENTER);
-  geda_arc_object_modify (toplevel, obj, scm_to_int(r_s), 0, ARC_RADIUS);
-  geda_arc_object_modify (toplevel, obj, scm_to_int(start_angle_s), 0, ARC_START_ANGLE);
-  geda_arc_object_modify (toplevel, obj, scm_to_int(end_angle_s), 0, ARC_SWEEP_ANGLE);
-  o_set_color (toplevel, obj, scm_to_int (color_s));
+  geda_arc_object_modify (obj, scm_to_int(x_s), scm_to_int(y_s), ARC_CENTER);
+  geda_arc_object_modify (obj, scm_to_int(r_s), 0, ARC_RADIUS);
+  geda_arc_object_modify (obj, scm_to_int(start_angle_s), 0, ARC_START_ANGLE);
+  geda_arc_object_modify (obj, scm_to_int(end_angle_s), 0, ARC_SWEEP_ANGLE);
+  o_set_color (obj, scm_to_int (color_s));
 
   o_page_changed (obj);
 
@@ -1483,8 +1460,7 @@ SCM_DEFINE (arc_info, "%arc-info", 1, 0, 0,
 SCM_DEFINE (make_text, "%make-text", 0, 0, 0,
             (), "Create a new text object.")
 {
-  OBJECT *obj = geda_text_object_new (edascm_c_current_toplevel (),
-                                      DEFAULT_COLOR,
+  OBJECT *obj = geda_text_object_new (DEFAULT_COLOR,
                                       0,
                                       0,
                                       LOWER_LEFT,
@@ -1547,7 +1523,6 @@ SCM_DEFINE (set_text_x, "%set-text!", 10, 0, 0,
   SCM_ASSERT (scm_is_symbol (show_s),    show_s,     9, s_set_text_x);
   SCM_ASSERT (scm_is_integer (color_s),  color_s,   10, s_set_text_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (text_s);
 
   /* Alignment. Sadly we can't switch on pointers. :-( */
@@ -1603,7 +1578,7 @@ SCM_DEFINE (set_text_x, "%set-text!", 10, 0, 0,
   }
 
   /* Actually make changes */
-  o_emit_pre_change_notify (toplevel, obj);
+  o_emit_pre_change_notify (obj);
 
   obj->text->x = scm_to_int (x_s);
   obj->text->y = scm_to_int (y_s);
@@ -1614,16 +1589,16 @@ SCM_DEFINE (set_text_x, "%set-text!", 10, 0, 0,
   obj->visibility = visibility;
   obj->show_name_value = show;
 
-  o_emit_change_notify (toplevel, obj);
+  o_emit_change_notify (obj);
 
   char *tmp = scm_to_utf8_string (string_s);
-  o_text_set_string (toplevel, obj, tmp);
+  o_text_set_string (obj, tmp);
   free (tmp);
 
-  o_text_recreate (toplevel, obj);
+  o_text_recreate (obj);
 
   /* Color */
-  o_set_color (toplevel, obj, scm_to_int (color_s));
+  o_set_color (obj, scm_to_int (color_s));
 
   o_page_changed (obj);
 
@@ -1759,9 +1734,8 @@ SCM_DEFINE (object_component, "%object-component", 1, 0, 0,
   SCM_ASSERT (edascm_is_object (obj_s), obj_s,
               SCM_ARG1, s_object_component);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
-  OBJECT *parent = o_get_parent (toplevel, obj);
+  OBJECT *parent = o_get_parent (obj);
 
   if (parent == NULL) return SCM_BOOL_F;
 
@@ -1781,8 +1755,7 @@ SCM_DEFINE (object_component, "%object-component", 1, 0, 0,
 SCM_DEFINE (make_path, "%make-path", 0, 0, 0,
             (), "Create a new path object")
 {
-  OBJECT *obj = geda_path_object_new (edascm_c_current_toplevel (),
-                                      OBJ_PATH, DEFAULT_COLOR, "");
+  OBJECT *obj = geda_path_object_new (OBJ_PATH, DEFAULT_COLOR, "");
 
   SCM result = edascm_from_object (obj);
 
@@ -1912,7 +1885,6 @@ SCM_DEFINE (path_remove_x, "%path-remove!", 2, 0, 0,
               SCM_ARG1, s_path_ref);
   SCM_ASSERT (scm_is_integer (index_s), index_s, SCM_ARG2, s_path_ref);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   int idx = scm_to_int (index_s);
 
@@ -1922,7 +1894,7 @@ SCM_DEFINE (path_remove_x, "%path-remove!", 2, 0, 0,
 
   }
 
-  o_emit_pre_change_notify (toplevel, obj);
+  o_emit_pre_change_notify (obj);
 
   if (idx + 1 == obj->path->num_sections) {
     /* Section is last in path */
@@ -1937,7 +1909,7 @@ SCM_DEFINE (path_remove_x, "%path-remove!", 2, 0, 0,
     obj->path->num_sections--;
   }
 
-  o_emit_change_notify (toplevel, obj);
+  o_emit_change_notify (obj);
   o_page_changed (obj);
 
   return obj_s;
@@ -1986,7 +1958,6 @@ SCM_DEFINE (path_insert_x, "%path-insert", 3, 6, 0,
   SCM_ASSERT (scm_is_integer (index_s), index_s, SCM_ARG2, s_path_insert_x);
   SCM_ASSERT (scm_is_symbol (type_s), type_s, SCM_ARG3, s_path_insert_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   PATH *path = obj->path;
   PATH_SECTION section = {(PATH_CODE) 0, 0, 0, 0, 0, 0, 0};
@@ -2031,7 +2002,7 @@ SCM_DEFINE (path_insert_x, "%path-insert", 3, 6, 0,
   }
 
   /* Start making changes */
-  o_emit_pre_change_notify (toplevel, obj);
+  o_emit_pre_change_notify (obj);
 
   /* Make sure there's enough space for the new element */
   if (path->num_sections == path->num_sections_max) {
@@ -2052,7 +2023,7 @@ SCM_DEFINE (path_insert_x, "%path-insert", 3, 6, 0,
   path->num_sections++;
   path->sections[idx] = section;
 
-  o_emit_change_notify (toplevel, obj);
+  o_emit_change_notify (obj);
   o_page_changed (obj);
 
   return obj_s;
@@ -2072,8 +2043,7 @@ SCM_DEFINE (path_insert_x, "%path-insert", 3, 6, 0,
 SCM_DEFINE (make_picture, "%make-picture", 0, 0, 0, (),
             "Create a new picture object")
 {
-  OBJECT *obj = o_picture_new (edascm_c_current_toplevel (),
-                               NULL, 0, NULL, OBJ_PICTURE,
+  OBJECT *obj = o_picture_new (NULL, 0, NULL, OBJ_PICTURE,
                                0, 0, 0, 0, 0, FALSE, TRUE);
   SCM result = edascm_from_object (obj);
 
@@ -2155,7 +2125,6 @@ SCM_DEFINE (set_picture_x, "%set-picture!", 7, 0, 0,
   SCM_ASSERT (scm_is_integer (y2_s), x1_s, SCM_ARG5, s_set_picture_x);
   SCM_ASSERT (scm_is_integer (angle_s), angle_s, SCM_ARG6, s_set_picture_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
 
   /* Angle */
@@ -2174,15 +2143,15 @@ SCM_DEFINE (set_picture_x, "%set-picture!", 7, 0, 0,
                     scm_list_1 (angle_s));
   }
 
-  o_emit_pre_change_notify (toplevel, obj);
+  o_emit_pre_change_notify (obj);
 
   obj->picture->angle = scm_to_int (angle_s);
   obj->picture->mirrored = scm_is_true (mirror_s);
-  o_picture_modify_all (toplevel, obj,
+  o_picture_modify_all (obj,
                         scm_to_int (x1_s), scm_to_int (y1_s),
                         scm_to_int (x2_s), scm_to_int (y2_s));
 
-  o_emit_change_notify (toplevel, obj);
+  o_emit_change_notify (obj);
   return obj_s;
 }
 
@@ -2234,12 +2203,11 @@ SCM_DEFINE (set_picture_data_vector_x, "%set-picture-data/vector!",
 
   gboolean status;
   GError *error = NULL;
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   gchar *filename = scm_to_utf8_string (filename_s);
   scm_dynwind_unwind_handler (g_free, filename, SCM_F_WIND_EXPLICITLY);
 
-  status = o_picture_set_from_buffer (toplevel, obj, filename,
+  status = o_picture_set_from_buffer (obj, filename,
                                       buf, len, &error);
 
   if (!status) {
@@ -2281,14 +2249,13 @@ SCM_DEFINE (translate_object_x, "%translate-object!", 3, 0, 0,
   SCM_ASSERT (scm_is_integer (dy_s), dy_s,
               SCM_ARG3, s_translate_object_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   int dx = scm_to_int (dx_s);
   int dy = scm_to_int (dy_s);
 
-  o_emit_pre_change_notify (toplevel, obj);
+  o_emit_pre_change_notify (obj);
   geda_object_translate (obj, dx, dy);
-  o_emit_change_notify (toplevel, obj);
+  o_emit_change_notify (obj);
   o_page_changed (obj);
 
   return obj_s;
@@ -2323,7 +2290,6 @@ SCM_DEFINE (rotate_object_x, "%rotate-object!", 4, 0, 0,
   SCM_ASSERT (scm_is_integer (angle_s), angle_s,
               SCM_ARG4, s_rotate_object_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   int x = scm_to_int (x_s);
   int y = scm_to_int (y_s);
@@ -2337,9 +2303,9 @@ SCM_DEFINE (rotate_object_x, "%rotate-object!", 4, 0, 0,
   SCM_ASSERT (angle % 90 == 0, angle_s,
               SCM_ARG4, s_rotate_object_x);
 
-  o_emit_pre_change_notify (toplevel, obj);
-  geda_object_rotate (toplevel, x, y, angle, obj);
-  o_emit_change_notify (toplevel, obj);
+  o_emit_pre_change_notify (obj);
+  geda_object_rotate (x, y, angle, obj);
+  o_emit_change_notify (obj);
   o_page_changed (obj);
 
   return obj_s;
@@ -2366,13 +2332,12 @@ SCM_DEFINE (mirror_object_x, "%mirror-object!", 2, 0, 0,
   SCM_ASSERT (scm_is_integer (x_s), x_s,
               SCM_ARG2, s_mirror_object_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   int x = scm_to_int (x_s);
 
-  o_emit_pre_change_notify (toplevel, obj);
-  geda_object_mirror (toplevel, x, 0, obj);
-  o_emit_change_notify (toplevel, obj);
+  o_emit_pre_change_notify (obj);
+  geda_object_mirror (x, 0, obj);
+  o_emit_change_notify (obj);
   o_page_changed (obj);
 
   return obj_s;
