@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /*!
@@ -39,15 +39,6 @@ SCM_DEFINE (edascm_make_toplevel, "%make-toplevel", 0, 0, 0,
             "Make new TOPLEVEL.")
 {
   TOPLEVEL* toplevel = s_toplevel_new();
-
-  /* Almost all calls to s_toplevel_new() are accompanied
-   * by subsequent call to i_vars_libgeda_set() in C code.
-   * It can't be done in Scheme.
-   * To get properly initialized TOPLEVEL object in Scheme
-   * code, call i_vars_libgeda_set() here:
-  */
-  i_vars_libgeda_set (toplevel);
-
   return edascm_from_toplevel (toplevel);
 }
 
@@ -95,6 +86,7 @@ SCM_DEFINE (edascm_current_toplevel, "%current-toplevel", 0, 0, 0,
 TOPLEVEL *
 edascm_c_current_toplevel ()
 {
+  g_debug ("edascm_c_current_toplevel()\n");
   SCM s_toplevel = edascm_current_toplevel ();
 
   EDASCM_ASSERT_SMOB_VALID(s_toplevel);
