@@ -1,6 +1,6 @@
 /* libleptonrenderer - Rendering Lepton EDA schematics with Cairo
  * Copyright (C) 2010-2015 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -119,9 +119,8 @@ eda_pango_renderer_class_init (EdaPangoRendererClass *klass)
 static void
 eda_pango_renderer_init (EdaPangoRenderer *renderer)
 {
-  renderer->priv = G_TYPE_INSTANCE_GET_PRIVATE (renderer,
-                                                EDA_TYPE_PANGO_RENDERER,
-                                                EdaPangoRendererPrivate);
+  renderer->priv =
+    (EdaPangoRendererPrivate*) eda_pango_renderer_get_instance_private (renderer);
 }
 
 static GObject *
