@@ -143,11 +143,9 @@ static void eda_renderer_draw_arc (EdaRenderer *renderer, OBJECT *object);
 static void eda_renderer_draw_circle (EdaRenderer *renderer, OBJECT *object);
 static void eda_renderer_draw_path (EdaRenderer *renderer, OBJECT *object);
 static void eda_renderer_draw_text (EdaRenderer *renderer, OBJECT *object);
-static int eda_renderer_get_font_descent (EdaRenderer *renderer,
-                                          PangoFontDescription *desc);
 static int eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object);
 static void eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object,
-                                             int descent, double *x, double *y);
+                                             double *x, double *y);
 static void eda_renderer_draw_picture (EdaRenderer *renderer, OBJECT *object);
 static void eda_renderer_draw_component (EdaRenderer *renderer, OBJECT *object);
 
@@ -174,14 +172,6 @@ eda_renderer_default_get_user_bounds (EdaRenderer *renderer,
                                       double *right,
                                       double *bottom);
 
-static gboolean
-eda_renderer_get_text_user_bounds (EdaRenderer *renderer,
-                                   const GedaObject *object,
-                                   double *left,
-                                   double *top,
-                                   double *right,
-                                   double *bottom);
-
 G_DEFINE_TYPE_WITH_PRIVATE (EdaRenderer, eda_renderer, G_TYPE_OBJECT);
 
 GType
@@ -273,9 +263,8 @@ eda_renderer_class_init (EdaRendererClass *klass)
 static void
 eda_renderer_init (EdaRenderer *renderer)
 {
-  renderer->priv = G_TYPE_INSTANCE_GET_PRIVATE (renderer,
-                                                EDA_TYPE_RENDERER,
-                                                EdaRendererPrivate);
+  renderer->priv =
+    (EdaRendererPrivate*) eda_renderer_get_instance_private (renderer);
 
   /* Set some sensible default options */
   renderer->priv->font_name = g_strdup (DEFAULT_FONT_NAME);
@@ -861,33 +850,12 @@ eda_renderer_draw_text (EdaRenderer *renderer, OBJECT *object)
                     -1, -1);
 }
 
-static int
-eda_renderer_get_font_descent (EdaRenderer *renderer,
-                               PangoFontDescription *desc)
-{
-  PangoFontMetrics *metrics;
-  int size = pango_font_description_get_size (desc);
-  int *key;
-
-  /* Lookup the font size in the metrics cache, and get the metrics
-   * from there if available. Otherwise, calculate the metrics and
-   * cache them. */
-  metrics = (PangoFontMetrics*) g_hash_table_lookup (renderer->priv->metrics_cache, &size);
-  if (metrics == NULL) {
-    metrics = pango_context_get_metrics (renderer->priv->pc, desc, NULL);
-    key = g_new (int, 1);
-    *key = size;
-    g_hash_table_insert (renderer->priv->metrics_cache, key, metrics);
-  }
-  return pango_font_metrics_get_descent (metrics);
-}
-
 static int
 eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object)
 {
   gint angle;
   double points_size, dx, dy;
-  int size, descent;
+  int size;
   char *draw_string;
   cairo_font_options_t *options;
   PangoFontDescription *desc;
@@ -913,7 +881,6 @@ eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object)
   desc = pango_font_description_from_string (renderer->priv->font_name);
   pango_font_description_set_size (desc, size);
   pango_layout_set_font_description (renderer->priv->pl, desc);
-  descent = eda_renderer_get_font_descent (renderer, desc);
   pango_font_description_free (desc);
 
   /* Extract text to display and Pango text attributes, and then set
@@ -928,7 +895,7 @@ eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object)
   pango_attr_list_unref (attrs);
 
   /* Calculate text position. */
-  eda_renderer_calc_text_position (renderer, object, descent, &dx, &dy);
+  eda_renderer_calc_text_position (renderer, object, &dx, &dy);
 
   cairo_translate (renderer->priv->cr, object->text->x, object->text->y);
 
@@ -951,7 +918,6 @@ eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object)
     cairo_translate (renderer->priv->cr, dx, dy);
   }
 
-  pango_cairo_update_layout (renderer->priv->cr, renderer->priv->pl);
   return TRUE;
 }
 
@@ -959,13 +925,16 @@ eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object)
  * world coordinates. */
 static void
 eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object,
-                                 int descent, double *x, double *y)
+                                 double *x, double *y)
 {
   PangoRectangle inked_rect, logical_rect;
   double temp;
   double y_lower, y_middle, y_upper;
   double x_left, x_middle, x_right;
 
+  cairo_save (renderer->priv->cr);
+  cairo_identity_matrix (renderer->priv->cr);
+  pango_cairo_update_layout (renderer->priv->cr, renderer->priv->pl);
   pango_layout_get_extents (renderer->priv->pl,
                             &inked_rect, &logical_rect);
 
@@ -973,17 +942,9 @@ eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object
   x_middle = -logical_rect.width / 2.0;
   x_right = -logical_rect.width;
 
-  /*! \note Ideally, we would be using just font / logical metrics for vertical
-   *        alignment, however this way seems to be more backward compatible
-   *        with the old gschem rendering.
-   *
-   *        Lower alignment is at the baseline of the bottom text line, whereas
-   *        middle and upper alignment is based upon the inked extents of the
-   *        entire text block.
-   */
-  y_upper  = -inked_rect.y;                     /* Top of inked extents */
-  y_middle = y_upper - inked_rect.height / 2.;  /* Middle of inked extents */
-  y_lower  = descent - logical_rect.height;     /* Baseline of bottom line */
+  y_upper  = -logical_rect.y;                     /* Top of inked extents */
+  y_middle = y_upper - logical_rect.height / 2.;  /* Middle of inked extents */
+  y_lower  = y_upper - logical_rect.height;       /* Baseline of bottom line */
 
   /* Special case flips attachment point to opposite corner when
    * the text is rotated to 180 degrees, since the drawing code
@@ -1010,6 +971,7 @@ eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object
 
   *x /= PANGO_SCALE;
   *y /= PANGO_SCALE;
+  cairo_restore (renderer->priv->cr);
 }
 
 static void
@@ -1506,7 +1468,7 @@ eda_renderer_default_get_user_bounds (EdaRenderer *renderer,
 
   switch (object->type) {
   case OBJ_TEXT:
-    return eda_renderer_get_text_user_bounds (renderer, object,
+    return eda_renderer_get_text_user_bounds (object, FALSE,
                                               left, top, right, bottom);
   case OBJ_LINE:
   case OBJ_BOX:
@@ -1526,19 +1488,19 @@ eda_renderer_default_get_user_bounds (EdaRenderer *renderer,
   }
 }
 
-static gboolean
-eda_renderer_get_text_user_bounds (EdaRenderer *renderer,
-                                   const GedaObject *object,
+gboolean
+eda_renderer_get_text_user_bounds (const GedaObject *object,
+                                   gboolean enable_hidden,
                                    double *left,
                                    double *top,
                                    double *right,
                                    double *bottom)
 {
   PangoRectangle inked_rect, logical_rect;
+  gboolean result = FALSE;
 
   /* First check if this is hidden text. */
-  if (object->visibility == INVISIBLE
-      && !EDA_RENDERER_CHECK_FLAG (renderer, FLAG_TEXT_HIDDEN)) {
+  if (object->visibility == INVISIBLE && !enable_hidden) {
     return FALSE;
   }
 
@@ -1546,29 +1508,53 @@ eda_renderer_get_text_user_bounds (EdaRenderer *renderer,
   if (object->text->disp_string == NULL)
     return FALSE;
 
+  /* Use dummy zero-sized surface */
+  cairo_surface_t *surface =
+    cairo_image_surface_create (CAIRO_FORMAT_ARGB32, 0, 0);
+  cairo_t *cr = cairo_create (surface);
+
+  EdaRenderer *renderer = eda_renderer_new (NULL, NULL);
+  g_object_set (G_OBJECT (renderer),
+                "cairo-context", cr,
+                NULL);
+  EdaConfig *cfg = eda_config_get_context_for_path (".");
+  gchar *font_name = eda_config_get_string (cfg, "schematic.gui", "font", NULL);
+  if (font_name != NULL) {
+    g_object_set (G_OBJECT (renderer),
+                  "font-name", font_name,
+                  NULL);
+  }
+  g_free (font_name);
+
   cairo_save (renderer->priv->cr);
 
   /* Set up the text and check it worked. */
-  if (!eda_renderer_prepare_text (renderer, object))
-    return FALSE;
+  if (eda_renderer_prepare_text (renderer, object)) {
 
-  /* Figure out the bounds, send them back.  Note that Pango thinks in
-   * device coordinates, but we need world coordinates. */
-  pango_layout_get_pixel_extents (renderer->priv->pl,
-                                  &inked_rect, &logical_rect);
-  *left = (double) inked_rect.x;
-  *top = (double) inked_rect.y;
-  *right = (double) inked_rect.x + inked_rect.width;
-  *bottom = (double) inked_rect.y + inked_rect.height;
-  cairo_user_to_device (renderer->priv->cr, left, top);
-  cairo_user_to_device (renderer->priv->cr, right, bottom);
+    /* Figure out the bounds, send them back.  Note that Pango thinks in
+     * device coordinates, but we need world coordinates. */
+    pango_layout_get_pixel_extents (renderer->priv->pl,
+                                    &inked_rect, &logical_rect);
+    *left = (double) logical_rect.x;
+    *top = (double) logical_rect.y;
+    *right = (double) logical_rect.x + logical_rect.width;
+    *bottom = (double) logical_rect.y + logical_rect.height;
+    cairo_user_to_device (renderer->priv->cr, left, top);
+    cairo_user_to_device (renderer->priv->cr, right, bottom);
 
-  cairo_restore (renderer->priv->cr);
+    cairo_restore (renderer->priv->cr);
 
-  cairo_device_to_user (renderer->priv->cr, left, top);
-  cairo_device_to_user (renderer->priv->cr, right, bottom);
+    cairo_device_to_user (renderer->priv->cr, left, top);
+    cairo_device_to_user (renderer->priv->cr, right, bottom);
 
-  return TRUE;
+    result = TRUE;
+  }
+
+  cairo_destroy (cr);
+  cairo_surface_destroy (surface);
+  eda_renderer_destroy (renderer);
+
+  return result;
 }
 
 
