@@ -324,8 +324,6 @@ void i_callback_options_draw_grips(gpointer data, guint callback_action, GtkWidg
 gboolean i_callback_close_wm(GtkWidget *widget, GdkEvent *event, gpointer data);
 /* i_vars.c */
 void i_vars_set(GschemToplevel *w_current);
-void i_vars_freenames();
-void i_vars_init_defaults (void);
 void i_vars_atexit_save_cache_config (gpointer user_data);
  /* m_basic.c */
 int snap_grid(GschemToplevel *w_current, int input);
@@ -508,13 +506,6 @@ void o_select_move_to_place_list(GschemToplevel *w_current);
 void o_slot_start(GschemToplevel *w_current, OBJECT *object);
 void o_slot_end(GschemToplevel *w_current, OBJECT *object, const char *string);
 /* o_text.c */
-gboolean
-o_text_get_rendered_bounds (void *user_data,
-                            const GedaObject *o_current,
-                            gint *min_x,
-                            gint *min_y,
-                            gint *max_x,
-                            gint *max_y);
 void o_text_prepare_place(GschemToplevel *w_current, char *text, int color, int align, int rotate, int size);
 void o_text_change(GschemToplevel *w_current, OBJECT *object, char *string, int visibility, int show);
 /* o_undo.c */
@@ -610,7 +601,13 @@ void x_compselect_deselect (GschemToplevel *w_current);
 /* x_fileselect.c */
 void x_fileselect_open(GschemToplevel *w_current);
 gboolean x_fileselect_save(GschemToplevel *w_current, PAGE* page, gboolean* result);
-int x_fileselect_load_backup(void *user_data, GString *message);
+
+gboolean
+schematic_file_open (GschemToplevel *w_current,
+                     PAGE *page,
+                     const gchar *filename,
+                     GError **err);
+
 /* x_fstylecb.c */
 GtkWidget* x_fstylecb_new ();
 int x_fstylecb_get_index (GtkWidget *widget);
@@ -661,8 +658,6 @@ void x_rc_parse_gschem (TOPLEVEL *toplevel, const gchar *rcfile);
 GtkWidget* gschem_rotation_combo_new ();
 int gschem_rotation_combo_get_angle (GtkWidget *widget);
 void gschem_rotation_combo_set_angle (GtkWidget *widget, int angle);
-/* x_script.c */
-void setup_script_selector(GschemToplevel *w_current);
 /* x_stroke.c */
 void x_stroke_init (void);
 void x_stroke_free (void);
@@ -705,6 +700,7 @@ void x_widgets_show_find_text_state (GschemToplevel* w_current);
 void x_widgets_show_color_edit (GschemToplevel* w_current);
 void x_widgets_show_font_select (GschemToplevel* w_current);
 void x_widgets_show_page_select (GschemToplevel* w_current);
+void x_widgets_destroy_dialogs (GschemToplevel* w_current);
 
 /* x_tabs.c */
 gboolean x_tabs_enabled();
@@ -724,6 +720,40 @@ void x_tabs_dbg_pages_dump (GschemToplevel* w_current);
 /* color_edit_widget.c */
 void color_edit_widget_update (GschemToplevel* w_current);
 
+/* schematic_hierarchy.c */
+PAGE*
+s_hierarchy_down_schematic_single (GschemToplevel *w_current,
+                                   const gchar *filename,
+                                   PAGE *parent,
+                                   int page_control,
+                                   int flag,
+                                   GError **err);
+void
+s_hierarchy_down_symbol (GschemToplevel *w_current,
+                         const CLibSymbol *symbol,
+                         PAGE *parent);
+PAGE*
+s_hierarchy_find_up_page (GedaPageList *page_list,
+                          PAGE *current_page);
+PAGE*
+s_hierarchy_load_subpage (GschemToplevel *w_current,
+                          PAGE *page,
+                          const char *filename,
+                          GError **error);
+GList*
+s_hierarchy_traversepages (GschemToplevel *w_current,
+                           PAGE *p_current,
+                           gint flags);
+gint
+s_hierarchy_print_page (PAGE *p_current,
+                        void * data);
+PAGE*
+s_hierarchy_find_prev_page (GedaPageList *page_list,
+                            PAGE *current_page);
+PAGE*
+s_hierarchy_find_next_page (GedaPageList *page_list,
+                            PAGE *current_page);
+
 
 #endif /* LEPTON_PROTOTYPE_H_ */
 
