@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
  */
 /*! \todo STILL NEED to clean up line lengths in aa and tr */
 #include <config.h>
-#include <version.h>
 
 #include <stdio.h>
 #ifdef HAVE_STDLIB_H
@@ -68,9 +67,9 @@ void arc_angle_dialog_response(GtkWidget *w, gint response,
     arc_object = (OBJECT*) g_object_get_data(G_OBJECT(w_current->aawindow),"arc_object");
 
     if (arc_object != NULL) {
-      geda_arc_object_modify (w_current->toplevel, arc_object, radius, 0, ARC_RADIUS);
-      geda_arc_object_modify (w_current->toplevel, arc_object, start_angle, 0, ARC_START_ANGLE);
-      geda_arc_object_modify (w_current->toplevel, arc_object, sweep_angle, 0, ARC_SWEEP_ANGLE);
+      geda_arc_object_modify (arc_object, radius, 0, ARC_RADIUS);
+      geda_arc_object_modify (arc_object, start_angle, 0, ARC_START_ANGLE);
+      geda_arc_object_modify (arc_object, sweep_angle, 0, ARC_SWEEP_ANGLE);
     } else {
       o_arc_end4(w_current, radius, start_angle, sweep_angle);
     }
