@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,7 +52,8 @@ enum
   PROP_HADJUSTMENT,
   PROP_PAGE,
   PROP_PAGE_GEOMETRY,
-  PROP_VADJUSTMENT
+  PROP_VADJUSTMENT,
+  PROP_SHOW_HIDDEN_TEXT
 };
 
 
@@ -206,6 +207,18 @@ event_unrealize(GtkWidget *widget, gpointer unused)
 }
 
 
+/*! \brief Event handler for window unrealized
+ */
+static void
+event_toggle_hidden_text (GtkWidget *widget, gpointer unused)
+{
+  GschemPageView *view = GSCHEM_PAGE_VIEW (widget);
+
+  g_return_if_fail (view != NULL);
+
+  view->show_hidden_text = !view->show_hidden_text;
+}
+
 
 /*! \brief Finalize object
  */
@@ -255,6 +268,10 @@ get_property (GObject *object, guint param_id, GValue *value, GParamSpec *pspec)
       g_value_set_object (value, gschem_page_view_get_vadjustment (view));
       break;
 
+    case PROP_SHOW_HIDDEN_TEXT:
+      g_value_set_boolean (value, gschem_page_view_get_show_hidden_text (view));
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
   }
@@ -312,6 +329,15 @@ gschem_page_view_class_init (GschemPageViewClass *klass)
                                                         (GParamFlags) (G_PARAM_READWRITE
                                                                        | G_PARAM_CONSTRUCT)));
 
+  g_object_class_install_property (G_OBJECT_CLASS (klass),
+                                   PROP_SHOW_HIDDEN_TEXT,
+                                   g_param_spec_boolean ("show-hidden-text",
+                                                        "Show hidden text",
+                                                        "Show hidden text in page-view",
+                                                        FALSE,
+                                                        (GParamFlags) (G_PARAM_READWRITE |
+                                                                       G_PARAM_CONSTRUCT)));
+
   GTK_WIDGET_CLASS (klass)->set_scroll_adjustments_signal = g_signal_new (
     "set-scroll-adjustments",
     G_OBJECT_CLASS_TYPE (klass),
@@ -335,6 +361,17 @@ gschem_page_view_class_init (GschemPageViewClass *klass)
     g_cclosure_marshal_VOID__VOID,
     G_TYPE_NONE,
     0);
+
+  g_signal_new ("toggle-hidden-text",
+                G_OBJECT_CLASS_TYPE (klass),
+                (GSignalFlags) (G_SIGNAL_RUN_LAST), /*signal_flags */
+                0, /*class_offset */
+                NULL, /* accumulator */
+                NULL, /* accu_data */
+                NULL,
+                G_TYPE_NONE,
+                0 /* n_params */
+                );
 }
 
 
@@ -402,20 +439,20 @@ gschem_page_view_get_page_geometry (GschemPageView *view)
   if (geometry == NULL) {
     geometry = gschem_page_geometry_new_with_values (screen_width,
                                                      screen_height,
-                                                     page->toplevel->init_left,
-                                                     page->toplevel->init_top,
-                                                     page->toplevel->init_right,
-                                                     page->toplevel->init_bottom,
-                                                     page->toplevel->init_left,
-                                                     page->toplevel->init_top,
-                                                     page->toplevel->init_right,
-                                                     page->toplevel->init_bottom);
+                                                     WORLD_DEFAULT_LEFT,
+                                                     WORLD_DEFAULT_TOP,
+                                                     WORLD_DEFAULT_RIGHT,
+                                                     WORLD_DEFAULT_BOTTOM,
+                                                     WORLD_DEFAULT_LEFT,
+                                                     WORLD_DEFAULT_TOP,
+                                                     WORLD_DEFAULT_RIGHT,
+                                                     WORLD_DEFAULT_BOTTOM);
 
     geometry_cache_insert (view, page, geometry);
 
     gschem_page_geometry_zoom_extents (geometry,
-                                       page->toplevel,
-                                       s_page_objects (page));
+                                       s_page_objects (page),
+                                       view->show_hidden_text);
   }
   else {
 
@@ -443,6 +480,14 @@ gschem_page_view_get_page_geometry (GschemPageView *view)
 }
 
 
+gboolean
+gschem_page_view_get_show_hidden_text (GschemPageView *view)
+{
+  g_return_val_if_fail (view != NULL, FALSE);
+
+  return view->show_hidden_text;
+}
+
 
 /*! \brief Get/register GschemPageView type.
  */
@@ -514,50 +559,6 @@ gschem_page_view_invalidate_all (GschemPageView *view)
 }
 
 
-
-/*! \brief Schedule redraw of the given object
- *
- *  \param [in,out] view   The Gschem page view to redraw
- *  \param [in]     object The object to redraw
- */
-void
-gschem_page_view_invalidate_object (GschemPageView *view, OBJECT *object)
-{
-  g_return_if_fail (object != NULL);
-  g_return_if_fail (view != NULL);
-
-  if (!gtk_widget_get_realized (GTK_WIDGET (view))) {
-    return;
-  }
-
-  PAGE *page = gschem_page_view_get_page (view);
-
-  if (page != NULL) {
-    gboolean success;
-    int world_bottom;
-    int world_right;
-    int world_left;
-    int world_top;
-
-    success = geda_object_calculate_visible_bounds (page->toplevel,
-                                                    object,
-                                                    &world_left,
-                                                    &world_top,
-                                                    &world_right,
-                                                    &world_bottom);
-
-    if (success) {
-      gschem_page_view_invalidate_world_rect (view,
-                                              world_left,
-                                              world_top,
-                                              world_right,
-                                              world_bottom);
-    }
-  }
-}
-
-
-
 /*! \brief Schedule redraw of the given rectange
  *
  *  \param [in,out] view   The Gschem page view to redraw
@@ -608,10 +609,10 @@ gschem_page_view_invalidate_screen_rect (GschemPageView *view, int left, int top
 void
 gschem_page_view_invalidate_world_rect (GschemPageView *view, int left, int top, int right, int bottom)
 {
-  int screen_bottom;
-  int screen_right;
-  int screen_left;
-  int screen_top;
+  int screen_bottom = 0;
+  int screen_right = 0;
+  int screen_left = 0;
+  int screen_top = 0;
 
   g_return_if_fail (view != NULL);
 
@@ -663,6 +664,11 @@ gschem_page_view_init (GschemPageView *view)
                    "unrealize",
                    G_CALLBACK (event_unrealize),
                    NULL);
+
+  g_signal_connect (view,
+                   "toggle-hidden-text",
+                   G_CALLBACK (event_toggle_hidden_text),
+                   NULL);
 }
 
 
@@ -1007,6 +1013,15 @@ gschem_page_view_set_vadjustment (GschemPageView *view, GtkAdjustment *vadjustme
 
 
 
+void
+gschem_page_view_set_show_hidden_text (GschemPageView *view,
+                                       gboolean show_hidden_text)
+{
+  g_return_if_fail (view != NULL);
+  view->show_hidden_text = show_hidden_text;
+}
+
+
 /*! \brief Signal handler for a horizontal scroll adjustment change
  */
 static void
@@ -1057,6 +1072,11 @@ set_property (GObject *object, guint param_id, const GValue *value, GParamSpec *
                                         GTK_ADJUSTMENT (g_value_get_object (value)));
       break;
 
+    case PROP_SHOW_HIDDEN_TEXT:
+      gschem_page_view_set_show_hidden_text (view,
+                                             g_value_get_boolean (value));
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
   }
@@ -1297,7 +1317,7 @@ gschem_page_view_zoom_extents (GschemPageView *view, const GList *objects)
     temp = s_page_objects (gschem_page_view_get_page (view));
   }
 
-  gschem_page_geometry_zoom_extents (geometry, page->toplevel, temp);
+  gschem_page_geometry_zoom_extents (geometry, temp, view->show_hidden_text);
 
   /* Trigger a motion event to update the objects being drawn */
   x_event_faked_motion (view, NULL);
@@ -1329,8 +1349,8 @@ gschem_page_view_zoom_object (GschemPageView *view, OBJECT *object)
   g_return_if_fail (object->page != NULL);
   g_return_if_fail (object->page->toplevel != NULL);
 
-  success = geda_object_calculate_visible_bounds (object->page->toplevel,
-                                                  object,
+  success = geda_object_calculate_visible_bounds (object,
+                                                  view->show_hidden_text,
                                                   &x[0],
                                                   &y[0],
                                                   &x[1],
