@@ -132,18 +132,56 @@ void i_callback_toolbar_file_open(GtkWidget* widget, gpointer data)
   i_callback_file_open (data, 0, widget);
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
+
+
+/*! \brief Open the "Execute Script" dialog, execute the selected Scheme file
  */
 DEFINE_I_CALLBACK(file_script)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-
   g_return_if_fail (w_current != NULL);
-  setup_script_selector(w_current);
-}
+
+  GtkWidget* dialog = gtk_file_chooser_dialog_new(
+    _("Execute Script"),
+    GTK_WINDOW (w_current->main_window),
+    GTK_FILE_CHOOSER_ACTION_OPEN,
+    GTK_STOCK_CANCEL,  GTK_RESPONSE_CANCEL,
+    GTK_STOCK_EXECUTE, GTK_RESPONSE_ACCEPT,
+    NULL);
+
+  /* Filter for Scheme files:
+  */
+  GtkFileFilter* filter_scm = gtk_file_filter_new();
+  gtk_file_filter_set_name (filter_scm, _("Scheme files (*.scm)"));
+  gtk_file_filter_add_pattern (filter_scm, "*.scm");
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter_scm);
+
+  /* Filter for all files:
+  */
+  GtkFileFilter* filter_all = gtk_file_filter_new();
+  gtk_file_filter_set_name (filter_all, _("All files"));
+  gtk_file_filter_add_pattern (filter_all, "*");
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter_all);
+
+  gtk_dialog_set_alternative_button_order(
+    GTK_DIALOG (dialog),
+    GTK_RESPONSE_ACCEPT,
+    GTK_RESPONSE_CANCEL,
+    -1);
+
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+  {
+    gchar* filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+    s_log_message (_("Executing Guile script [%s]"), filename);
+    g_read_file (w_current->toplevel, filename, NULL);
+
+    g_free (filename);
+  }
+
+  gtk_widget_destroy (dialog);
+
+} /* i_callback_file_script() */
 
 
 
@@ -2142,12 +2180,12 @@ DEFINE_I_CALLBACK(hierarchy_down_schematic)
     while(current_filename != NULL) {
       GError *err = NULL;
       s_log_message(_("Searching for source [%1$s]"), current_filename);
-      child = s_hierarchy_down_schematic_single(gschem_toplevel_get_toplevel (w_current),
-                                                current_filename,
-                                                parent,
-                                                page_control,
-                                                HIERARCHY_NORMAL_LOAD,
-                                                &err);
+      child = s_hierarchy_down_schematic_single (w_current,
+                                                 current_filename,
+                                                 parent,
+                                                 page_control,
+                                                 HIERARCHY_NORMAL_LOAD,
+                                                 &err);
       gschem_toplevel_page_changed (w_current);
 
       /* s_hierarchy_down_schematic_single() will not zoom the loaded page.
@@ -2280,7 +2318,7 @@ DEFINE_I_CALLBACK(hierarchy_down_symbol)
 
   TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (w_current);
 
-  s_hierarchy_down_symbol (toplevel, sym, toplevel->page_current);
+  s_hierarchy_down_symbol (w_current, sym, toplevel->page_current);
   gschem_toplevel_page_changed (w_current);
 
   x_window_set_current_page (w_current, toplevel->page_current);
@@ -2722,7 +2760,7 @@ DEFINE_I_CALLBACK(cancel)
    * action, the list (refering to objects on the page) would
    * already have been cleared in o_move_cancel(), so this is OK. */
   if (toplevel->page_current != NULL) {
-    geda_object_list_delete (toplevel, toplevel->page_current->place_list);
+    geda_object_list_delete (toplevel->page_current->place_list);
     toplevel->page_current->place_list = NULL;
   }
 
