@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -92,16 +92,20 @@ void o_redraw_rect (GschemToplevel *w_current,
   world_rect->upper_x = ceil (upper_x);
   world_rect->upper_y = ceil (upper_y);
 
+  gboolean show_hidden_text =
+    gschem_toplevel_get_show_hidden_text (w_current);
+
   obj_list = s_page_objects_in_regions (toplevel,
                                         page,
                                         world_rect,
-                                        1);
+                                        1,
+                                        show_hidden_text);
 
   g_free (world_rect);
 
   /* Set up renderer based on configuration in w_current */
   render_flags = EDA_RENDERER_FLAG_HINTING;
-  if (toplevel->show_hidden_text)
+  if (show_hidden_text)
     render_flags |= EDA_RENDERER_FLAG_TEXT_HIDDEN;
   if (w_current->fast_mousepan &&
       gschem_toplevel_get_current_page_view(w_current)->doing_pan)
@@ -366,7 +370,7 @@ int o_redraw_cleanstates(GschemToplevel *w_current)
       /* Free the place list and its contents. If we were in a move
        * action, the list (refering to objects on the page) would
        * already have been cleared in o_move_cancel(), so this is OK. */
-      geda_object_list_delete (toplevel, toplevel->page_current->place_list);
+      geda_object_list_delete (toplevel->page_current->place_list);
       toplevel->page_current->place_list = NULL;
 
       i_action_stop (w_current);
@@ -449,14 +453,20 @@ void o_invalidate (GschemToplevel *w_current, OBJECT *object)
 
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   PAGE *page = gschem_page_view_get_page (page_view);
+  gboolean show_hidden_text =
+    gschem_toplevel_get_show_hidden_text (w_current);
 
   /* this function may be called before a page is created */
   if (page == NULL) {
     return;
   }
 
-  if (geda_object_calculate_visible_bounds(page->toplevel, object, &left,  &top,
-                                                       &right, &bottom)) {
+  if (geda_object_calculate_visible_bounds (object,
+                                            show_hidden_text,
+                                            &left,
+                                            &top,
+                                            &right,
+                                            &bottom)) {
     gschem_page_view_invalidate_world_rect (page_view,
                                             left,
                                             top,
@@ -485,8 +495,15 @@ void o_invalidate_glist (GschemToplevel *w_current, GList *list)
   PAGE *page = gschem_page_view_get_page (page_view);
   g_return_if_fail (page != NULL);
 
-  if (world_get_object_glist_bounds (page->toplevel, list, &left,  &top,
-                                                     &right, &bottom)) {
+  gboolean show_hidden_text =
+    gschem_toplevel_get_show_hidden_text (w_current);
+
+  if (world_get_object_glist_bounds (list,
+                                     show_hidden_text,
+                                     &left,
+                                     &top,
+                                     &right,
+                                     &bottom)) {
     gschem_page_view_invalidate_world_rect (page_view,
                                             left,
                                             top,
