@@ -222,10 +222,10 @@ void o_rotate_world_update(GschemToplevel *w_current,
   for (o_iter = list; o_iter != NULL; o_iter = g_list_next (o_iter)) {
     o_current = (OBJECT*) o_iter->data;
 
-    s_conn_remove_object_connections (toplevel, o_current);
+    s_conn_remove_object_connections (o_current);
   }
 
-  geda_object_list_rotate ( list, centerx, centery, angle, toplevel );
+  geda_object_list_rotate (list, centerx, centery, angle);
 
   /* Find connected objects, adding each object in turn back to the
    * connection list. We only _really_ want those objects connected
@@ -280,10 +280,10 @@ void o_mirror_world_update(GschemToplevel *w_current, int centerx, int centery,
   for (o_iter = list; o_iter != NULL; o_iter = g_list_next (o_iter)) {
     o_current = (OBJECT*) o_iter->data;
 
-    s_conn_remove_object_connections (toplevel, o_current);
+    s_conn_remove_object_connections (o_current);
   }
 
-  geda_object_list_mirror ( list, centerx, centery, toplevel );
+  geda_object_list_mirror (list, centerx, centery);
 
   /* Find connected objects, adding each object in turn back to the
    * connection list. We only _really_ want those objects connected
@@ -316,17 +316,16 @@ void o_mirror_world_update(GschemToplevel *w_current, int centerx, int centery,
 void o_edit_show_hidden_lowlevel (GschemToplevel *w_current,
                                   const GList *o_list)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
   OBJECT *o_current;
   const GList *iter;
 
   iter = o_list;
   while (iter != NULL) {
     o_current = (OBJECT *)iter->data;
-    if (o_current->type == OBJ_TEXT && !o_is_visible (toplevel, o_current)) {
+    if (o_current->type == OBJ_TEXT && !o_is_visible (o_current)) {
 
       /* don't toggle the visibility flag */
-      o_text_recreate (toplevel, o_current);
+      o_text_recreate (o_current);
     }
 
     if (o_current->type == OBJ_COMPONENT || o_current->type == OBJ_PLACEHOLDER) {
@@ -350,13 +349,14 @@ void o_edit_show_hidden (GschemToplevel *w_current, const GList *o_list)
 
   /* toggle show_hidden_text variable, which when it is true */
   /* means that hidden text IS drawn */
-  w_current->toplevel->show_hidden_text = !w_current->toplevel->show_hidden_text;
+  g_signal_emit_by_name (gschem_toplevel_get_current_page_view (w_current),
+                         "toggle-hidden-text");
   i_show_state(w_current, NULL); /* update screen status */
 
   o_edit_show_hidden_lowlevel(w_current, o_list);
   gschem_page_view_invalidate_all (gschem_toplevel_get_current_page_view (w_current));
 
-  if (w_current->toplevel->show_hidden_text) {
+  if (gschem_toplevel_get_show_hidden_text (w_current)) {
     s_log_message(_("Hidden text is now visible"));
   } else {
     s_log_message(_("Hidden text is now invisible"));
@@ -383,9 +383,9 @@ void o_edit_hide_specific_text (GschemToplevel *w_current,
     if (o_current->type == OBJ_TEXT) {
       const gchar *str = geda_text_object_get_string (o_current);
       if (!strncmp (stext, str, strlen (stext))) {
-        if (o_is_visible (toplevel, o_current)) {
-          o_set_visibility (toplevel, o_current, INVISIBLE);
-          o_text_recreate(toplevel, o_current);
+        if (o_is_visible (o_current)) {
+          o_set_visibility (o_current, INVISIBLE);
+          o_text_recreate (o_current);
 
           gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
         }
@@ -417,9 +417,9 @@ void o_edit_show_specific_text (GschemToplevel *w_current,
     if (o_current->type == OBJ_TEXT) {
       const gchar *str = geda_text_object_get_string (o_current);
       if (!strncmp (stext, str, strlen (stext))) {
-        if (!o_is_visible (toplevel, o_current)) {
-          o_set_visibility (toplevel, o_current, VISIBLE);
-          o_text_recreate(toplevel, o_current);
+        if (!o_is_visible (o_current)) {
+          o_set_visibility (o_current, VISIBLE);
+          o_text_recreate (o_current);
 
           gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
         }
@@ -473,21 +473,24 @@ o_update_component (GschemToplevel *w_current, OBJECT *o_current)
   }
 
   /* Unselect the old object. */
-  o_selection_remove (toplevel, page->selection_list, o_current);
+  o_selection_remove (page->selection_list, o_current);
 
   /* Create new object and set embedded */
-  o_new = o_component_new (toplevel, OBJ_COMPONENT, DEFAULT_COLOR,
+  o_new = o_component_new (toplevel->page_current,
+                           OBJ_COMPONENT,
+                           DEFAULT_COLOR,
                            o_current->component->x,
                            o_current->component->y,
                            o_current->component->angle,
                            o_current->component->mirror,
-                           clib, o_current->component_basename,
+                           clib,
+                           o_current->component_basename,
                            1);
   if (o_component_is_embedded (o_current)) {
     o_embed (o_new);
   }
 
-  new_attribs = o_component_promote_attribs (toplevel, o_new);
+  new_attribs = o_component_promote_attribs (o_new);
 
   /* Cull any attributes from new COMPONENT that are already attached to
    * old COMPONENT. Note that the new_attribs list is kept consistent by
@@ -506,8 +509,8 @@ o_update_component (GschemToplevel *w_current, OBJECT *o_current)
 
     value = o_attrib_search_attached_attribs_by_name (o_current, name, 0);
     if (value != NULL) {
-      o_attrib_remove (toplevel, &o_new->attribs, attr_new);
-      s_delete_object (toplevel, attr_new);
+      o_attrib_remove (&o_new->attribs, attr_new);
+      s_delete_object (attr_new);
       iter->data = NULL;
     }
 
@@ -518,22 +521,22 @@ o_update_component (GschemToplevel *w_current, OBJECT *o_current)
 
   /* Detach attributes from old OBJECT and attach to new OBJECT */
   old_attribs = g_list_copy (o_current->attribs);
-  o_attrib_detach_all (toplevel, o_current);
-  o_attrib_attach_list (toplevel, old_attribs, o_new, 1);
+  o_attrib_detach_all (o_current);
+  o_attrib_attach_list (old_attribs, o_new, 1);
   g_list_free (old_attribs);
 
   /* Add new attributes to page */
-  s_page_append_list (toplevel, page, new_attribs);
+  s_page_append_list (page, new_attribs);
 
   /* Update pinnumbers for current slot */
-  s_slot_update_object (toplevel, o_new);
+  s_slot_update_object (o_new);
 
   /* Replace old OBJECT with new OBJECT */
-  s_page_replace (toplevel, page, o_current, o_new);
-  s_delete_object (toplevel, o_current);
+  s_page_replace (page, o_current, o_new);
+  s_delete_object (o_current);
 
   /* Select new OBJECT */
-  o_selection_add (toplevel, page->selection_list, o_new);
+  o_selection_add (page->selection_list, o_new);
 
   /* mark the page as modified */
   gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
@@ -634,8 +637,7 @@ void o_autosave_backups(GschemToplevel *w_current)
           umask(saved_umask);
         }
 
-        if (o_save (toplevel,
-                    s_page_objects (toplevel->page_current),
+        if (o_save (s_page_objects (toplevel->page_current),
                     backup_filename, NULL)) {
 
           p_current->ops_since_last_backup = 0;
