@@ -238,8 +238,12 @@ void o_net_find_magnetic(GschemToplevel *w_current,
       int left, top, right, bottom;
       o_current = (OBJECT*) iter2->data;
 
-      if (!geda_object_calculate_visible_bounds(page->toplevel, o_current,
-                                                &left, &top, &right, &bottom) ||
+      if (!geda_object_calculate_visible_bounds (o_current,
+                                                 FALSE,
+                                                 &left,
+                                                 &top,
+                                                 &right,
+                                                 &bottom) ||
           !visible (w_current, left, top, right, bottom))
         continue; /* skip invisible objects */
 
@@ -511,10 +515,10 @@ void o_net_end(GschemToplevel *w_current, int w_x, int w_y)
 
   if (!primary_zero_length ) {
   /* create primary net */
-      new_net = geda_net_object_new (page->toplevel, OBJ_NET, NET_COLOR,
+      new_net = geda_net_object_new (OBJ_NET, NET_COLOR,
                                      w_current->first_wx, w_current->first_wy,
                                      w_current->second_wx, w_current->second_wy);
-      s_page_append (page->toplevel, page, new_net);
+      s_page_append (page, new_net);
 
       added_objects = g_list_prepend (added_objects, new_net);
 
@@ -546,10 +550,10 @@ void o_net_end(GschemToplevel *w_current, int w_x, int w_y)
   if (!secondary_zero_length && !found_primary_connection) {
 
       /* Add secondary net */
-      new_net = geda_net_object_new (page->toplevel, OBJ_NET, NET_COLOR,
+      new_net = geda_net_object_new (OBJ_NET, NET_COLOR,
                                      w_current->second_wx, w_current->second_wy,
                                      w_current->third_wx, w_current->third_wy);
-      s_page_append (page->toplevel, page, new_net);
+      s_page_append (page, new_net);
 
       added_objects = g_list_prepend (added_objects, new_net);
 
@@ -1034,7 +1038,7 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
   }
 
   if (made_changes) {
-    s_conn_remove_object_connections (page->toplevel, net_obj);
+    s_conn_remove_object_connections (net_obj);
 
     if (w_current->bus_ripper_type == COMP_BUS_RIPPER) {
       GList *symlist =
@@ -1047,21 +1051,21 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
 
     for (i = 0; i < ripper_count; i++) {
       if (w_current->bus_ripper_type == NET_BUS_RIPPER) {
-        new_obj = geda_net_object_new (page->toplevel, OBJ_NET, NET_COLOR,
+        new_obj = geda_net_object_new (OBJ_NET, NET_COLOR,
                                        rippers[i].x[0], rippers[i].y[0],
                                        rippers[i].x[1], rippers[i].y[1]);
-        s_page_append (page->toplevel, page, new_obj);
+        s_page_append (page, new_obj);
       } else {
 
         if (rippersym != NULL) {
-          new_obj = o_component_new (page->toplevel, OBJ_COMPONENT, DEFAULT_COLOR,
+          new_obj = o_component_new (page, OBJ_COMPONENT, DEFAULT_COLOR,
                                      rippers[i].x[0], rippers[i].y[0],
                                      component_angle, 0,
                                      rippersym,
                                      w_current->bus_ripper_symname, 1);
-          s_page_append_list (page->toplevel, page,
-                              o_component_promote_attribs (page->toplevel, new_obj));
-          s_page_append (page->toplevel, page, new_obj);
+          s_page_append_list (page,
+                              o_component_promote_attribs (new_obj));
+          s_page_append (page, new_obj);
         } else {
           s_log_message(_("Bus ripper symbol [%1$s] was not found in any component library"),
                         w_current->bus_ripper_symname);
