@@ -113,12 +113,11 @@ void o_slot_end(GschemToplevel *w_current, OBJECT *object, const char *string)
   g_free (slot_value);
 
   if (o_slot != NULL && !o_attrib_is_inherited (o_slot)) {
-    o_text_set_string (toplevel, o_slot, string);
+    o_text_set_string (o_slot, string);
   } else {
     /* here you need to do the add the slot
        attribute since it doesn't exist */
-    new_obj = geda_text_object_new (toplevel,
-                                    ATTRIBUTE_COLOR,
+    new_obj = geda_text_object_new (ATTRIBUTE_COLOR,
                                     object->component->x,
                                     object->component->y,
                                     LOWER_LEFT,
@@ -127,16 +126,16 @@ void o_slot_end(GschemToplevel *w_current, OBJECT *object, const char *string)
                                     10,
                                     INVISIBLE,
                                     SHOW_NAME_VALUE);
-    s_page_append (toplevel, toplevel->page_current, new_obj);
+    s_page_append (toplevel->page_current, new_obj);
 
     /* manually attach attribute */
-    o_attrib_attach (toplevel, new_obj, object, FALSE);
+    o_attrib_attach (new_obj, object, FALSE);
 
     /* Call add-objects-hook */
     g_run_hook_object (w_current, "%add-objects-hook", new_obj);
   }
 
-  s_slot_update_object (toplevel, object);
+  s_slot_update_object (object);
 
   gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
   g_free (value);
