@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -569,7 +569,7 @@ widget_create (PageSelectWidget* pagesel)
                       hbox, FALSE, TRUE, 0);
   gtk_widget_show (hbox);
 
-  GtkWidget* chkbox = gtk_check_button_new_with_mnemonic ("_Show full paths");
+  GtkWidget* chkbox = gtk_check_button_new_with_mnemonic (_("Show _full paths"));
   gtk_box_pack_start (GTK_BOX (hbox), chkbox, FALSE, TRUE, 5);
 
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox),
