@@ -134,8 +134,7 @@ x_compselect_callback_response (GtkDialog *dialog,
           if (w_current->rubber_visible)
             o_place_invalidate_rubber (w_current, FALSE);
           w_current->rubber_visible = 0;
-          geda_object_list_delete (toplevel,
-                                   toplevel->page_current->place_list);
+          geda_object_list_delete (toplevel->page_current->place_list);
           toplevel->page_current->place_list = NULL;
         } else {
           /* Cancel whatever other action is currently in progress */
@@ -1445,7 +1444,7 @@ compselect_constructor (GType type,
   /* dialog initialization */
   g_object_set (object,
                 /* GtkWindow */
-                "title",           _("Select Component..."),
+                "title",           _("Add Component"),
                 "default-height",  300,
                 "default-width",   400,
                 NULL);
