@@ -550,7 +550,7 @@ void x_image_setup (GschemToplevel *w_current)
   gtk_widget_show(vbox2);
 
   /* Create the dialog */
-  dialog = gtk_file_chooser_dialog_new (_("Write image..."),
+  dialog = gtk_file_chooser_dialog_new (_("Write Image"),
       GTK_WINDOW(w_current->main_window),
       GTK_FILE_CHOOSER_ACTION_SAVE,
       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -728,16 +728,17 @@ GdkPixbuf
   rect.width = right - origin_x;
   rect.height = bottom - origin_y;
 
-  new_geometry = gschem_page_geometry_new_with_values (width,
-                                                   height,
-                                                   old_geometry->viewport_left,
-                                                   old_geometry->viewport_top,
-                                                   old_geometry->viewport_right,
-                                                   old_geometry->viewport_bottom,
-                                                   toplevel.init_left,
-                                                   toplevel.init_top,
-                                                   toplevel.init_right,
-                                                   toplevel.init_bottom);
+  new_geometry =
+    gschem_page_geometry_new_with_values (width,
+                                          height,
+                                          old_geometry->viewport_left,
+                                          old_geometry->viewport_top,
+                                          old_geometry->viewport_right,
+                                          old_geometry->viewport_bottom,
+                                          WORLD_DEFAULT_LEFT,
+                                          WORLD_DEFAULT_TOP,
+                                          WORLD_DEFAULT_RIGHT,
+                                          WORLD_DEFAULT_BOTTOM);
 
   o_redraw_rect (&new_w_current,
                  window,
