@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 2013 Ales Hvezda
  * Copyright (C) 2013-2015 gEDA Contributors
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -430,7 +430,7 @@ text_input_dialog (GschemToplevel *w_current)
                                 /* GtkContainer */
                                 "border-width",     DIALOG_BORDER_SPACING,
                                 /* GtkWindow */
-                                "title",            _("Text Entry..."),
+                                "title",            _("Add Text"),
                                 "default-width",    320,
                                 "default-height",   350,
                                 "window-position",  GTK_WIN_POS_MOUSE,
