@@ -298,14 +298,19 @@ x_window_find_text (GtkWidget *widget, gint response, GschemToplevel *w_current)
   g_return_if_fail (w_current != NULL);
   g_return_if_fail (w_current->toplevel != NULL);
 
+  gboolean show_hidden_text =
+    gschem_toplevel_get_show_hidden_text (w_current);
+
   switch (response) {
   case GTK_RESPONSE_OK:
     count = gschem_find_text_state_find (
+        w_current,
         GSCHEM_FIND_TEXT_STATE (w_current->find_text_state),
         geda_list_get_glist (w_current->toplevel->pages),
         gschem_find_text_widget_get_find_type (GSCHEM_FIND_TEXT_WIDGET (w_current->find_text_widget)),
         gschem_find_text_widget_get_find_text_string (GSCHEM_FIND_TEXT_WIDGET (w_current->find_text_widget)),
-        gschem_find_text_widget_get_descend (GSCHEM_FIND_TEXT_WIDGET (w_current->find_text_widget)));
+        gschem_find_text_widget_get_descend (GSCHEM_FIND_TEXT_WIDGET (w_current->find_text_widget)),
+        show_hidden_text);
 
     if (count > 0)
     {
@@ -569,7 +574,6 @@ void x_window_create_main(GschemToplevel *w_current)
  */
 void x_window_close(GschemToplevel *w_current)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
   gboolean last_window = FALSE;
 
   /* If we're closing whilst inside an action, re-wind the
@@ -588,10 +592,9 @@ void x_window_close(GschemToplevel *w_current)
 
   w_current->dont_invalidate = TRUE;
 
-  /* close all the dialog boxes */
-  if (w_current->sowindow)
-  gtk_widget_destroy(w_current->sowindow);
+  x_widgets_destroy_dialogs (w_current);
 
+  /* close all the dialog boxes */
   if (w_current->cswindow)
   gtk_widget_destroy(w_current->cswindow);
 
@@ -625,17 +628,6 @@ void x_window_close(GschemToplevel *w_current)
     geometry_save (w_current);
   }
 
-  if (toplevel->major_changed_refdes) {
-    GList* current = toplevel->major_changed_refdes;
-    while (current)
-    {
-      /* printf("yeah freeing: %s\n", (char*) current->data); */
-      g_free(current->data);
-      current = g_list_next(current);
-    }
-    g_list_free(toplevel->major_changed_refdes);
-  }
-
   /* stuff that has to be done before we free w_current */
   if (last_window) {
     /* close the log file */
@@ -738,7 +730,7 @@ x_window_open_page_impl (GschemToplevel *w_current, const gchar *filename)
 
   /* Try to load [filename]: */
   GError* err = NULL;
-  if (!f_open (toplevel, page, filename, &err))
+  if (!schematic_file_open (w_current, page, filename, &err))
   {
     g_warning ("%s\n", err->message);
     open_page_error_dialog (w_current, filename, err);
@@ -810,10 +802,6 @@ x_window_set_current_page_impl (GschemToplevel *w_current, PAGE *page)
  *  to save page <B>page</B> to file <B>filename</B> (1 on success, 0
  *  on failure).
  *
- *  <B>page</B> may not be the current page of <B>toplevel</B>. The
- *  current page of <B>toplevel</B> is not affected by this function.
- *
- *  \param [in] w_current The toplevel environment.
  *  \param [in] page      The page to save.
  *  \param [in] filename  The name of the file in which to save page.
  *  \returns 1 on success, 0 otherwise.
@@ -821,17 +809,15 @@ x_window_set_current_page_impl (GschemToplevel *w_current, PAGE *page)
 gint
 x_window_save_page (GschemToplevel *w_current, PAGE *page, const gchar *filename)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
   const gchar *log_msg, *state_msg;
   gint ret;
   GError *err = NULL;
 
-  g_return_val_if_fail (toplevel != NULL, 0);
   g_return_val_if_fail (page     != NULL, 0);
   g_return_val_if_fail (filename != NULL, 0);
 
   /* try saving page to filename */
-  ret = (gint)f_save (toplevel, page, filename, &err);
+  ret = (gint)f_save (page, filename, &err);
 
   if (ret != 1) {
     log_msg   = _("Could NOT save page [%1$s]\n");
@@ -1017,12 +1003,6 @@ GschemToplevel* x_window_new (TOPLEVEL *toplevel)
   gschem_toplevel_set_toplevel (w_current,
                                 (toplevel != NULL) ? toplevel : s_toplevel_new ());
 
-  gschem_toplevel_get_toplevel (w_current)->load_newer_backup_func = x_fileselect_load_backup;
-  gschem_toplevel_get_toplevel (w_current)->load_newer_backup_data = w_current;
-
-  o_text_set_rendered_bounds_func (gschem_toplevel_get_toplevel (w_current),
-                                   o_text_get_rendered_bounds, w_current);
-
   /* Damage notifications should invalidate the object on screen */
   o_add_change_notify (gschem_toplevel_get_toplevel (w_current),
                        (ChangeNotifyFunc) o_invalidate,
@@ -1400,20 +1380,18 @@ create_bottom_widget (GschemToplevel *w_current, GtkWidget *main_box)
 void
 x_window_setup_scrolling (GschemToplevel *w_current, GtkWidget *scrolled)
 {
-  GedaToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
-
   GtkAdjustment *hadjustment = GTK_ADJUSTMENT(
     gtk_adjustment_new (0.0,
-                        toplevel->init_left,
-                        toplevel->init_right,
+                        WORLD_DEFAULT_LEFT,
+                        WORLD_DEFAULT_RIGHT,
                         100.0,
                         100.0,
                         10.0));
 
   GtkAdjustment *vadjustment = GTK_ADJUSTMENT(
-    gtk_adjustment_new (toplevel->init_bottom,
+    gtk_adjustment_new (WORLD_DEFAULT_BOTTOM,
                         0.0,
-                        toplevel->init_bottom - toplevel->init_top,
+                        WORLD_DEFAULT_BOTTOM - WORLD_DEFAULT_TOP,
                         100.0,
                         100.0,
                         10.0));
@@ -1475,7 +1453,7 @@ create_notebook_bottom (GschemToplevel* w_current)
 
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
                               GTK_WIDGET (w_current->log_widget),
-                              gtk_label_new(_("Status")));
+                              gtk_label_new(_("Log")));
 
 
     gtk_container_set_border_width (GTK_CONTAINER (notebook),
@@ -1495,14 +1473,26 @@ create_notebook_bottom (GschemToplevel* w_current)
 PAGE*
 x_window_open_page (GschemToplevel* w_current, const gchar* filename)
 {
+  PAGE* page = NULL;
+
   if (x_tabs_enabled())
   {
-    return x_tabs_page_open (w_current, filename);
+    page = x_tabs_page_open (w_current, filename);
   }
   else
   {
-    return x_window_open_page_impl (w_current, filename);
+    page = x_window_open_page_impl (w_current, filename);
   }
+
+  if (filename != NULL && page != NULL)
+  {
+    /* check for symbol version changes, display
+     * an error dialog box, if necessary:
+    */
+    major_changed_dialog (w_current);
+  }
+
+  return page;
 }
 
 
